window.Gleam.initSearch([{"doc":"gleam_stdlib","title":"gleam_stdlib","content":"# stdlib\n\n[![Package Version](https://img.shields.io/hexpm/v/gleam_stdlib)](https://hex.pm/packages/gleam_stdlib)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleam_stdlib/)\n[![Discord chat](https://img.shields.io/discord/768594524158427167?color=blue)](https://discord.gg/Fm8Pwmy)\n\nGleam&#39;s standard library!\nDocumentation available on [HexDocs](https://hexdocs.pm/gleam_stdlib/).\n\n## Installation\n\nAdd `gleam_stdlib` to your Gleam project.\n\n```sh\ngleam add gleam_stdlib\n```\n\n## Usage\n\nImport the modules you want to use and write some code!\n\n```gleam\nimport gleam/string\n\npub fn greet(name: String) -&gt; String {\n  string.concat([&quot;Hello &quot;, name, &quot;!&quot;])\n}\n```\n\n## Targets\n\nGleam&#39;s standard library supports both targets: Erlang and JavaScript.\n\n### Compatibility\n\nThis library is compatible with all versions of Erlang/OTP 26 and higher, \nas well as all NodeJS, Deno, Bun, and major browsers that are currently\nsupported by their maintainers. If you have a compatibility issue with\nany platform open an issue and we&#39;ll see what we can do to help.\n","url":"index.html"},{"doc":"gleam/order","title":"Order","content":"pub type Order {\n  Lt\n  Eq\n  Gt\n}\n Represents the result of a single comparison to determine the precise\n ordering of two values.\n\nLt\n Less-than\n\nEq\n Equal\n\nGt\n Greater than\n\nSynonyms:\ngleam/order.Order\ngleam/order Order","url":"gleam/order.html#Order"},{"doc":"gleam/order","title":"break_tie","content":"pub fn break_tie(in order: Order, with other: Order) -&gt; Order\n Return a fallback `Order` in case the first argument is `Eq`.\n\n ## Examples\n\n \n import gleam/int\n\n break_tie(in: int.compare(1, 1), with: Lt)\n // -&gt; Lt\n \n\n \n import gleam/int\n\n break_tie(in: int.compare(1, 0), with: Eq)\n // -&gt; Gt\n \n\nSynonyms:\ngleam/order.break_tie\ngleam/order break_tie","url":"gleam/order.html#break_tie"},{"doc":"gleam/order","title":"compare","content":"pub fn compare(a: Order, with b: Order) -&gt; Order\n Compares two `Order` values to one another, producing a new `Order`.\n\n ## Examples\n\n \n compare(Eq, with: Lt)\n // -&gt; Gt\n \n\nSynonyms:\ngleam/order.compare\ngleam/order compare","url":"gleam/order.html#compare"},{"doc":"gleam/order","title":"lazy_break_tie","content":"pub fn lazy_break_tie(\n  in order: Order,\n  with comparison: fn() -&gt; Order,\n) -&gt; Order\n Invokes a fallback function returning an `Order` in case the first argument\n is `Eq`.\n\n This can be useful when the fallback comparison might be expensive and it\n needs to be delayed until strictly necessary.\n\n ## Examples\n\n \n import gleam/int\n\n lazy_break_tie(in: int.compare(1, 1), with: fn() { Lt })\n // -&gt; Lt\n \n\n \n import gleam/int\n\n lazy_break_tie(in: int.compare(1, 0), with: fn() { Eq })\n // -&gt; Gt\n \n\nSynonyms:\ngleam/order.lazy_break_tie\ngleam/order lazy_break_tie","url":"gleam/order.html#lazy_break_tie"},{"doc":"gleam/order","title":"negate","content":"pub fn negate(order: Order) -&gt; Order\n Inverts an order, so less-than becomes greater-than and greater-than\n becomes less-than.\n\n ## Examples\n\n \n negate(Lt)\n // -&gt; Gt\n \n\n \n negate(Eq)\n // -&gt; Eq\n \n\n \n negate(Gt)\n // -&gt; Lt\n \n\nSynonyms:\ngleam/order.negate\ngleam/order negate","url":"gleam/order.html#negate"},{"doc":"gleam/order","title":"reverse","content":"pub fn reverse(orderer: fn(a, a) -&gt; Order) -&gt; fn(a, a) -&gt; Order\n Inverts an ordering function, so less-than becomes greater-than and greater-than\n becomes less-than.\n\n ## Examples\n\n \n import gleam/int\n import gleam/list\n\n list.sort([1, 5, 4], by: reverse(int.compare))\n // -&gt; [5, 4, 1]\n \n\nSynonyms:\ngleam/order.reverse\ngleam/order reverse","url":"gleam/order.html#reverse"},{"doc":"gleam/order","title":"to_int","content":"pub fn to_int(order: Order) -&gt; Int\n Produces a numeric representation of the order.\n\n ## Examples\n\n \n to_int(Lt)\n // -&gt; -1\n \n\n \n to_int(Eq)\n // -&gt; 0\n \n\n \n to_int(Gt)\n // -&gt; 1\n \n\nSynonyms:\ngleam/order.to_int\ngleam/order to_int","url":"gleam/order.html#to_int"},{"doc":"gleam/order","title":"gleam/order","content":"","url":"gleam/order.html"},{"doc":"gleam/float","title":"absolute_value","content":"pub fn absolute_value(x: Float) -&gt; Float\n Returns the absolute value of the input as a `Float`.\n\n ## Examples\n\n \n absolute_value(-12.5)\n // -&gt; 12.5\n \n\n \n absolute_value(10.2)\n // -&gt; 10.2\n \n\nSynonyms:\ngleam/float.absolute_value\ngleam/float absolute_value","url":"gleam/float.html#absolute_value"},{"doc":"gleam/float","title":"add","content":"pub fn add(a: Float, b: Float) -&gt; Float\n Adds two floats together.\n\n It&#39;s the function equivalent of the `+.` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n add(1.0, 2.0)\n // -&gt; 3.0\n \n\n \n import gleam/list\n\n list.fold([1.0, 2.0, 3.0], 0.0, add)\n // -&gt; 6.0\n \n\n \n 3.0 |&gt; add(2.0)\n // -&gt; 5.0\n \n\nSynonyms:\ngleam/float.add\ngleam/float add","url":"gleam/float.html#add"},{"doc":"gleam/float","title":"ceiling","content":"pub fn ceiling(x: Float) -&gt; Float\n Rounds the value to the next highest whole number as a `Float`.\n\n ## Examples\n\n \n ceiling(2.3)\n // -&gt; 3.0\n \n\nSynonyms:\ngleam/float.ceiling\ngleam/float ceiling","url":"gleam/float.html#ceiling"},{"doc":"gleam/float","title":"clamp","content":"pub fn clamp(\n  x: Float,\n  min min_bound: Float,\n  max max_bound: Float,\n) -&gt; Float\n Restricts a `Float` between a lower and upper bound.\n\n ## Examples\n\n \n clamp(1.2, min: 1.4, max: 1.6)\n // -&gt; 1.4\n \n\nSynonyms:\ngleam/float.clamp\ngleam/float clamp","url":"gleam/float.html#clamp"},{"doc":"gleam/float","title":"compare","content":"pub fn compare(a: Float, with b: Float) -&gt; Order\n Compares two `Float`s, returning an `Order`:\n `Lt` for lower than, `Eq` for equals, or `Gt` for greater than.\n\n ## Examples\n\n \n compare(2.0, 2.3)\n // -&gt; Lt\n \n\n To handle\n [Floating Point Imprecision](https://en.wikipedia.org/wiki/Floating-point_arithmetic#Accuracy_problems)\n you may use [`loosely_compare`](#loosely_compare) instead.\n\nSynonyms:\ngleam/float.compare\ngleam/float compare","url":"gleam/float.html#compare"},{"doc":"gleam/float","title":"divide","content":"pub fn divide(a: Float, by b: Float) -&gt; Result(Float, Nil)\n Returns division of the inputs as a `Result`.\n\n ## Examples\n\n \n divide(0.0, 1.0)\n // -&gt; Ok(0.0)\n \n\n \n divide(1.0, 0.0)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/float.divide\ngleam/float divide","url":"gleam/float.html#divide"},{"doc":"gleam/float","title":"exponential","content":"pub fn exponential(x: Float) -&gt; Float\n Returns e (Euler&#39;s number) raised to the power of the given exponent, as\n a `Float`.\n\n ## Examples\n\n \n exponential(0.0)\n // -&gt; Ok(1.0)\n \n\n \n exponential(1.0)\n // -&gt; Ok(2.718281828459045)\n \n\n \n exponential(-1.0)\n // -&gt; Ok(0.36787944117144233)\n \n\nSynonyms:\ngleam/float.exponential\ngleam/float exponential","url":"gleam/float.html#exponential"},{"doc":"gleam/float","title":"floor","content":"pub fn floor(x: Float) -&gt; Float\n Rounds the value to the next lowest whole number as a `Float`.\n\n ## Examples\n\n \n floor(2.3)\n // -&gt; 2.0\n \n\nSynonyms:\ngleam/float.floor\ngleam/float floor","url":"gleam/float.html#floor"},{"doc":"gleam/float","title":"logarithm","content":"pub fn logarithm(x: Float) -&gt; Result(Float, Nil)\n Returns the natural logarithm (base e) of the given as a `Result`. If the\n input is less than or equal to 0, returns `Error(Nil)`.\n\n ## Examples\n\n \n logarithm(1.0)\n // -&gt; Ok(0.0)\n \n\n \n logarithm(2.718281828459045)  // e\n // -&gt; Ok(1.0)\n \n\n \n logarithm(0.0)\n // -&gt; Error(Nil)\n \n\n \n logarithm(-1.0)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/float.logarithm\ngleam/float logarithm","url":"gleam/float.html#logarithm"},{"doc":"gleam/float","title":"loosely_compare","content":"pub fn loosely_compare(\n  a: Float,\n  with b: Float,\n  tolerating tolerance: Float,\n) -&gt; Order\n Compares two `Float`s within a tolerance, returning an `Order`:\n `Lt` for lower than, `Eq` for equals, or `Gt` for greater than.\n\n This function allows Float comparison while handling\n [Floating Point Imprecision](https://en.wikipedia.org/wiki/Floating-point_arithmetic#Accuracy_problems).\n\n Notice: For `Float`s the tolerance won&#39;t be exact:\n `5.3 - 5.0` is not exactly `0.3`.\n\n ## Examples\n\n \n loosely_compare(5.0, with: 5.3, tolerating: 0.5)\n // -&gt; Eq\n \n\n If you want to check only for equality you may use\n [`loosely_equals`](#loosely_equals) instead.\n\nSynonyms:\ngleam/float.loosely_compare\ngleam/float loosely_compare","url":"gleam/float.html#loosely_compare"},{"doc":"gleam/float","title":"loosely_equals","content":"pub fn loosely_equals(\n  a: Float,\n  with b: Float,\n  tolerating tolerance: Float,\n) -&gt; Bool\n Checks for equality of two `Float`s within a tolerance,\n returning an `Bool`.\n\n This function allows Float comparison while handling\n [Floating Point Imprecision](https://en.wikipedia.org/wiki/Floating-point_arithmetic#Accuracy_problems).\n\n Notice: For `Float`s the tolerance won&#39;t be exact:\n `5.3 - 5.0` is not exactly `0.3`.\n\n ## Examples\n\n \n loosely_equals(5.0, with: 5.3, tolerating: 0.5)\n // -&gt; True\n \n\n \n loosely_equals(5.0, with: 5.1, tolerating: 0.1)\n // -&gt; False\n \n\nSynonyms:\ngleam/float.loosely_equals\ngleam/float loosely_equals","url":"gleam/float.html#loosely_equals"},{"doc":"gleam/float","title":"max","content":"pub fn max(a: Float, b: Float) -&gt; Float\n Compares two `Float`s, returning the larger of the two.\n\n ## Examples\n\n \n max(2.0, 2.3)\n // -&gt; 2.3\n \n\nSynonyms:\ngleam/float.max\ngleam/float max","url":"gleam/float.html#max"},{"doc":"gleam/float","title":"min","content":"pub fn min(a: Float, b: Float) -&gt; Float\n Compares two `Float`s, returning the smaller of the two.\n\n ## Examples\n\n \n min(2.0, 2.3)\n // -&gt; 2.0\n \n\nSynonyms:\ngleam/float.min\ngleam/float min","url":"gleam/float.html#min"},{"doc":"gleam/float","title":"modulo","content":"pub fn modulo(\n  dividend: Float,\n  by divisor: Float,\n) -&gt; Result(Float, Nil)\n Computes the modulo of an float division of inputs as a `Result`.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n ## Examples\n\n \n modulo(13.3, by: 3.3)\n // -&gt; Ok(0.1)\n \n\n \n modulo(-13.3, by: 3.3)\n // -&gt; Ok(3.2)\n \n\n \n modulo(13.3, by: -3.3)\n // -&gt; Ok(-3.2)\n \n\n \n modulo(-13.3, by: -3.3)\n // -&gt; Ok(-0.1)\n \n\nSynonyms:\ngleam/float.modulo\ngleam/float modulo","url":"gleam/float.html#modulo"},{"doc":"gleam/float","title":"multiply","content":"pub fn multiply(a: Float, b: Float) -&gt; Float\n Multiplies two floats together.\n\n It&#39;s the function equivalent of the `*.` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n multiply(2.0, 4.0)\n // -&gt; 8.0\n \n\n \n import gleam/list\n\n list.fold([2.0, 3.0, 4.0], 1.0, multiply)\n // -&gt; 24.0\n \n\n \n 3.0 |&gt; multiply(2.0)\n // -&gt; 6.0\n \n\nSynonyms:\ngleam/float.multiply\ngleam/float multiply","url":"gleam/float.html#multiply"},{"doc":"gleam/float","title":"negate","content":"pub fn negate(x: Float) -&gt; Float\n Returns the negative of the value provided.\n\n ## Examples\n\n \n negate(1.0)\n // -&gt; -1.0\n \n\nSynonyms:\ngleam/float.negate\ngleam/float negate","url":"gleam/float.html#negate"},{"doc":"gleam/float","title":"parse","content":"pub fn parse(string: String) -&gt; Result(Float, Nil)\n Attempts to parse a string as a `Float`, returning `Error(Nil)` if it was\n not possible.\n\n ## Examples\n\n \n parse(&quot;2.3&quot;)\n // -&gt; Ok(2.3)\n \n\n \n parse(&quot;ABC&quot;)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/float.parse\ngleam/float parse","url":"gleam/float.html#parse"},{"doc":"gleam/float","title":"power","content":"pub fn power(\n  base: Float,\n  of exponent: Float,\n) -&gt; Result(Float, Nil)\n Returns the results of the base being raised to the power of the\n exponent, as a `Float`.\n\n ## Examples\n\n \n power(2.0, -1.0)\n // -&gt; Ok(0.5)\n \n\n \n power(2.0, 2.0)\n // -&gt; Ok(4.0)\n \n\n \n power(8.0, 1.5)\n // -&gt; Ok(22.627416997969522)\n \n\n \n 4.0 |&gt; power(of: 2.0)\n // -&gt; Ok(16.0)\n \n\n \n power(-1.0, 0.5)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/float.power\ngleam/float power","url":"gleam/float.html#power"},{"doc":"gleam/float","title":"product","content":"pub fn product(numbers: List(Float)) -&gt; Float\n Multiplies a list of `Float`s and returns the product.\n\n ## Example\n\n \n product([2.5, 3.2, 4.2])\n // -&gt; 33.6\n \n\nSynonyms:\ngleam/float.product\ngleam/float product","url":"gleam/float.html#product"},{"doc":"gleam/float","title":"random","content":"pub fn random() -&gt; Float\n Generates a random float between the given zero (inclusive) and one\n (exclusive).\n\n On Erlang this updates the random state in the process dictionary.\n See: &lt;https://www.erlang.org/doc/man/rand.html#uniform-0&gt;\n\n ## Examples\n\n \n random()\n // -&gt; 0.646355926896028\n \n\nSynonyms:\ngleam/float.random\ngleam/float random","url":"gleam/float.html#random"},{"doc":"gleam/float","title":"round","content":"pub fn round(x: Float) -&gt; Int\n Rounds the value to the nearest whole number as an `Int`.\n\n ## Examples\n\n \n round(2.3)\n // -&gt; 2\n \n\n \n round(2.5)\n // -&gt; 3\n \n\nSynonyms:\ngleam/float.round\ngleam/float round","url":"gleam/float.html#round"},{"doc":"gleam/float","title":"square_root","content":"pub fn square_root(x: Float) -&gt; Result(Float, Nil)\n Returns the square root of the input as a `Float`.\n\n ## Examples\n\n \n square_root(4.0)\n // -&gt; Ok(2.0)\n \n\n \n square_root(-16.0)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/float.square_root\ngleam/float square_root","url":"gleam/float.html#square_root"},{"doc":"gleam/float","title":"subtract","content":"pub fn subtract(a: Float, b: Float) -&gt; Float\n Subtracts one float from another.\n\n It&#39;s the function equivalent of the `-.` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n subtract(3.0, 1.0)\n // -&gt; 2.0\n \n\n \n import gleam/list\n\n list.fold([1.0, 2.0, 3.0], 10.0, subtract)\n // -&gt; 4.0\n \n\n \n 3.0 |&gt; subtract(_, 2.0)\n // -&gt; 1.0\n \n\n \n 3.0 |&gt; subtract(2.0, _)\n // -&gt; -1.0\n \n\nSynonyms:\ngleam/float.subtract\ngleam/float subtract","url":"gleam/float.html#subtract"},{"doc":"gleam/float","title":"sum","content":"pub fn sum(numbers: List(Float)) -&gt; Float\n Sums a list of `Float`s.\n\n ## Example\n\n \n sum([1.0, 2.2, 3.3])\n // -&gt; 6.5\n \n\nSynonyms:\ngleam/float.sum\ngleam/float sum","url":"gleam/float.html#sum"},{"doc":"gleam/float","title":"to_precision","content":"pub fn to_precision(x: Float, precision: Int) -&gt; Float\n Converts the value to a given precision as a `Float`.\n The precision is the number of allowed decimal places.\n Negative precisions are allowed and force rounding\n to the nearest tenth, hundredth, thousandth etc.\n\n ## Examples\n\n \n to_precision(2.43434348473, precision: 2)\n // -&gt; 2.43\n \n\n \n to_precision(547890.453444, precision: -3)\n // -&gt; 548000.0\n \n\nSynonyms:\ngleam/float.to_precision\ngleam/float to_precision","url":"gleam/float.html#to_precision"},{"doc":"gleam/float","title":"to_string","content":"pub fn to_string(x: Float) -&gt; String\n Returns the string representation of the provided `Float`.\n\n ## Examples\n\n \n to_string(2.3)\n // -&gt; &quot;2.3&quot;\n \n\nSynonyms:\ngleam/float.to_string\ngleam/float to_string","url":"gleam/float.html#to_string"},{"doc":"gleam/float","title":"truncate","content":"pub fn truncate(x: Float) -&gt; Int\n Returns the value as an `Int`, truncating all decimal digits.\n\n ## Examples\n\n \n truncate(2.4343434847383438)\n // -&gt; 2\n \n\nSynonyms:\ngleam/float.truncate\ngleam/float truncate","url":"gleam/float.html#truncate"},{"doc":"gleam/float","title":"gleam/float","content":" Functions for working with floats.\n\n ## Float representation\n\n Floats are represented as 64 bit floating point numbers on both the Erlang\n and JavaScript runtimes. The floating point behaviour is native to their\n respective runtimes, so their exact behaviour will be slightly different on\n the two runtimes.\n\n ### Infinity and NaN\n\n Under the JavaScript runtime, exceeding the maximum (or minimum)\n representable value for a floating point value will result in Infinity (or\n -Infinity). Should you try to divide two infinities you will get NaN as a\n result.\n\n When running on BEAM, exceeding the maximum (or minimum) representable\n value for a floating point value will raise an error.\n\n ## Division by zero\n\n Gleam runs on the Erlang virtual machine, which does not follow the IEEE\n 754 standard for floating point arithmetic and does not have an `Infinity`\n value.  In Erlang division by zero results in a crash, however Gleam does\n not have partial functions and operators in core so instead division by zero\n returns zero, a behaviour taken from Pony, Coq, and Lean.\n\n This may seem unexpected at first, but it is no less mathematically valid\n than crashing or returning a special value. Division by zero is undefined\n in mathematics.","url":"gleam/float.html"},{"doc":"gleam/int","title":"absolute_value","content":"pub fn absolute_value(x: Int) -&gt; Int\n Returns the absolute value of the input.\n\n ## Examples\n\n \n absolute_value(-12)\n // -&gt; 12\n \n\n \n absolute_value(10)\n // -&gt; 10\n \n\nSynonyms:\ngleam/int.absolute_value\ngleam/int absolute_value","url":"gleam/int.html#absolute_value"},{"doc":"gleam/int","title":"add","content":"pub fn add(a: Int, b: Int) -&gt; Int\n Adds two integers together.\n\n It&#39;s the function equivalent of the `+` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n add(1, 2)\n // -&gt; 3\n \n\n \n import gleam/list\n list.fold([1, 2, 3], 0, add)\n // -&gt; 6\n \n\n \n 3 |&gt; add(2)\n // -&gt; 5\n \n\nSynonyms:\ngleam/int.add\ngleam/int add","url":"gleam/int.html#add"},{"doc":"gleam/int","title":"base_parse","content":"pub fn base_parse(string: String, base: Int) -&gt; Result(Int, Nil)\n Parses a given string as an int in a given base if possible.\n Supports only bases 2 to 36, for values outside of which this function returns an `Error(Nil)`.\n\n ## Examples\n\n \n base_parse(&quot;10&quot;, 2)\n // -&gt; Ok(2)\n \n\n \n base_parse(&quot;30&quot;, 16)\n // -&gt; Ok(48)\n \n\n \n base_parse(&quot;1C&quot;, 36)\n // -&gt; Ok(48)\n \n\n \n base_parse(&quot;48&quot;, 1)\n // -&gt; Error(Nil)\n \n\n \n base_parse(&quot;48&quot;, 37)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/int.base_parse\ngleam/int base_parse","url":"gleam/int.html#base_parse"},{"doc":"gleam/int","title":"bitwise_and","content":"pub fn bitwise_and(x: Int, y: Int) -&gt; Int\n Calculates the bitwise AND of its arguments.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_and\ngleam/int bitwise_and","url":"gleam/int.html#bitwise_and"},{"doc":"gleam/int","title":"bitwise_exclusive_or","content":"pub fn bitwise_exclusive_or(x: Int, y: Int) -&gt; Int\n Calculates the bitwise XOR of its arguments.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_exclusive_or\ngleam/int bitwise_exclusive_or","url":"gleam/int.html#bitwise_exclusive_or"},{"doc":"gleam/int","title":"bitwise_not","content":"pub fn bitwise_not(x: Int) -&gt; Int\n Calculates the bitwise NOT of its argument.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_not\ngleam/int bitwise_not","url":"gleam/int.html#bitwise_not"},{"doc":"gleam/int","title":"bitwise_or","content":"pub fn bitwise_or(x: Int, y: Int) -&gt; Int\n Calculates the bitwise OR of its arguments.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_or\ngleam/int bitwise_or","url":"gleam/int.html#bitwise_or"},{"doc":"gleam/int","title":"bitwise_shift_left","content":"pub fn bitwise_shift_left(x: Int, y: Int) -&gt; Int\n Calculates the result of an arithmetic left bitshift.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_shift_left\ngleam/int bitwise_shift_left","url":"gleam/int.html#bitwise_shift_left"},{"doc":"gleam/int","title":"bitwise_shift_right","content":"pub fn bitwise_shift_right(x: Int, y: Int) -&gt; Int\n Calculates the result of an arithmetic right bitshift.\n\n The exact behaviour of this function depends on the target platform.\n On Erlang it is equivalent to bitwise operations on ints, on JavaScript it\n is equivalent to bitwise operations on big-ints.\n\nSynonyms:\ngleam/int.bitwise_shift_right\ngleam/int bitwise_shift_right","url":"gleam/int.html#bitwise_shift_right"},{"doc":"gleam/int","title":"clamp","content":"pub fn clamp(\n  x: Int,\n  min min_bound: Int,\n  max max_bound: Int,\n) -&gt; Int\n Restricts an int between a lower and upper bound.\n\n ## Examples\n\n \n clamp(40, min: 50, max: 60)\n // -&gt; 50\n \n\nSynonyms:\ngleam/int.clamp\ngleam/int clamp","url":"gleam/int.html#clamp"},{"doc":"gleam/int","title":"compare","content":"pub fn compare(a: Int, with b: Int) -&gt; Order\n Compares two ints, returning an order.\n\n ## Examples\n\n \n compare(2, 3)\n // -&gt; Lt\n \n\n \n compare(4, 3)\n // -&gt; Gt\n \n\n \n compare(3, 3)\n // -&gt; Eq\n \n\nSynonyms:\ngleam/int.compare\ngleam/int compare","url":"gleam/int.html#compare"},{"doc":"gleam/int","title":"digits","content":"pub fn digits(x: Int, base: Int) -&gt; Result(List(Int), Nil)\n Splits an integer into its digit representation in the specified base.\n Returns an error if the base is less than 2.\n\n ## Examples\n\n \n digits(234, 10)\n // -&gt; Ok([2,3,4])\n \n\n \n digits(234, 1)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/int.digits\ngleam/int digits","url":"gleam/int.html#digits"},{"doc":"gleam/int","title":"divide","content":"pub fn divide(dividend: Int, by divisor: Int) -&gt; Result(Int, Nil)\n Performs a truncated integer division.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n ## Examples\n\n \n divide(0, 1)\n // -&gt; Ok(0)\n \n\n \n divide(1, 0)\n // -&gt; Error(Nil)\n \n\n \n divide(5, 2)\n // -&gt; Ok(2)\n \n\n \n divide(-99, 2)\n // -&gt; Ok(-49)\n \n\nSynonyms:\ngleam/int.divide\ngleam/int divide","url":"gleam/int.html#divide"},{"doc":"gleam/int","title":"floor_divide","content":"pub fn floor_divide(\n  dividend: Int,\n  by divisor: Int,\n) -&gt; Result(Int, Nil)\n Performs a *floored* integer division, which means that the result will\n always be rounded towards negative infinity.\n\n If you want to perform truncated integer division (rounding towards zero),\n use `int.divide()` or the `/` operator instead.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n ## Examples\n\n \n floor_divide(1, 0)\n // -&gt; Error(Nil)\n \n\n \n floor_divide(5, 2)\n // -&gt; Ok(2)\n \n\n \n floor_divide(6, -4)\n // -&gt; Ok(-2)\n \n\n \n floor_divide(-99, 2)\n // -&gt; Ok(-50)\n \n\nSynonyms:\ngleam/int.floor_divide\ngleam/int floor_divide","url":"gleam/int.html#floor_divide"},{"doc":"gleam/int","title":"is_even","content":"pub fn is_even(x: Int) -&gt; Bool\n Returns whether the value provided is even.\n\n ## Examples\n\n \n is_even(2)\n // -&gt; True\n \n\n \n is_even(3)\n // -&gt; False\n \n\nSynonyms:\ngleam/int.is_even\ngleam/int is_even","url":"gleam/int.html#is_even"},{"doc":"gleam/int","title":"is_odd","content":"pub fn is_odd(x: Int) -&gt; Bool\n Returns whether the value provided is odd.\n\n ## Examples\n\n \n is_odd(3)\n // -&gt; True\n \n\n \n is_odd(2)\n // -&gt; False\n \n\nSynonyms:\ngleam/int.is_odd\ngleam/int is_odd","url":"gleam/int.html#is_odd"},{"doc":"gleam/int","title":"max","content":"pub fn max(a: Int, b: Int) -&gt; Int\n Compares two ints, returning the larger of the two.\n\n ## Examples\n\n \n max(2, 3)\n // -&gt; 3\n \n\nSynonyms:\ngleam/int.max\ngleam/int max","url":"gleam/int.html#max"},{"doc":"gleam/int","title":"min","content":"pub fn min(a: Int, b: Int) -&gt; Int\n Compares two ints, returning the smaller of the two.\n\n ## Examples\n\n \n min(2, 3)\n // -&gt; 2\n \n\nSynonyms:\ngleam/int.min\ngleam/int min","url":"gleam/int.html#min"},{"doc":"gleam/int","title":"modulo","content":"pub fn modulo(dividend: Int, by divisor: Int) -&gt; Result(Int, Nil)\n Computes the modulo of an integer division of inputs as a `Result`.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n Most the time you will want to use the `%` operator instead of this\n function.\n\n ## Examples\n\n \n modulo(3, 2)\n // -&gt; Ok(1)\n \n\n \n modulo(1, 0)\n // -&gt; Error(Nil)\n \n\n \n modulo(10, -1)\n // -&gt; Ok(0)\n \n\n \n modulo(13, by: 3)\n // -&gt; Ok(1)\n \n\n \n modulo(-13, by: 3)\n // -&gt; Ok(2)\n \n\nSynonyms:\ngleam/int.modulo\ngleam/int modulo","url":"gleam/int.html#modulo"},{"doc":"gleam/int","title":"multiply","content":"pub fn multiply(a: Int, b: Int) -&gt; Int\n Multiplies two integers together.\n\n It&#39;s the function equivalent of the `*` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n multiply(2, 4)\n // -&gt; 8\n \n\n \n import gleam/list\n\n list.fold([2, 3, 4], 1, multiply)\n // -&gt; 24\n \n\n \n 3 |&gt; multiply(2)\n // -&gt; 6\n \n\nSynonyms:\ngleam/int.multiply\ngleam/int multiply","url":"gleam/int.html#multiply"},{"doc":"gleam/int","title":"negate","content":"pub fn negate(x: Int) -&gt; Int\n Returns the negative of the value provided.\n\n ## Examples\n\n \n negate(1)\n // -&gt; -1\n \n\nSynonyms:\ngleam/int.negate\ngleam/int negate","url":"gleam/int.html#negate"},{"doc":"gleam/int","title":"parse","content":"pub fn parse(string: String) -&gt; Result(Int, Nil)\n Parses a given string as an int if possible.\n\n ## Examples\n\n \n parse(&quot;2&quot;)\n // -&gt; Ok(2)\n \n\n \n parse(&quot;ABC&quot;)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/int.parse\ngleam/int parse","url":"gleam/int.html#parse"},{"doc":"gleam/int","title":"power","content":"pub fn power(base: Int, of exponent: Float) -&gt; Result(Float, Nil)\n Returns the results of the base being raised to the power of the\n exponent, as a `Float`.\n\n ## Examples\n\n \n power(2, -1.0)\n // -&gt; Ok(0.5)\n \n\n \n power(2, 2.0)\n // -&gt; Ok(4.0)\n \n\n \n power(8, 1.5)\n // -&gt; Ok(22.627416997969522)\n \n\n \n 4 |&gt; power(of: 2.0)\n // -&gt; Ok(16.0)\n \n\n \n power(-1, 0.5)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/int.power\ngleam/int power","url":"gleam/int.html#power"},{"doc":"gleam/int","title":"product","content":"pub fn product(numbers: List(Int)) -&gt; Int\n Multiplies a list of ints and returns the product.\n\n ## Example\n\n \n product([2, 3, 4])\n // -&gt; 24\n \n\nSynonyms:\ngleam/int.product\ngleam/int product","url":"gleam/int.html#product"},{"doc":"gleam/int","title":"random","content":"pub fn random(max: Int) -&gt; Int\n Generates a random int between zero and the given maximum.\n\n The lower number is inclusive, the upper number is exclusive.\n\n ## Examples\n\n \n random(10)\n // -&gt; 4\n \n\n \n random(1)\n // -&gt; 0\n \n\n \n random(-1)\n // -&gt; -1\n \n\nSynonyms:\ngleam/int.random\ngleam/int random","url":"gleam/int.html#random"},{"doc":"gleam/int","title":"remainder","content":"pub fn remainder(\n  dividend: Int,\n  by divisor: Int,\n) -&gt; Result(Int, Nil)\n Computes the remainder of an integer division of inputs as a `Result`.\n\n Returns division of the inputs as a `Result`: If the given divisor equals\n `0`, this function returns an `Error`.\n\n Most the time you will want to use the `%` operator instead of this\n function.\n\n ## Examples\n\n \n remainder(3, 2)\n // -&gt; Ok(1)\n \n\n \n remainder(1, 0)\n // -&gt; Error(Nil)\n \n\n \n remainder(10, -1)\n // -&gt; Ok(0)\n \n\n \n remainder(13, by: 3)\n // -&gt; Ok(1)\n \n\n \n remainder(-13, by: 3)\n // -&gt; Ok(-1)\n \n\n \n remainder(13, by: -3)\n // -&gt; Ok(1)\n \n\n \n remainder(-13, by: -3)\n // -&gt; Ok(-1)\n \n\nSynonyms:\ngleam/int.remainder\ngleam/int remainder","url":"gleam/int.html#remainder"},{"doc":"gleam/int","title":"square_root","content":"pub fn square_root(x: Int) -&gt; Result(Float, Nil)\n Returns the square root of the input as a `Float`.\n\n ## Examples\n\n \n square_root(4)\n // -&gt; Ok(2.0)\n \n\n \n square_root(-16)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/int.square_root\ngleam/int square_root","url":"gleam/int.html#square_root"},{"doc":"gleam/int","title":"subtract","content":"pub fn subtract(a: Int, b: Int) -&gt; Int\n Subtracts one int from another.\n\n It&#39;s the function equivalent of the `-` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n subtract(3, 1)\n // -&gt; 2\n \n\n \n import gleam/list\n\n list.fold([1, 2, 3], 10, subtract)\n // -&gt; 4\n \n\n \n 3 |&gt; subtract(2)\n // -&gt; 1\n \n\n \n 3 |&gt; subtract(2, _)\n // -&gt; -1\n \n\nSynonyms:\ngleam/int.subtract\ngleam/int subtract","url":"gleam/int.html#subtract"},{"doc":"gleam/int","title":"sum","content":"pub fn sum(numbers: List(Int)) -&gt; Int\n Sums a list of ints.\n\n ## Example\n\n \n sum([1, 2, 3])\n // -&gt; 6\n \n\nSynonyms:\ngleam/int.sum\ngleam/int sum","url":"gleam/int.html#sum"},{"doc":"gleam/int","title":"to_base16","content":"pub fn to_base16(x: Int) -&gt; String\n Prints a given int to a string using base-16.\n\n ## Examples\n\n \n to_base16(48)\n // -&gt; &quot;30&quot;\n \n\nSynonyms:\ngleam/int.to_base16\ngleam/int to_base16","url":"gleam/int.html#to_base16"},{"doc":"gleam/int","title":"to_base2","content":"pub fn to_base2(x: Int) -&gt; String\n Prints a given int to a string using base-2.\n\n ## Examples\n\n \n to_base2(2)\n // -&gt; &quot;10&quot;\n \n\nSynonyms:\ngleam/int.to_base2\ngleam/int to_base2","url":"gleam/int.html#to_base2"},{"doc":"gleam/int","title":"to_base36","content":"pub fn to_base36(x: Int) -&gt; String\n Prints a given int to a string using base-36.\n\n ## Examples\n\n \n to_base36(48)\n // -&gt; &quot;1C&quot;\n \n\nSynonyms:\ngleam/int.to_base36\ngleam/int to_base36","url":"gleam/int.html#to_base36"},{"doc":"gleam/int","title":"to_base8","content":"pub fn to_base8(x: Int) -&gt; String\n Prints a given int to a string using base-8.\n\n ## Examples\n\n \n to_base8(15)\n // -&gt; &quot;17&quot;\n \n\nSynonyms:\ngleam/int.to_base8\ngleam/int to_base8","url":"gleam/int.html#to_base8"},{"doc":"gleam/int","title":"to_base_string","content":"pub fn to_base_string(x: Int, base: Int) -&gt; Result(String, Nil)\n Prints a given int to a string using the base number provided.\n Supports only bases 2 to 36, for values outside of which this function returns an `Error(Nil)`.\n For common bases (2, 8, 16, 36), use the `to_baseN` functions.\n\n ## Examples\n\n \n to_base_string(2, 2)\n // -&gt; Ok(&quot;10&quot;)\n \n\n \n to_base_string(48, 16)\n // -&gt; Ok(&quot;30&quot;)\n \n\n \n to_base_string(48, 36)\n // -&gt; Ok(&quot;1C&quot;)\n \n\n \n to_base_string(48, 1)\n // -&gt; Error(Nil)\n \n\n \n to_base_string(48, 37)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/int.to_base_string\ngleam/int to_base_string","url":"gleam/int.html#to_base_string"},{"doc":"gleam/int","title":"to_float","content":"pub fn to_float(x: Int) -&gt; Float\n Takes an int and returns its value as a float.\n\n ## Examples\n\n \n to_float(5)\n // -&gt; 5.0\n \n\n \n to_float(0)\n // -&gt; 0.0\n \n\n \n to_float(-3)\n // -&gt; -3.0\n \n\nSynonyms:\ngleam/int.to_float\ngleam/int to_float","url":"gleam/int.html#to_float"},{"doc":"gleam/int","title":"to_string","content":"pub fn to_string(x: Int) -&gt; String\n Prints a given int to a string.\n\n ## Examples\n\n \n to_string(2)\n // -&gt; &quot;2&quot;\n \n\nSynonyms:\ngleam/int.to_string\ngleam/int to_string","url":"gleam/int.html#to_string"},{"doc":"gleam/int","title":"undigits","content":"pub fn undigits(\n  numbers: List(Int),\n  base: Int,\n) -&gt; Result(Int, Nil)\n Joins a list of digits into a single value.\n Returns an error if the base is less than 2 or if the list contains a digit greater than or equal to the specified base.\n\n ## Examples\n\n \n undigits([2,3,4], 10)\n // -&gt; Ok(234)\n \n\n \n undigits([2,3,4], 1)\n // -&gt; Error(Nil)\n \n\n \n undigits([2,3,4], 2)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/int.undigits\ngleam/int undigits","url":"gleam/int.html#undigits"},{"doc":"gleam/int","title":"gleam/int","content":" Functions for working with integers.\n\n ## Division by zero\n\n In Erlang division by zero results in a crash, however Gleam does not have\n partial functions and operators in core so instead division by zero returns\n zero, a behaviour taken from Pony, Coq, and Lean.\n\n This may seem unexpected at first, but it is no less mathematically valid\n than crashing or returning a special value. Division by zero is undefined\n in mathematics.","url":"gleam/int.html"},{"doc":"gleam/option","title":"Option","content":"pub type Option(a) {\n  Some(a)\n  None\n}\n `Option` represents a value that may be present or not. `Some` means the value is\n present, `None` means the value is not.\n\n This is Gleam&#39;s alternative to having a value that could be Null, as is\n possible in some other languages.\n\n ## `Option` and `Result`\n\n In other languages failible functions may return either `Result` or\n `Option` depending on whether there is more information to be given about the\n failure. In Gleam all failible functions return `Result`, and `Nil` is used\n as the error if there is no extra detail to give. This consistency removes\n the boilerplate that would otherwise be needed to convert between `Option`\n and `Result` types, and makes APIs more predictable.\n\n The `Option` type should only be used for taking optional values as\n function arguments, or for storing them in other data structures.\n\nSome(a)\n\n\nNone\n\n\nSynonyms:\ngleam/option.Option\ngleam/option Option","url":"gleam/option.html#Option"},{"doc":"gleam/option","title":"all","content":"pub fn all(list: List(Option(a))) -&gt; Option(List(a))\n Combines a list of `Option`s into a single `Option`.\n If all elements in the list are `Some` then returns a `Some` holding the list of values.\n If any element is `None` then returns`None`.\n\n ## Examples\n\n \n all([Some(1), Some(2)])\n // -&gt; Some([1, 2])\n \n\n \n all([Some(1), None])\n // -&gt; None\n \n\nSynonyms:\ngleam/option.all\ngleam/option all","url":"gleam/option.html#all"},{"doc":"gleam/option","title":"flatten","content":"pub fn flatten(option: Option(Option(a))) -&gt; Option(a)\n Merges a nested `Option` into a single layer.\n\n ## Examples\n\n \n flatten(Some(Some(1)))\n // -&gt; Some(1)\n \n\n \n flatten(Some(None))\n // -&gt; None\n \n\n \n flatten(None)\n // -&gt; None\n \n\nSynonyms:\ngleam/option.flatten\ngleam/option flatten","url":"gleam/option.html#flatten"},{"doc":"gleam/option","title":"from_result","content":"pub fn from_result(result: Result(a, b)) -&gt; Option(a)\n Converts a `Result` type to an `Option` type.\n\n ## Examples\n\n \n from_result(Ok(1))\n // -&gt; Some(1)\n \n\n \n from_result(Error(&quot;some_error&quot;))\n // -&gt; None\n \n\nSynonyms:\ngleam/option.from_result\ngleam/option from_result","url":"gleam/option.html#from_result"},{"doc":"gleam/option","title":"is_none","content":"pub fn is_none(option: Option(a)) -&gt; Bool\n Checks whether the `Option` is a `None` value.\n\n ## Examples\n\n \n is_none(Some(1))\n // -&gt; False\n \n\n \n is_none(None)\n // -&gt; True\n \n\nSynonyms:\ngleam/option.is_none\ngleam/option is_none","url":"gleam/option.html#is_none"},{"doc":"gleam/option","title":"is_some","content":"pub fn is_some(option: Option(a)) -&gt; Bool\n Checks whether the `Option` is a `Some` value.\n\n ## Examples\n\n \n is_some(Some(1))\n // -&gt; True\n \n\n \n is_some(None)\n // -&gt; False\n \n\nSynonyms:\ngleam/option.is_some\ngleam/option is_some","url":"gleam/option.html#is_some"},{"doc":"gleam/option","title":"lazy_or","content":"pub fn lazy_or(\n  first: Option(a),\n  second: fn() -&gt; Option(a),\n) -&gt; Option(a)\n Returns the first value if it is `Some`, otherwise evaluates the given function for a fallback value.\n\n ## Examples\n\n \n lazy_or(Some(1), fn() { Some(2) })\n // -&gt; Some(1)\n \n\n \n lazy_or(Some(1), fn() { None })\n // -&gt; Some(1)\n \n\n \n lazy_or(None, fn() { Some(2) })\n // -&gt; Some(2)\n \n\n \n lazy_or(None, fn() { None })\n // -&gt; None\n \n\nSynonyms:\ngleam/option.lazy_or\ngleam/option lazy_or","url":"gleam/option.html#lazy_or"},{"doc":"gleam/option","title":"lazy_unwrap","content":"pub fn lazy_unwrap(option: Option(a), or default: fn() -&gt; a) -&gt; a\n Extracts the value from an `Option`, evaluating the default function if the option is `None`.\n\n ## Examples\n\n \n lazy_unwrap(Some(1), fn() { 0 })\n // -&gt; 1\n \n\n \n lazy_unwrap(None, fn() { 0 })\n // -&gt; 0\n \n\nSynonyms:\ngleam/option.lazy_unwrap\ngleam/option lazy_unwrap","url":"gleam/option.html#lazy_unwrap"},{"doc":"gleam/option","title":"map","content":"pub fn map(\n  over option: Option(a),\n  with fun: fn(a) -&gt; b,\n) -&gt; Option(b)\n Updates a value held within the `Some` of an `Option` by calling a given function\n on it.\n\n If the `Option` is a `None` rather than `Some`, the function is not called and the\n `Option` stays the same.\n\n ## Examples\n\n \n map(over: Some(1), with: fn(x) { x + 1 })\n // -&gt; Some(2)\n \n\n \n map(over: None, with: fn(x) { x + 1 })\n // -&gt; None\n \n\nSynonyms:\ngleam/option.map\ngleam/option map","url":"gleam/option.html#map"},{"doc":"gleam/option","title":"or","content":"pub fn or(first: Option(a), second: Option(a)) -&gt; Option(a)\n Returns the first value if it is `Some`, otherwise returns the second value.\n\n ## Examples\n\n \n or(Some(1), Some(2))\n // -&gt; Some(1)\n \n\n \n or(Some(1), None)\n // -&gt; Some(1)\n \n\n \n or(None, Some(2))\n // -&gt; Some(2)\n \n\n \n or(None, None)\n // -&gt; None\n \n\nSynonyms:\ngleam/option.or\ngleam/option or","url":"gleam/option.html#or"},{"doc":"gleam/option","title":"then","content":"pub fn then(\n  option: Option(a),\n  apply fun: fn(a) -&gt; Option(b),\n) -&gt; Option(b)\n Updates a value held within the `Some` of an `Option` by calling a given function\n on it, where the given function also returns an `Option`. The two options are\n then merged together into one `Option`.\n\n If the `Option` is a `None` rather than `Some` the function is not called and the\n option stays the same.\n\n This function is the equivalent of calling `map` followed by `flatten`, and\n it is useful for chaining together multiple functions that return `Option`.\n\n ## Examples\n\n \n then(Some(1), fn(x) { Some(x + 1) })\n // -&gt; Some(2)\n \n\n \n then(Some(1), fn(x) { Some(#(&quot;a&quot;, x)) })\n // -&gt; Some(#(&quot;a&quot;, 1))\n \n\n \n then(Some(1), fn(_) { None })\n // -&gt; None\n \n\n \n then(None, fn(x) { Some(x + 1) })\n // -&gt; None\n \n\nSynonyms:\ngleam/option.then\ngleam/option then","url":"gleam/option.html#then"},{"doc":"gleam/option","title":"to_result","content":"pub fn to_result(option: Option(a), e: b) -&gt; Result(a, b)\n Converts an `Option` type to a `Result` type.\n\n ## Examples\n\n \n to_result(Some(1), &quot;some_error&quot;)\n // -&gt; Ok(1)\n \n\n \n to_result(None, &quot;some_error&quot;)\n // -&gt; Error(&quot;some_error&quot;)\n \n\nSynonyms:\ngleam/option.to_result\ngleam/option to_result","url":"gleam/option.html#to_result"},{"doc":"gleam/option","title":"unwrap","content":"pub fn unwrap(option: Option(a), or default: a) -&gt; a\n Extracts the value from an `Option`, returning a default value if there is none.\n\n ## Examples\n\n \n unwrap(Some(1), 0)\n // -&gt; 1\n \n\n \n unwrap(None, 0)\n // -&gt; 0\n \n\nSynonyms:\ngleam/option.unwrap\ngleam/option unwrap","url":"gleam/option.html#unwrap"},{"doc":"gleam/option","title":"values","content":"pub fn values(options: List(Option(a))) -&gt; List(a)\n Given a list of `Option`s,\n returns only the values inside `Some`.\n\n ## Examples\n\n \n values([Some(1), None, Some(3)])\n // -&gt; [1, 3]\n \n\nSynonyms:\ngleam/option.values\ngleam/option values","url":"gleam/option.html#values"},{"doc":"gleam/option","title":"gleam/option","content":"","url":"gleam/option.html"},{"doc":"gleam/dict","title":"Dict","content":"pub type Dict(key, value)\n A dictionary of keys and values.\n\n Any type can be used for the keys and values of a dict, but all the keys\n must be of the same type and all the values must be of the same type.\n\n Each key can only be present in a dict once.\n\n Dicts are not ordered in any way, and any unintentional ordering is not to\n be relied upon in your code as it may change in future versions of Erlang\n or Gleam.\n\n See [the Erlang map module](https://erlang.org/doc/man/maps.html) for more\n information.\n\n\nSynonyms:\ngleam/dict.Dict\ngleam/dict Dict","url":"gleam/dict.html#Dict"},{"doc":"gleam/dict","title":"combine","content":"pub fn combine(\n  dict: Dict(a, b),\n  other: Dict(a, b),\n  with fun: fn(b, b) -&gt; b,\n) -&gt; Dict(a, b)\n Creates a new dict from a pair of given dicts by combining their entries.\n\n If there are entries with the same keys in both dicts the given function is\n used to determine the new value to use in the resulting dict.\n\n ## Examples\n\n \n let a = from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n let b = from_list([#(&quot;a&quot;, 2), #(&quot;c&quot;, 3)])\n combine(a, b, fn(one, other) { one + other })\n // -&gt; from_list([#(&quot;a&quot;, 2), #(&quot;b&quot;, 1), #(&quot;c&quot;, 3)])\n \n\nSynonyms:\ngleam/dict.combine\ngleam/dict combine","url":"gleam/dict.html#combine"},{"doc":"gleam/dict","title":"delete","content":"pub fn delete(from dict: Dict(a, b), delete key: a) -&gt; Dict(a, b)\n Creates a new dict from a given dict with all the same entries except for the\n one with a given key, if it exists.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]) |&gt; delete(&quot;a&quot;)\n // -&gt; from_list([#(&quot;b&quot;, 1)])\n \n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]) |&gt; delete(&quot;c&quot;)\n // -&gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\nSynonyms:\ngleam/dict.delete\ngleam/dict delete","url":"gleam/dict.html#delete"},{"doc":"gleam/dict","title":"drop","content":"pub fn drop(\n  from dict: Dict(a, b),\n  drop disallowed_keys: List(a),\n) -&gt; Dict(a, b)\n Creates a new dict from a given dict with all the same entries except any with\n keys found in a given list.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]) |&gt; drop([&quot;a&quot;])\n // -&gt; from_list([#(&quot;b&quot;, 1)])\n \n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]) |&gt; drop([&quot;c&quot;])\n // -&gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]) |&gt; drop([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; from_list([])\n \n\nSynonyms:\ngleam/dict.drop\ngleam/dict drop","url":"gleam/dict.html#drop"},{"doc":"gleam/dict","title":"each","content":"pub fn each(dict: Dict(a, b), fun: fn(a, b) -&gt; c) -&gt; Nil\n Calls a function for each key and value in a dict, discarding the return\n value.\n\n Useful for producing a side effect for every item of a dict.\n\n \n import gleam/io\n\n let dict = from_list([#(&quot;a&quot;, &quot;apple&quot;), #(&quot;b&quot;, &quot;banana&quot;), #(&quot;c&quot;, &quot;cherry&quot;)])\n\n each(dict, fn(k, v) {\n   io.println(key &lt;&gt; &quot; =&gt; &quot; &lt;&gt; value)\n })\n // -&gt; Nil\n // a =&gt; apple\n // b =&gt; banana\n // c =&gt; cherry\n \n\n The order of elements in the iteration is an implementation detail that\n should not be relied upon.\n\nSynonyms:\ngleam/dict.each\ngleam/dict each","url":"gleam/dict.html#each"},{"doc":"gleam/dict","title":"filter","content":"pub fn filter(\n  in dict: Dict(a, b),\n  keeping predicate: fn(a, b) -&gt; Bool,\n) -&gt; Dict(a, b)\n Creates a new dict from a given dict, minus any entries that a given function\n returns `False` for.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n |&gt; filter(fn(key, value) { value != 0 })\n // -&gt; from_list([#(&quot;b&quot;, 1)])\n \n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n |&gt; filter(fn(key, value) { True })\n // -&gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\nSynonyms:\ngleam/dict.filter\ngleam/dict filter","url":"gleam/dict.html#filter"},{"doc":"gleam/dict","title":"fold","content":"pub fn fold(\n  over dict: Dict(a, b),\n  from initial: c,\n  with fun: fn(c, a, b) -&gt; c,\n) -&gt; c\n Combines all entries into a single value by calling a given function on each\n one.\n\n Dicts are not ordered so the values are not returned in any specific order. Do\n not write code that relies on the order entries are used by this function\n as it may change in later versions of Gleam or Erlang.\n\n # Examples\n\n \n let dict = from_list([#(&quot;a&quot;, 1), #(&quot;b&quot;, 3), #(&quot;c&quot;, 9)])\n fold(dict, 0, fn(accumulator, key, value) { accumulator + value })\n // -&gt; 13\n \n\n \n import gleam/string\n\n let dict = from_list([#(&quot;a&quot;, 1), #(&quot;b&quot;, 3), #(&quot;c&quot;, 9)])\n fold(dict, &quot;&quot;, fn(accumulator, key, value) {\n   string.append(accumulator, key)\n })\n // -&gt; &quot;abc&quot;\n \n\nSynonyms:\ngleam/dict.fold\ngleam/dict fold","url":"gleam/dict.html#fold"},{"doc":"gleam/dict","title":"from_list","content":"pub fn from_list(list: List(#(a, b))) -&gt; Dict(a, b)\n Converts a list of 2-element tuples `#(key, value)` to a dict.\n\n If two tuples have the same key the last one in the list will be the one\n that is present in the dict.\n\nSynonyms:\ngleam/dict.from_list\ngleam/dict from_list","url":"gleam/dict.html#from_list"},{"doc":"gleam/dict","title":"get","content":"pub fn get(from: Dict(a, b), get: a) -&gt; Result(b, Nil)\n Fetches a value from a dict for a given key.\n\n The dict may not have a value for the key, so the value is wrapped in a\n `Result`.\n\n ## Examples\n\n \n new() |&gt; insert(&quot;a&quot;, 0) |&gt; get(&quot;a&quot;)\n // -&gt; Ok(0)\n \n\n \n new() |&gt; insert(&quot;a&quot;, 0) |&gt; get(&quot;b&quot;)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/dict.get\ngleam/dict get","url":"gleam/dict.html#get"},{"doc":"gleam/dict","title":"has_key","content":"pub fn has_key(dict: Dict(a, b), key: a) -&gt; Bool\n Determines whether or not a value present in the dict for a given key.\n\n ## Examples\n\n \n new() |&gt; insert(&quot;a&quot;, 0) |&gt; has_key(&quot;a&quot;)\n // -&gt; True\n \n\n \n new() |&gt; insert(&quot;a&quot;, 0) |&gt; has_key(&quot;b&quot;)\n // -&gt; False\n \n\nSynonyms:\ngleam/dict.has_key\ngleam/dict has_key","url":"gleam/dict.html#has_key"},{"doc":"gleam/dict","title":"insert","content":"pub fn insert(\n  into dict: Dict(a, b),\n  for key: a,\n  insert value: b,\n) -&gt; Dict(a, b)\n Inserts a value into the dict with the given key.\n\n If the dict already has a value for the given key then the value is\n replaced with the new value.\n\n ## Examples\n\n \n new() |&gt; insert(&quot;a&quot;, 0)\n // -&gt; from_list([#(&quot;a&quot;, 0)])\n \n\n \n new() |&gt; insert(&quot;a&quot;, 0) |&gt; insert(&quot;a&quot;, 5)\n // -&gt; from_list([#(&quot;a&quot;, 5)])\n \n\nSynonyms:\ngleam/dict.insert\ngleam/dict insert","url":"gleam/dict.html#insert"},{"doc":"gleam/dict","title":"is_empty","content":"pub fn is_empty(dict: Dict(a, b)) -&gt; Bool\n Determines whether or not the dict is empty.\n\n ## Examples\n\n \n new() |&gt; is_empty\n // -&gt; True\n \n\n \n new() |&gt; insert(&quot;b&quot;, 1) |&gt; is_empty\n // -&gt; False\n \n\nSynonyms:\ngleam/dict.is_empty\ngleam/dict is_empty","url":"gleam/dict.html#is_empty"},{"doc":"gleam/dict","title":"keys","content":"pub fn keys(dict: Dict(a, b)) -&gt; List(a)\n Gets a list of all keys in a given dict.\n\n Dicts are not ordered so the keys are not returned in any specific order. Do\n not write code that relies on the order keys are returned by this function\n as it may change in later versions of Gleam or Erlang.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]) |&gt; keys\n // -&gt; [&quot;a&quot;, &quot;b&quot;]\n \n\nSynonyms:\ngleam/dict.keys\ngleam/dict keys","url":"gleam/dict.html#keys"},{"doc":"gleam/dict","title":"map_values","content":"pub fn map_values(\n  in dict: Dict(a, b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; Dict(a, c)\n Updates all values in a given dict by calling a given function on each key\n and value.\n\n ## Examples\n\n \n from_list([#(3, 3), #(2, 4)])\n |&gt; map_values(fn(key, value) { key * value })\n // -&gt; from_list([#(3, 9), #(2, 8)])\n \n\nSynonyms:\ngleam/dict.map_values\ngleam/dict map_values","url":"gleam/dict.html#map_values"},{"doc":"gleam/dict","title":"merge","content":"pub fn merge(\n  into dict: Dict(a, b),\n  from new_entries: Dict(a, b),\n) -&gt; Dict(a, b)\n Creates a new dict from a pair of given dicts by combining their entries.\n\n If there are entries with the same keys in both dicts the entry from the\n second dict takes precedence.\n\n ## Examples\n\n \n let a = from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n let b = from_list([#(&quot;b&quot;, 2), #(&quot;c&quot;, 3)])\n merge(a, b)\n // -&gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 2), #(&quot;c&quot;, 3)])\n \n\nSynonyms:\ngleam/dict.merge\ngleam/dict merge","url":"gleam/dict.html#merge"},{"doc":"gleam/dict","title":"new","content":"pub fn new() -&gt; Dict(a, b)\n Creates a fresh dict that contains no values.\n\nSynonyms:\ngleam/dict.new\ngleam/dict new","url":"gleam/dict.html#new"},{"doc":"gleam/dict","title":"size","content":"pub fn size(dict: Dict(a, b)) -&gt; Int\n Determines the number of key-value pairs in the dict.\n This function runs in constant time and does not need to iterate the dict.\n\n ## Examples\n\n \n new() |&gt; size\n // -&gt; 0\n \n\n \n new() |&gt; insert(&quot;key&quot;, &quot;value&quot;) |&gt; size\n // -&gt; 1\n \n\nSynonyms:\ngleam/dict.size\ngleam/dict size","url":"gleam/dict.html#size"},{"doc":"gleam/dict","title":"take","content":"pub fn take(\n  from dict: Dict(a, b),\n  keeping desired_keys: List(a),\n) -&gt; Dict(a, b)\n Creates a new dict from a given dict, only including any entries for which the\n keys are in a given list.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n |&gt; take([&quot;b&quot;])\n // -&gt; from_list([#(&quot;b&quot;, 1)])\n \n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n |&gt; take([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)])\n \n\nSynonyms:\ngleam/dict.take\ngleam/dict take","url":"gleam/dict.html#take"},{"doc":"gleam/dict","title":"to_list","content":"pub fn to_list(dict: Dict(a, b)) -&gt; List(#(a, b))\n Converts the dict to a list of 2-element tuples `#(key, value)`, one for\n each key-value pair in the dict.\n\n The tuples in the list have no specific order.\n\n ## Examples\n\n Calling `to_list` on an empty `dict` returns an empty list.\n\n \n new() |&gt; to_list\n // -&gt; []\n \n\n The ordering of elements in the resulting list is an implementation detail\n that should not be relied upon.\n\n \n new() |&gt; insert(&quot;b&quot;, 1) |&gt; insert(&quot;a&quot;, 0) |&gt; insert(&quot;c&quot;, 2) |&gt; to_list\n // -&gt; [#(&quot;a&quot;, 0), #(&quot;b&quot;, 1), #(&quot;c&quot;, 2)]\n \n\nSynonyms:\ngleam/dict.to_list\ngleam/dict to_list","url":"gleam/dict.html#to_list"},{"doc":"gleam/dict","title":"upsert","content":"pub fn upsert(\n  in dict: Dict(a, b),\n  update key: a,\n  with fun: fn(Option(b)) -&gt; b,\n) -&gt; Dict(a, b)\n Creates a new dict with one entry inserted or updated using a given function.\n\n If there was not an entry in the dict for the given key then the function\n gets `None` as its argument, otherwise it gets `Some(value)`.\n\n ## Example\n\n \n let dict = from_list([#(&quot;a&quot;, 0)])\n let increment = fn(x) {\n   case x {\n     Some(i) -&gt; i + 1\n     None -&gt; 0\n   }\n }\n\n upsert(dict, &quot;a&quot;, increment)\n // -&gt; from_list([#(&quot;a&quot;, 1)])\n\n upsert(dict, &quot;b&quot;, increment)\n // -&gt; from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 0)])\n \n\nSynonyms:\ngleam/dict.upsert\ngleam/dict upsert","url":"gleam/dict.html#upsert"},{"doc":"gleam/dict","title":"values","content":"pub fn values(dict: Dict(a, b)) -&gt; List(b)\n Gets a list of all values in a given dict.\n\n Dicts are not ordered so the values are not returned in any specific order. Do\n not write code that relies on the order values are returned by this function\n as it may change in later versions of Gleam or Erlang.\n\n ## Examples\n\n \n from_list([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)]) |&gt; values\n // -&gt; [0, 1]\n \n\nSynonyms:\ngleam/dict.values\ngleam/dict values","url":"gleam/dict.html#values"},{"doc":"gleam/dict","title":"gleam/dict","content":"","url":"gleam/dict.html"},{"doc":"gleam/pair","title":"first","content":"pub fn first(pair: #(a, b)) -&gt; a\n Returns the first element in a pair.\n\n ## Examples\n\n \n first(#(1, 2))\n // -&gt; 1\n \n\nSynonyms:\ngleam/pair.first\ngleam/pair first","url":"gleam/pair.html#first"},{"doc":"gleam/pair","title":"map_first","content":"pub fn map_first(\n  of pair: #(a, b),\n  with fun: fn(a) -&gt; c,\n) -&gt; #(c, b)\n Returns a new pair with the first element having had `with` applied to\n it.\n\n ## Examples\n\n \n #(1, 2) |&gt; map_first(fn(n) { n * 2 })\n // -&gt; #(2, 2)\n \n\nSynonyms:\ngleam/pair.map_first\ngleam/pair map_first","url":"gleam/pair.html#map_first"},{"doc":"gleam/pair","title":"map_second","content":"pub fn map_second(\n  of pair: #(a, b),\n  with fun: fn(b) -&gt; c,\n) -&gt; #(a, c)\n Returns a new pair with the second element having had `with` applied to\n it.\n\n ## Examples\n\n \n #(1, 2) |&gt; map_second(fn(n) { n * 2 })\n // -&gt; #(1, 4)\n \n\nSynonyms:\ngleam/pair.map_second\ngleam/pair map_second","url":"gleam/pair.html#map_second"},{"doc":"gleam/pair","title":"new","content":"pub fn new(first: a, second: b) -&gt; #(a, b)\n Returns a new pair with the given elements. This can also be done using the dedicated\n syntax instead: `new(1, 2) == #(1, 2)`.\n\n ## Examples\n\n \n new(1, 2)\n // -&gt; #(1, 2)\n \n\nSynonyms:\ngleam/pair.new\ngleam/pair new","url":"gleam/pair.html#new"},{"doc":"gleam/pair","title":"second","content":"pub fn second(pair: #(a, b)) -&gt; b\n Returns the second element in a pair.\n\n ## Examples\n\n \n second(#(1, 2))\n // -&gt; 2\n \n\nSynonyms:\ngleam/pair.second\ngleam/pair second","url":"gleam/pair.html#second"},{"doc":"gleam/pair","title":"swap","content":"pub fn swap(pair: #(a, b)) -&gt; #(b, a)\n Returns a new pair with the elements swapped.\n\n ## Examples\n\n \n swap(#(1, 2))\n // -&gt; #(2, 1)\n \n\nSynonyms:\ngleam/pair.swap\ngleam/pair swap","url":"gleam/pair.html#swap"},{"doc":"gleam/pair","title":"gleam/pair","content":"","url":"gleam/pair.html"},{"doc":"gleam/list","title":"ContinueOrStop","content":"pub type ContinueOrStop(a) {\n  Continue(a)\n  Stop(a)\n}\n\nContinue(a)\n\n\nStop(a)\n\n\nSynonyms:\ngleam/list.ContinueOrStop\ngleam/list ContinueOrStop","url":"gleam/list.html#ContinueOrStop"},{"doc":"gleam/list","title":"all","content":"pub fn all(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if the given function returns `True` for all the elements in\n the given list. If the function returns `False` for any of the elements it\n immediately returns `False` without checking the rest of the list.\n\n ## Examples\n\n \n all([], fn(x) { x &gt; 3 })\n // -&gt; True\n \n\n \n all([4, 5], fn(x) { x &gt; 3 })\n // -&gt; True\n \n\n \n all([4, 3], fn(x) { x &gt; 3 })\n // -&gt; False\n \n\nSynonyms:\ngleam/list.all\ngleam/list all","url":"gleam/list.html#all"},{"doc":"gleam/list","title":"any","content":"pub fn any(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; Bool\n Returns `True` if the given function returns `True` for any the elements in\n the given list. If the function returns `True` for any of the elements it\n immediately returns `True` without checking the rest of the list.\n\n ## Examples\n\n \n any([], fn(x) { x &gt; 3 })\n // -&gt; False\n \n\n \n any([4, 5], fn(x) { x &gt; 3 })\n // -&gt; True\n \n\n \n any([4, 3], fn(x) { x &gt; 4 })\n // -&gt; False\n \n\n \n any([3, 4], fn(x) { x &gt; 3 })\n // -&gt; True\n \n\nSynonyms:\ngleam/list.any\ngleam/list any","url":"gleam/list.html#any"},{"doc":"gleam/list","title":"append","content":"pub fn append(first: List(a), second: List(a)) -&gt; List(a)\n Joins one list onto the end of another.\n\n This function runs in linear time, and it traverses and copies the first\n list.\n\n ## Examples\n\n \n append([1, 2], [3])\n // -&gt; [1, 2, 3]\n \n\nSynonyms:\ngleam/list.append\ngleam/list append","url":"gleam/list.html#append"},{"doc":"gleam/list","title":"chunk","content":"pub fn chunk(in list: List(a), by f: fn(a) -&gt; b) -&gt; List(List(a))\n Returns a list of chunks in which\n the return value of calling `f` on each element is the same.\n\n ## Examples\n\n \n [1, 2, 2, 3, 4, 4, 6, 7, 7] |&gt; chunk(by: fn(n) { n % 2 })\n // -&gt; [[1], [2, 2], [3], [4, 4, 6], [7, 7]]\n \n\nSynonyms:\ngleam/list.chunk\ngleam/list chunk","url":"gleam/list.html#chunk"},{"doc":"gleam/list","title":"combination_pairs","content":"pub fn combination_pairs(items: List(a)) -&gt; List(#(a, a))\n Return unique pair combinations of elements in the list\n\n ## Examples\n\n \n combination_pairs([1, 2, 3])\n // -&gt; [#(1, 2), #(1, 3), #(2, 3)]\n \n\nSynonyms:\ngleam/list.combination_pairs\ngleam/list combination_pairs","url":"gleam/list.html#combination_pairs"},{"doc":"gleam/list","title":"combinations","content":"pub fn combinations(items: List(a), by n: Int) -&gt; List(List(a))\n Return unique combinations of elements in the list.\n\n ## Examples\n\n \n combinations([1, 2, 3], 2)\n // -&gt; [[1, 2], [1, 3], [2, 3]]\n \n\n \n combinations([1, 2, 3, 4], 3)\n // -&gt; [[1, 2, 3], [1, 2, 4], [1, 3, 4], [2, 3, 4]]\n \n\nSynonyms:\ngleam/list.combinations\ngleam/list combinations","url":"gleam/list.html#combinations"},{"doc":"gleam/list","title":"contains","content":"pub fn contains(list: List(a), any elem: a) -&gt; Bool\n Determines whether or not a given element exists within a given list.\n\n This function traverses the list to find the element, so it runs in linear\n time.\n\n ## Examples\n\n \n [] |&gt; contains(any: 0)\n // -&gt; False\n \n\n \n [0] |&gt; contains(any: 0)\n // -&gt; True\n \n\n \n [1] |&gt; contains(any: 0)\n // -&gt; False\n \n\n \n [1, 1] |&gt; contains(any: 0)\n // -&gt; False\n \n\n \n [1, 0] |&gt; contains(any: 0)\n // -&gt; True\n \n\nSynonyms:\ngleam/list.contains\ngleam/list contains","url":"gleam/list.html#contains"},{"doc":"gleam/list","title":"count","content":"pub fn count(\n  list: List(a),\n  where predicate: fn(a) -&gt; Bool,\n) -&gt; Int\n Counts the number of elements in a given list satisfying a given predicate.\n\n This function has to traverse the list to determine the number of elements,\n so it runs in linear time.\n\n ## Examples\n\n \n count([], fn(a) { a &gt; 0 })\n // -&gt; 0\n \n\n \n count([1], fn(a) { a &gt; 0 })\n // -&gt; 1\n \n\n \n count([1, 2, 3], int.is_odd)\n // -&gt; 2\n \n\nSynonyms:\ngleam/list.count\ngleam/list count","url":"gleam/list.html#count"},{"doc":"gleam/list","title":"drop","content":"pub fn drop(from list: List(a), up_to n: Int) -&gt; List(a)\n Returns a list that is the given list with up to the given number of\n elements removed from the front of the list.\n\n If the element has less than the number of elements an empty list is\n returned.\n\n This function runs in linear time but does not copy the list.\n\n ## Examples\n\n \n drop([1, 2, 3, 4], 2)\n // -&gt; [3, 4]\n \n\n \n drop([1, 2, 3, 4], 9)\n // -&gt; []\n \n\nSynonyms:\ngleam/list.drop\ngleam/list drop","url":"gleam/list.html#drop"},{"doc":"gleam/list","title":"drop_while","content":"pub fn drop_while(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; List(a)\n Drops the first elements in a given list for which the predicate function returns `True`.\n\n ## Examples\n\n \n drop_while([1, 2, 3, 4], fn (x) { x &lt; 3 })\n // -&gt; [3, 4]\n \n\nSynonyms:\ngleam/list.drop_while\ngleam/list drop_while","url":"gleam/list.html#drop_while"},{"doc":"gleam/list","title":"each","content":"pub fn each(list: List(a), f: fn(a) -&gt; b) -&gt; Nil\n Calls a function for each element in a list, discarding the return value.\n\n Useful for calling a side effect for every item of a list.\n\n \n import gleam/io\n\n each([&quot;1&quot;, &quot;2&quot;, &quot;3&quot;], io.println)\n // -&gt; Nil\n // 1\n // 2\n // 3\n \n\nSynonyms:\ngleam/list.each\ngleam/list each","url":"gleam/list.html#each"},{"doc":"gleam/list","title":"filter","content":"pub fn filter(\n  list: List(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; List(a)\n Returns a new list containing only the elements from the first list for\n which the given functions returns `True`.\n\n ## Examples\n\n \n filter([2, 4, 6, 1], fn(x) { x &gt; 2 })\n // -&gt; [4, 6]\n \n\n \n filter([2, 4, 6, 1], fn(x) { x &gt; 6 })\n // -&gt; []\n \n\nSynonyms:\ngleam/list.filter\ngleam/list filter","url":"gleam/list.html#filter"},{"doc":"gleam/list","title":"filter_map","content":"pub fn filter_map(\n  list: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; List(b)\n Returns a new list containing only the elements from the first list for\n which the given functions returns `Ok(_)`.\n\n ## Examples\n\n \n filter_map([2, 4, 6, 1], Error)\n // -&gt; []\n \n\n \n filter_map([2, 4, 6, 1], fn(x) { Ok(x + 1) })\n // -&gt; [3, 5, 7, 2]\n \n\nSynonyms:\ngleam/list.filter_map\ngleam/list filter_map","url":"gleam/list.html#filter_map"},{"doc":"gleam/list","title":"find","content":"pub fn find(\n  in list: List(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(a, Nil)\n Finds the first element in a given list for which the given function returns\n `True`.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n find([1, 2, 3], fn(x) { x &gt; 2 })\n // -&gt; Ok(3)\n \n\n \n find([1, 2, 3], fn(x) { x &gt; 4 })\n // -&gt; Error(Nil)\n \n\n \n find([], fn(_) { True })\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.find\ngleam/list find","url":"gleam/list.html#find"},{"doc":"gleam/list","title":"find_map","content":"pub fn find_map(\n  in list: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Result(b, Nil)\n Finds the first element in a given list for which the given function returns\n `Ok(new_value)`, then returns the wrapped `new_value`.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n find_map([[], [2], [3]], first)\n // -&gt; Ok(2)\n \n\n \n find_map([[], []], first)\n // -&gt; Error(Nil)\n \n\n \n find_map([], first)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.find_map\ngleam/list find_map","url":"gleam/list.html#find_map"},{"doc":"gleam/list","title":"first","content":"pub fn first(list: List(a)) -&gt; Result(a, Nil)\n Gets the first element from the start of the list, if there is one.\n\n ## Examples\n\n \n first([])\n // -&gt; Error(Nil)\n \n\n \n first([0])\n // -&gt; Ok(0)\n \n\n \n first([1, 2])\n // -&gt; Ok(1)\n \n\nSynonyms:\ngleam/list.first\ngleam/list first","url":"gleam/list.html#first"},{"doc":"gleam/list","title":"flat_map","content":"pub fn flat_map(\n  over list: List(a),\n  with fun: fn(a) -&gt; List(b),\n) -&gt; List(b)\n Maps the list with the given function into a list of lists, and then flattens it.\n\n ## Examples\n\n \n flat_map([2, 4, 6], fn(x) { [x, x + 1] })\n // -&gt; [2, 3, 4, 5, 6, 7]\n \n\nSynonyms:\ngleam/list.flat_map\ngleam/list flat_map","url":"gleam/list.html#flat_map"},{"doc":"gleam/list","title":"flatten","content":"pub fn flatten(lists: List(List(a))) -&gt; List(a)\n This is the same as `concat`: it joins a list of lists into a single\n list.\n\n This function traverses all elements twice.\n\n ## Examples\n\n \n flatten([[1], [2, 3], []])\n // -&gt; [1, 2, 3]\n \n\nSynonyms:\ngleam/list.flatten\ngleam/list flatten","url":"gleam/list.html#flatten"},{"doc":"gleam/list","title":"fold","content":"pub fn fold(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from left to right.\n\n `fold([1, 2, 3], 0, add)` is the equivalent of\n `add(add(add(0, 1), 2), 3)`.\n\n This function runs in linear time.\n\nSynonyms:\ngleam/list.fold\ngleam/list fold","url":"gleam/list.html#fold"},{"doc":"gleam/list","title":"fold_right","content":"pub fn fold_right(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; b\n Reduces a list of elements into a single value by calling a given function\n on each element, going from right to left.\n\n `fold_right([1, 2, 3], 0, add)` is the equivalent of\n `add(add(add(0, 3), 2), 1)`.\n\n This function runs in linear time.\n\n Unlike `fold` this function is not tail recursive. Where possible use\n `fold` instead as it will use less memory.\n\nSynonyms:\ngleam/list.fold_right\ngleam/list fold_right","url":"gleam/list.html#fold_right"},{"doc":"gleam/list","title":"fold_until","content":"pub fn fold_until(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; ContinueOrStop(b),\n) -&gt; b\n A variant of fold that allows to stop folding earlier.\n\n The folding function should return `ContinueOrStop(accumulator)`.\n If the returned value is `Continue(accumulator)` fold_until will try the next value in the list.\n If the returned value is `Stop(accumulator)` fold_until will stop and return that accumulator.\n\n ## Examples\n\n \n [1, 2, 3, 4]\n |&gt; fold_until(0, fn(acc, i) {\n   case i &lt; 3 {\n     True -&gt; Continue(acc + i)\n     False -&gt; Stop(acc)\n   }\n })\n // -&gt; 3\n \n\nSynonyms:\ngleam/list.fold_until\ngleam/list fold_until","url":"gleam/list.html#fold_until"},{"doc":"gleam/list","title":"group","content":"pub fn group(\n  list: List(a),\n  by key: fn(a) -&gt; b,\n) -&gt; Dict(b, List(a))\n Groups the elements from the given list by the given key function.\n\n Does not preserve the initial value order.\n\n ## Examples\n\n \n import gleam/dict\n\n [Ok(3), Error(&quot;Wrong&quot;), Ok(200), Ok(73)]\n |&gt; group(by: fn(i) {\n   case i {\n     Ok(_) -&gt; &quot;Successful&quot;\n     Error(_) -&gt; &quot;Failed&quot;\n   }\n })\n |&gt; dict.to_list\n // -&gt; [\n //   #(&quot;Failed&quot;, [Error(&quot;Wrong&quot;)]),\n //   #(&quot;Successful&quot;, [Ok(73), Ok(200), Ok(3)])\n // ]\n \n\n \n import gleam/dict\n\n group([1,2,3,4,5], by: fn(i) { i - i / 3 * 3 })\n |&gt; dict.to_list\n // -&gt; [#(0, [3]), #(1, [4, 1]), #(2, [5, 2])]\n \n\nSynonyms:\ngleam/list.group\ngleam/list group","url":"gleam/list.html#group"},{"doc":"gleam/list","title":"index_fold","content":"pub fn index_fold(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a, Int) -&gt; b,\n) -&gt; b\n Like fold but the folding function also receives the index of the current element.\n\n ## Examples\n\n \n [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]\n |&gt; index_fold([], fn(acc, item, index) { ... })\n \n\nSynonyms:\ngleam/list.index_fold\ngleam/list index_fold","url":"gleam/list.html#index_fold"},{"doc":"gleam/list","title":"index_map","content":"pub fn index_map(\n  list: List(a),\n  with fun: fn(a, Int) -&gt; b,\n) -&gt; List(b)\n Returns a new list containing only the elements of the first list after the\n function has been applied to each one and their index.\n\n The index starts at 0, so the first element is 0, the second is 1, and so\n on.\n\n ## Examples\n\n \n index_map([&quot;a&quot;, &quot;b&quot;], fn(x, i) { #(i, x) })\n // -&gt; [#(0, &quot;a&quot;), #(1, &quot;b&quot;)]\n \n\nSynonyms:\ngleam/list.index_map\ngleam/list index_map","url":"gleam/list.html#index_map"},{"doc":"gleam/list","title":"interleave","content":"pub fn interleave(list: List(List(a))) -&gt; List(a)\n Make a list alternating the elements from the given lists\n\n ## Examples\n\n \n interleave([[1, 2], [101, 102], [201, 202]])\n // -&gt; [1, 101, 201, 2, 102, 202]\n \n\nSynonyms:\ngleam/list.interleave\ngleam/list interleave","url":"gleam/list.html#interleave"},{"doc":"gleam/list","title":"intersperse","content":"pub fn intersperse(list: List(a), with elem: a) -&gt; List(a)\n Inserts a given value between each existing element in a given list.\n\n This function runs in linear time and copies the list.\n\n ## Examples\n\n \n intersperse([1, 1, 1], 2)\n // -&gt; [1, 2, 1, 2, 1]\n \n\n \n intersperse([], 2)\n // -&gt; []\n \n\nSynonyms:\ngleam/list.intersperse\ngleam/list intersperse","url":"gleam/list.html#intersperse"},{"doc":"gleam/list","title":"is_empty","content":"pub fn is_empty(list: List(a)) -&gt; Bool\n Determines whether or not the list is empty.\n\n This function runs in constant time.\n\n ## Examples\n\n \n is_empty([])\n // -&gt; True\n \n\n \n is_empty([1])\n // -&gt; False\n \n\n \n is_empty([1, 1])\n // -&gt; False\n \n\nSynonyms:\ngleam/list.is_empty\ngleam/list is_empty","url":"gleam/list.html#is_empty"},{"doc":"gleam/list","title":"key_filter","content":"pub fn key_filter(\n  in keyword_list: List(#(a, b)),\n  find desired_key: a,\n) -&gt; List(b)\n Given a list of 2-element tuples, finds all tuples that have a given\n key as the first element and returns the second element.\n\n This function may be useful for interacting with Erlang code where lists of\n tuples are common.\n\n ## Examples\n\n \n key_filter([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1), #(&quot;a&quot;, 2)], &quot;a&quot;)\n // -&gt; [0, 2]\n \n\n \n key_filter([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;c&quot;)\n // -&gt; []\n \n\nSynonyms:\ngleam/list.key_filter\ngleam/list key_filter","url":"gleam/list.html#key_filter"},{"doc":"gleam/list","title":"key_find","content":"pub fn key_find(\n  in keyword_list: List(#(a, b)),\n  find desired_key: a,\n) -&gt; Result(b, Nil)\n Given a list of 2-element tuples, finds the first tuple that has a given\n key as the first element and returns the second element.\n\n If no tuple is found with the given key then `Error(Nil)` is returned.\n\n This function may be useful for interacting with Erlang code where lists of\n tuples are common.\n\n ## Examples\n\n \n key_find([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;a&quot;)\n // -&gt; Ok(0)\n \n\n \n key_find([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;b&quot;)\n // -&gt; Ok(1)\n \n\n \n key_find([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;c&quot;)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.key_find\ngleam/list key_find","url":"gleam/list.html#key_find"},{"doc":"gleam/list","title":"key_pop","content":"pub fn key_pop(\n  list: List(#(a, b)),\n  key: a,\n) -&gt; Result(#(b, List(#(a, b))), Nil)\n Given a list of 2-element tuples, finds the first tuple that has a given\n key as the first element. This function will return the second element\n of the found tuple and list with tuple removed.\n\n If no tuple is found with the given key then `Error(Nil)` is returned.\n\n ## Examples\n\n \n key_pop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;a&quot;)\n // -&gt; Ok(#(0, [#(&quot;b&quot;, 1)]))\n \n\n \n key_pop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;b&quot;)\n // -&gt; Ok(#(1, [#(&quot;a&quot;, 0)]))\n \n\n \n key_pop([#(&quot;a&quot;, 0), #(&quot;b&quot;, 1)], &quot;c&quot;)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.key_pop\ngleam/list key_pop","url":"gleam/list.html#key_pop"},{"doc":"gleam/list","title":"key_set","content":"pub fn key_set(\n  list: List(#(a, b)),\n  key: a,\n  value: b,\n) -&gt; List(#(a, b))\n Given a list of 2-element tuples, inserts a key and value into the list.\n\n If there was already a tuple with the key then it is replaced, otherwise it\n is added to the end of the list.\n\n ## Examples\n\n \n key_set([#(5, 0), #(4, 1)], 4, 100)\n // -&gt; [#(5, 0), #(4, 100)]\n \n\n \n key_set([#(5, 0), #(4, 1)], 1, 100)\n // -&gt; [#(5, 0), #(4, 1), #(1, 100)]\n \n\nSynonyms:\ngleam/list.key_set\ngleam/list key_set","url":"gleam/list.html#key_set"},{"doc":"gleam/list","title":"last","content":"pub fn last(list: List(a)) -&gt; Result(a, Nil)\n Returns the last element in the given list.\n\n Returns `Error(Nil)` if the list is empty.\n\n This function runs in linear time.\n\n ## Examples\n\n \n last([])\n // -&gt; Error(Nil)\n \n\n \n last([1, 2, 3, 4, 5])\n // -&gt; Ok(5)\n \n\nSynonyms:\ngleam/list.last\ngleam/list last","url":"gleam/list.html#last"},{"doc":"gleam/list","title":"length","content":"pub fn length(of list: List(a)) -&gt; Int\n Counts the number of elements in a given list.\n\n This function has to traverse the list to determine the number of elements,\n so it runs in linear time.\n\n This function is natively implemented by the virtual machine and is highly\n optimised.\n\n ## Examples\n\n \n length([])\n // -&gt; 0\n \n\n \n length([1])\n // -&gt; 1\n \n\n \n length([1, 2])\n // -&gt; 2\n \n\nSynonyms:\ngleam/list.length\ngleam/list length","url":"gleam/list.html#length"},{"doc":"gleam/list","title":"map","content":"pub fn map(list: List(a), with fun: fn(a) -&gt; b) -&gt; List(b)\n Returns a new list containing only the elements of the first list after the\n function has been applied to each one.\n\n ## Examples\n\n \n map([2, 4, 6], fn(x) { x * 2 })\n // -&gt; [4, 8, 12]\n \n\nSynonyms:\ngleam/list.map\ngleam/list map","url":"gleam/list.html#map"},{"doc":"gleam/list","title":"map2","content":"pub fn map2(\n  list1: List(a),\n  list2: List(b),\n  with fun: fn(a, b) -&gt; c,\n) -&gt; List(c)\n Combines two lists into a single list using the given function.\n\n If a list is longer than the other the extra elements are dropped.\n\n ## Examples\n\n \n map2([1, 2, 3], [4, 5, 6], fn(x, y) { x + y })\n // -&gt; [5, 7, 9]\n \n\n \n map2([1, 2], [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;], fn(i, x) { #(i, x) })\n // -&gt; [#(1, &quot;a&quot;), #(2, &quot;b&quot;)]\n \n\nSynonyms:\ngleam/list.map2\ngleam/list map2","url":"gleam/list.html#map2"},{"doc":"gleam/list","title":"map_fold","content":"pub fn map_fold(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; #(b, c),\n) -&gt; #(b, List(c))\n Similar to `map` but also lets you pass around an accumulated value.\n\n ## Examples\n\n \n map_fold(\n   over: [1, 2, 3],\n   from: 100,\n   with: fn(memo, i) { #(memo + i, i * 2) }\n )\n // -&gt; #(106, [2, 4, 6])\n \n\nSynonyms:\ngleam/list.map_fold\ngleam/list map_fold","url":"gleam/list.html#map_fold"},{"doc":"gleam/list","title":"max","content":"pub fn max(\n  over list: List(a),\n  with compare: fn(a, a) -&gt; Order,\n) -&gt; Result(a, Nil)\n Takes a list and a comparator, and returns the maximum element in the list\n\n\n ## Example\n\n \n range(1, 10) |&gt; list.max(int.compare)\n // -&gt; Ok(10)\n \n\n \n [&quot;a&quot;, &quot;c&quot;, &quot;b&quot;] |&gt; list.max(string.compare)\n // -&gt; Ok(&quot;c&quot;)\n \nSynonyms:\ngleam/list.max\ngleam/list max","url":"gleam/list.html#max"},{"doc":"gleam/list","title":"new","content":"pub fn new() -&gt; List(a)\n Returns a new empty list.\n\n ## Examples\n\n \n new()\n // -&gt; []\n \n\nSynonyms:\ngleam/list.new\ngleam/list new","url":"gleam/list.html#new"},{"doc":"gleam/list","title":"partition","content":"pub fn partition(\n  list: List(a),\n  with categorise: fn(a) -&gt; Bool,\n) -&gt; #(List(a), List(a))\n Partitions a list into a tuple/pair of lists\n by a given categorisation function.\n\n ## Examples\n\n \n import gleam/int\n\n [1, 2, 3, 4, 5] |&gt; partition(int.is_odd)\n // -&gt; #([1, 3, 5], [2, 4])\n \n\nSynonyms:\ngleam/list.partition\ngleam/list partition","url":"gleam/list.html#partition"},{"doc":"gleam/list","title":"permutations","content":"pub fn permutations(list: List(a)) -&gt; List(List(a))\n Returns all the permutations of a list.\n\n ## Examples\n\n \n permutations([1, 2])\n // -&gt; [[1, 2], [2, 1]]\n \n\nSynonyms:\ngleam/list.permutations\ngleam/list permutations","url":"gleam/list.html#permutations"},{"doc":"gleam/list","title":"pop","content":"pub fn pop(\n  in list: List(a),\n  one_that is_desired: fn(a) -&gt; Bool,\n) -&gt; Result(#(a, List(a)), Nil)\n Removes the first element in a given list for which the predicate function returns `True`.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n pop([1, 2, 3], fn(x) { x &gt; 2 })\n // -&gt; Ok(#(3, [1, 2]))\n \n\n \n pop([1, 2, 3], fn(x) { x &gt; 4 })\n // -&gt; Error(Nil)\n \n\n \n pop([], fn(_) { True })\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.pop\ngleam/list pop","url":"gleam/list.html#pop"},{"doc":"gleam/list","title":"pop_map","content":"pub fn pop_map(\n  in haystack: List(a),\n  one_that is_desired: fn(a) -&gt; Result(b, c),\n) -&gt; Result(#(b, List(a)), Nil)\n Removes the first element in a given list for which the given function returns\n `Ok(new_value)`, then returns the wrapped `new_value` as well as list with the value removed.\n\n Returns `Error(Nil)` if no such element is found.\n\n ## Examples\n\n \n pop_map([[], [2], [3]], first)\n // -&gt; Ok(#(2, [[], [3]]))\n \n\n \n pop_map([[], []], first)\n // -&gt; Error(Nil)\n \n\n \n pop_map([], first)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.pop_map\ngleam/list pop_map","url":"gleam/list.html#pop_map"},{"doc":"gleam/list","title":"prepend","content":"pub fn prepend(to list: List(a), this item: a) -&gt; List(a)\n Prefixes an item to a list. This can also be done using the dedicated\n syntax instead\n\n \n let existing_list = [2, 3, 4]\n\n [1, ..existing_list]\n // -&gt; [1, 2, 3, 4]\n\n prepend(to: existing_list, this: 1)\n // -&gt; [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/list.prepend\ngleam/list prepend","url":"gleam/list.html#prepend"},{"doc":"gleam/list","title":"range","content":"pub fn range(from start: Int, to stop: Int) -&gt; List(Int)\n Creates a list of ints ranging from a given start and finish.\n\n ## Examples\n\n \n range(0, 0)\n // -&gt; [0]\n \n\n \n range(0, 5)\n // -&gt; [0, 1, 2, 3, 4, 5]\n \n\n \n range(1, -5)\n // -&gt; [1, 0, -1, -2, -3, -4, -5]\n \n\nSynonyms:\ngleam/list.range\ngleam/list range","url":"gleam/list.html#range"},{"doc":"gleam/list","title":"reduce","content":"pub fn reduce(\n  over list: List(a),\n  with fun: fn(a, a) -&gt; a,\n) -&gt; Result(a, Nil)\n This function acts similar to fold, but does not take an initial state.\n Instead, it starts from the first element in the list\n and combines it with each subsequent element in turn using the given\n function. The function is called as `fun(accumulator, current_element)`.\n\n Returns `Ok` to indicate a successful run, and `Error` if called on an\n empty list.\n\n ## Examples\n\n \n [] |&gt; reduce(fn(acc, x) { acc + x })\n // -&gt; Error(Nil)\n \n\n \n [1, 2, 3, 4, 5] |&gt; reduce(fn(acc, x) { acc + x })\n // -&gt; Ok(15)\n \n\nSynonyms:\ngleam/list.reduce\ngleam/list reduce","url":"gleam/list.html#reduce"},{"doc":"gleam/list","title":"repeat","content":"pub fn repeat(item a: a, times times: Int) -&gt; List(a)\n Builds a list of a given value a given number of times.\n\n ## Examples\n\n \n repeat(&quot;a&quot;, times: 0)\n // -&gt; []\n \n\n \n repeat(&quot;a&quot;, times: 5)\n // -&gt; [&quot;a&quot;, &quot;a&quot;, &quot;a&quot;, &quot;a&quot;, &quot;a&quot;]\n \n\nSynonyms:\ngleam/list.repeat\ngleam/list repeat","url":"gleam/list.html#repeat"},{"doc":"gleam/list","title":"rest","content":"pub fn rest(list: List(a)) -&gt; Result(List(a), Nil)\n Returns the list minus the first element. If the list is empty, `Error(Nil)` is\n returned.\n\n This function runs in constant time and does not make a copy of the list.\n\n ## Examples\n\n \n rest([])\n // -&gt; Error(Nil)\n \n\n \n rest([0])\n // -&gt; Ok([])\n \n\n \n rest([1, 2])\n // -&gt; Ok([2])\n \n\nSynonyms:\ngleam/list.rest\ngleam/list rest","url":"gleam/list.html#rest"},{"doc":"gleam/list","title":"reverse","content":"pub fn reverse(list: List(a)) -&gt; List(a)\n Creates a new list from a given list containing the same elements but in the\n opposite order.\n\n This function has to traverse the list to create the new reversed list, so\n it runs in linear time.\n\n This function is natively implemented by the virtual machine and is highly\n optimised.\n\n ## Examples\n\n \n reverse([])\n // -&gt; []\n \n\n \n reverse([1])\n // -&gt; [1]\n \n\n \n reverse([1, 2])\n // -&gt; [2, 1]\n \n\nSynonyms:\ngleam/list.reverse\ngleam/list reverse","url":"gleam/list.html#reverse"},{"doc":"gleam/list","title":"sample","content":"pub fn sample(list: List(a), k: Int) -&gt; List(a)\n Take a random sample of k elements from a list using reservoir sampling via\n Algo L. Returns an empty list if the sample size is less than or equal to 0.\n\n Order is not random, only selection is.\n\n ## Examples\n\n \n reservoir_sample([1, 2, 3, 4, 5], 3)\n // -&gt; [2, 4, 5]  // A random sample of 3 items\n \n\nSynonyms:\ngleam/list.sample\ngleam/list sample","url":"gleam/list.html#sample"},{"doc":"gleam/list","title":"scan","content":"pub fn scan(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; b,\n) -&gt; List(b)\n Similar to `fold`, but yields the state of the accumulator at each stage.\n\n ## Examples\n\n \n scan(over: [1, 2, 3], from: 100, with: fn(acc, i) { acc + i })\n // -&gt; [101, 103, 106]\n \n\nSynonyms:\ngleam/list.scan\ngleam/list scan","url":"gleam/list.html#scan"},{"doc":"gleam/list","title":"shuffle","content":"pub fn shuffle(list: List(a)) -&gt; List(a)\n Takes a list, randomly sorts all items and returns the shuffled list.\n\n This function uses `float.random` to decide the order of the elements.\n\n ## Example\n\n \n range(1, 10) |&gt; shuffle()\n // -&gt; [1, 6, 9, 10, 3, 8, 4, 2, 7, 5]\n \n\nSynonyms:\ngleam/list.shuffle\ngleam/list shuffle","url":"gleam/list.html#shuffle"},{"doc":"gleam/list","title":"sized_chunk","content":"pub fn sized_chunk(\n  in list: List(a),\n  into count: Int,\n) -&gt; List(List(a))\n Returns a list of chunks containing `count` elements each.\n\n If the last chunk does not have `count` elements, it is instead\n a partial chunk, with less than `count` elements.\n\n For any `count` less than 1 this function behaves as if it was set to 1.\n\n ## Examples\n\n \n [1, 2, 3, 4, 5, 6] |&gt; sized_chunk(into: 2)\n // -&gt; [[1, 2], [3, 4], [5, 6]]\n \n\n \n [1, 2, 3, 4, 5, 6, 7, 8] |&gt; sized_chunk(into: 3)\n // -&gt; [[1, 2, 3], [4, 5, 6], [7, 8]]\n \n\nSynonyms:\ngleam/list.sized_chunk\ngleam/list sized_chunk","url":"gleam/list.html#sized_chunk"},{"doc":"gleam/list","title":"sort","content":"pub fn sort(\n  list: List(a),\n  by compare: fn(a, a) -&gt; Order,\n) -&gt; List(a)\n Sorts from smallest to largest based upon the ordering specified by a given\n function.\n\n ## Examples\n\n \n import gleam/int\n\n sort([4, 3, 6, 5, 4, 1, 2], by: int.compare)\n // -&gt; [1, 2, 3, 4, 4, 5, 6]\n \n\nSynonyms:\ngleam/list.sort\ngleam/list sort","url":"gleam/list.html#sort"},{"doc":"gleam/list","title":"split","content":"pub fn split(\n  list list: List(a),\n  at index: Int,\n) -&gt; #(List(a), List(a))\n Splits a list in two before the given index.\n\n If the list is not long enough to have the given index the before list will\n be the input list, and the after list will be empty.\n\n ## Examples\n\n \n split([6, 7, 8, 9], 0)\n // -&gt; #([], [6, 7, 8, 9])\n \n\n \n split([6, 7, 8, 9], 2)\n // -&gt; #([6, 7], [8, 9])\n \n\n \n split([6, 7, 8, 9], 4)\n // -&gt; #([6, 7, 8, 9], [])\n \n\nSynonyms:\ngleam/list.split\ngleam/list split","url":"gleam/list.html#split"},{"doc":"gleam/list","title":"split_while","content":"pub fn split_while(\n  list list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; #(List(a), List(a))\n Splits a list in two before the first element that a given function returns\n `False` for.\n\n If the function returns `True` for all elements the first list will be the\n input list, and the second list will be empty.\n\n ## Examples\n\n \n split_while([1, 2, 3, 4, 5], fn(x) { x &lt;= 3 })\n // -&gt; #([1, 2, 3], [4, 5])\n \n\n \n split_while([1, 2, 3, 4, 5], fn(x) { x &lt;= 5 })\n // -&gt; #([1, 2, 3, 4, 5], [])\n \n\nSynonyms:\ngleam/list.split_while\ngleam/list split_while","url":"gleam/list.html#split_while"},{"doc":"gleam/list","title":"strict_zip","content":"pub fn strict_zip(\n  list: List(a),\n  with other: List(b),\n) -&gt; Result(List(#(a, b)), Nil)\n Takes two lists and returns a single list of 2-element tuples.\n\n If one of the lists is longer than the other, an `Error` is returned.\n\n ## Examples\n\n \n strict_zip([], [])\n // -&gt; Ok([])\n \n\n \n strict_zip([1, 2], [3])\n // -&gt; Error(Nil)\n \n\n \n strict_zip([1], [3, 4])\n // -&gt; Error(Nil)\n \n\n \n strict_zip([1, 2], [3, 4])\n // -&gt; Ok([#(1, 3), #(2, 4)])\n \n\nSynonyms:\ngleam/list.strict_zip\ngleam/list strict_zip","url":"gleam/list.html#strict_zip"},{"doc":"gleam/list","title":"take","content":"pub fn take(from list: List(a), up_to n: Int) -&gt; List(a)\n Returns a list containing the first given number of elements from the given\n list.\n\n If the element has less than the number of elements then the full list is\n returned.\n\n This function runs in linear time.\n\n ## Examples\n\n \n take([1, 2, 3, 4], 2)\n // -&gt; [1, 2]\n \n\n \n take([1, 2, 3, 4], 9)\n // -&gt; [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/list.take\ngleam/list take","url":"gleam/list.html#take"},{"doc":"gleam/list","title":"take_while","content":"pub fn take_while(\n  in list: List(a),\n  satisfying predicate: fn(a) -&gt; Bool,\n) -&gt; List(a)\n Takes the first elements in a given list for which the predicate function returns `True`.\n\n ## Examples\n\n \n take_while([1, 2, 3, 2, 4], fn (x) { x &lt; 3 })\n // -&gt; [1, 2]\n \n\nSynonyms:\ngleam/list.take_while\ngleam/list take_while","url":"gleam/list.html#take_while"},{"doc":"gleam/list","title":"transpose","content":"pub fn transpose(list_of_list: List(List(a))) -&gt; List(List(a))\n Transpose rows and columns of the list of lists.\n\n Notice: This function is not tail recursive,\n and thus may exceed stack size if called,\n with large lists (on target JavaScript).\n\n ## Examples\n\n \n transpose([[1, 2, 3], [101, 102, 103]])\n // -&gt; [[1, 101], [2, 102], [3, 103]]\n \n\nSynonyms:\ngleam/list.transpose\ngleam/list transpose","url":"gleam/list.html#transpose"},{"doc":"gleam/list","title":"try_each","content":"pub fn try_each(\n  over list: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Result(Nil, c)\n Calls a `Result` returning function for each element in a list, discarding\n the return value. If the function returns `Error` then the iteration is\n stopped and the error is returned.\n\n Useful for calling a side effect for every item of a list.\n\n ## Examples\n\n \n try_each(\n   over: [1, 2, 3],\n   with: function_that_might_fail,\n )\n // -&gt; Ok(Nil)\n \n\nSynonyms:\ngleam/list.try_each\ngleam/list try_each","url":"gleam/list.html#try_each"},{"doc":"gleam/list","title":"try_fold","content":"pub fn try_fold(\n  over list: List(a),\n  from initial: b,\n  with fun: fn(b, a) -&gt; Result(b, c),\n) -&gt; Result(b, c)\n A variant of fold that might fail.\n\n The folding function should return `Result(accumulator, error)`.\n If the returned value is `Ok(accumulator)` try_fold will try the next value in the list.\n If the returned value is `Error(error)` try_fold will stop and return that error.\n\n ## Examples\n\n \n [1, 2, 3, 4]\n |&gt; try_fold(0, fn(acc, i) {\n   case i &lt; 3 {\n     True -&gt; Ok(acc + i)\n     False -&gt; Error(Nil)\n   }\n })\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.try_fold\ngleam/list try_fold","url":"gleam/list.html#try_fold"},{"doc":"gleam/list","title":"try_map","content":"pub fn try_map(\n  over list: List(a),\n  with fun: fn(a) -&gt; Result(b, c),\n) -&gt; Result(List(b), c)\n Takes a function that returns a `Result` and applies it to each element in a\n given list in turn.\n\n If the function returns `Ok(new_value)` for all elements in the list then a\n list of the new values is returned.\n\n If the function returns `Error(reason)` for any of the elements then it is\n returned immediately. None of the elements in the list are processed after\n one returns an `Error`.\n\n ## Examples\n\n \n try_map([1, 2, 3], fn(x) { Ok(x + 2) })\n // -&gt; Ok([3, 4, 5])\n \n\n \n try_map([1, 2, 3], fn(_) { Error(0) })\n // -&gt; Error(0)\n \n\n \n try_map([[1], [2, 3]], first)\n // -&gt; Ok([1, 2])\n \n\n \n try_map([[1], [], [2]], first)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/list.try_map\ngleam/list try_map","url":"gleam/list.html#try_map"},{"doc":"gleam/list","title":"unique","content":"pub fn unique(list: List(a)) -&gt; List(a)\n Removes any duplicate elements from a given list.\n\n This function returns in loglinear time.\n\n ## Examples\n\n \n unique([1, 1, 1, 4, 7, 3, 3, 4])\n // -&gt; [1, 4, 7, 3]\n \n\nSynonyms:\ngleam/list.unique\ngleam/list unique","url":"gleam/list.html#unique"},{"doc":"gleam/list","title":"unzip","content":"pub fn unzip(input: List(#(a, b))) -&gt; #(List(a), List(b))\n Takes a single list of 2-element tuples and returns two lists.\n\n ## Examples\n\n \n unzip([#(1, 2), #(3, 4)])\n // -&gt; #([1, 3], [2, 4])\n \n\n \n unzip([])\n // -&gt; #([], [])\n \n\nSynonyms:\ngleam/list.unzip\ngleam/list unzip","url":"gleam/list.html#unzip"},{"doc":"gleam/list","title":"window","content":"pub fn window(list: List(a), by n: Int) -&gt; List(List(a))\n Returns a list of sliding windows.\n\n ## Examples\n\n \n window([1,2,3,4,5], 3)\n // -&gt; [[1, 2, 3], [2, 3, 4], [3, 4, 5]]\n \n\n \n window([1, 2], 4)\n // -&gt; []\n \n\nSynonyms:\ngleam/list.window\ngleam/list window","url":"gleam/list.html#window"},{"doc":"gleam/list","title":"window_by_2","content":"pub fn window_by_2(list: List(a)) -&gt; List(#(a, a))\n Returns a list of tuples containing two contiguous elements.\n\n ## Examples\n\n \n window_by_2([1,2,3,4])\n // -&gt; [#(1, 2), #(2, 3), #(3, 4)]\n \n\n \n window_by_2([1])\n // -&gt; []\n \n\nSynonyms:\ngleam/list.window_by_2\ngleam/list window_by_2","url":"gleam/list.html#window_by_2"},{"doc":"gleam/list","title":"wrap","content":"pub fn wrap(item: a) -&gt; List(a)\n Returns the given item wrapped in a list.\n\n ## Examples\n\n \n wrap(1)\n // -&gt; [1]\n\n wrap([&quot;a&quot;, &quot;b&quot;, &quot;c&quot;])\n // -&gt; [[&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]]\n\n wrap([[]])\n // -&gt; [[[]]]\n \n\n\nSynonyms:\ngleam/list.wrap\ngleam/list wrap","url":"gleam/list.html#wrap"},{"doc":"gleam/list","title":"zip","content":"pub fn zip(list: List(a), with other: List(b)) -&gt; List(#(a, b))\n Takes two lists and returns a single list of 2-element tuples.\n\n If one of the lists is longer than the other, the remaining elements from\n the longer list are not used.\n\n ## Examples\n\n \n zip([], [])\n // -&gt; []\n \n\n \n zip([1, 2], [3])\n // -&gt; [#(1, 3)]\n \n\n \n zip([1], [3, 4])\n // -&gt; [#(1, 3)]\n \n\n \n zip([1, 2], [3, 4])\n // -&gt; [#(1, 3), #(2, 4)]\n \n\nSynonyms:\ngleam/list.zip\ngleam/list zip","url":"gleam/list.html#zip"},{"doc":"gleam/list","title":"gleam/list","content":" Lists are an ordered sequence of elements and are one of the most common\n data types in Gleam.\n\n New elements can be added and removed from the front of a list in\n constant time, while adding and removing from the end requires traversing\n and copying the whole list, so keep this in mind when designing your\n programs.\n\n There is a dedicated syntax for prefixing to a list:\n\n ```gleam\n let new_list = [1, 2, ..existing_list]\n ```\n\n And a matching syntax for getting the first elements of a list:\n\n ```gleam\n case list {\n   [first_element, ..rest] -&gt; first_element\n   _ -&gt; &quot;this pattern matches when the list is empty&quot;\n }\n ```\n","url":"gleam/list.html"},{"doc":"gleam/string_tree","title":"StringTree","content":"pub type StringTree\n `StringTree` is a type used for efficiently building text content to be\n written to a file or a socket. Internally it is represented as tree so to\n append or prepend to a string tree is a constant time operation that\n allocates a new node in the tree without copying any of the content. When\n writing to an output stream the tree is traversed and the content is sent\n directly rather than copying it into a single buffer beforehand.\n\n On Erlang this type is compatible with Erlang&#39;s iodata. On JavaScript this\n type is compatible with normal strings.\n\n The BEAM virtual machine has an optimisation for appending strings, where it\n will mutate the string buffer when safe to do so, so if you are looking to\n build a string through appending many small strings then you may get better\n performance by not using a string tree. Always benchmark your performance\n sensitive code.\n\n\nSynonyms:\ngleam/string_tree.StringTree\ngleam/string_tree StringTree","url":"gleam/string_tree.html#StringTree"},{"doc":"gleam/string_tree","title":"append","content":"pub fn append(\n  to tree: StringTree,\n  suffix second: String,\n) -&gt; StringTree\n Appends a `String` onto the end of some `StringTree`.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_tree.append\ngleam/string_tree append","url":"gleam/string_tree.html#append"},{"doc":"gleam/string_tree","title":"append_tree","content":"pub fn append_tree(\n  to tree: StringTree,\n  suffix suffix: StringTree,\n) -&gt; StringTree\n Appends some `StringTree` onto the end of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_tree.append_tree\ngleam/string_tree append_tree","url":"gleam/string_tree.html#append_tree"},{"doc":"gleam/string_tree","title":"byte_size","content":"pub fn byte_size(tree: StringTree) -&gt; Int\n Returns the size of the `StringTree` in bytes.\n\nSynonyms:\ngleam/string_tree.byte_size\ngleam/string_tree byte_size","url":"gleam/string_tree.html#byte_size"},{"doc":"gleam/string_tree","title":"concat","content":"pub fn concat(trees: List(StringTree)) -&gt; StringTree\n Joins a list of trees into a single tree.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_tree.concat\ngleam/string_tree concat","url":"gleam/string_tree.html#concat"},{"doc":"gleam/string_tree","title":"from_string","content":"pub fn from_string(string: String) -&gt; StringTree\n Converts a string into a `StringTree`.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_tree.from_string\ngleam/string_tree from_string","url":"gleam/string_tree.html#from_string"},{"doc":"gleam/string_tree","title":"from_strings","content":"pub fn from_strings(strings: List(String)) -&gt; StringTree\n Converts a list of strings into a `StringTree`.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_tree.from_strings\ngleam/string_tree from_strings","url":"gleam/string_tree.html#from_strings"},{"doc":"gleam/string_tree","title":"is_empty","content":"pub fn is_empty(tree: StringTree) -&gt; Bool\n Inspects a `StringTree` to determine if it is equivalent to an empty string.\n\n ## Examples\n\n \n from_string(&quot;ok&quot;) |&gt; is_empty\n // -&gt; False\n \n\n \n from_string(&quot;&quot;) |&gt; is_empty\n // -&gt; True\n \n\n \n from_strings([]) |&gt; is_empty\n // -&gt; True\n \n\nSynonyms:\ngleam/string_tree.is_empty\ngleam/string_tree is_empty","url":"gleam/string_tree.html#is_empty"},{"doc":"gleam/string_tree","title":"is_equal","content":"pub fn is_equal(a: StringTree, b: StringTree) -&gt; Bool\n Compares two string trees to determine if they have the same textual\n content.\n\n Comparing two string trees using the `==` operator may return `False` even\n if they have the same content as they may have been build in different ways,\n so using this function is often preferred.\n\n ## Examples\n\n \n from_strings([&quot;a&quot;, &quot;b&quot;]) == from_string(&quot;ab&quot;)\n // -&gt; False\n \n\n \n is_equal(from_strings([&quot;a&quot;, &quot;b&quot;]), from_string(&quot;ab&quot;))\n // -&gt; True\n \n\nSynonyms:\ngleam/string_tree.is_equal\ngleam/string_tree is_equal","url":"gleam/string_tree.html#is_equal"},{"doc":"gleam/string_tree","title":"join","content":"pub fn join(\n  trees: List(StringTree),\n  with sep: String,\n) -&gt; StringTree\n Joins the given trees into a new tree separated with the given string.\n\nSynonyms:\ngleam/string_tree.join\ngleam/string_tree join","url":"gleam/string_tree.html#join"},{"doc":"gleam/string_tree","title":"lowercase","content":"pub fn lowercase(tree: StringTree) -&gt; StringTree\n Converts a `StringTree` to a new one where the contents have been\n lowercased.\n\nSynonyms:\ngleam/string_tree.lowercase\ngleam/string_tree lowercase","url":"gleam/string_tree.html#lowercase"},{"doc":"gleam/string_tree","title":"new","content":"pub fn new() -&gt; StringTree\n Create an empty `StringTree`. Useful as the start of a pipe chaining many\n trees together.\n\nSynonyms:\ngleam/string_tree.new\ngleam/string_tree new","url":"gleam/string_tree.html#new"},{"doc":"gleam/string_tree","title":"prepend","content":"pub fn prepend(\n  to tree: StringTree,\n  prefix prefix: String,\n) -&gt; StringTree\n Prepends a `String` onto the start of some `StringTree`.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_tree.prepend\ngleam/string_tree prepend","url":"gleam/string_tree.html#prepend"},{"doc":"gleam/string_tree","title":"prepend_tree","content":"pub fn prepend_tree(\n  to tree: StringTree,\n  prefix prefix: StringTree,\n) -&gt; StringTree\n Prepends some `StringTree` onto the start of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/string_tree.prepend_tree\ngleam/string_tree prepend_tree","url":"gleam/string_tree.html#prepend_tree"},{"doc":"gleam/string_tree","title":"replace","content":"pub fn replace(\n  in tree: StringTree,\n  each pattern: String,\n  with substitute: String,\n) -&gt; StringTree\n Replaces all instances of a pattern with a given string substitute.\n\nSynonyms:\ngleam/string_tree.replace\ngleam/string_tree replace","url":"gleam/string_tree.html#replace"},{"doc":"gleam/string_tree","title":"reverse","content":"pub fn reverse(tree: StringTree) -&gt; StringTree\n Converts a `StringTree` to a new one with the contents reversed.\n\nSynonyms:\ngleam/string_tree.reverse\ngleam/string_tree reverse","url":"gleam/string_tree.html#reverse"},{"doc":"gleam/string_tree","title":"split","content":"pub fn split(\n  tree: StringTree,\n  on pattern: String,\n) -&gt; List(StringTree)\n Splits a `StringTree` on a given pattern into a list of trees.\n\nSynonyms:\ngleam/string_tree.split\ngleam/string_tree split","url":"gleam/string_tree.html#split"},{"doc":"gleam/string_tree","title":"to_string","content":"pub fn to_string(tree: StringTree) -&gt; String\n Turns a `StringTree` into a `String`\n\n This function is implemented natively by the virtual machine and is highly\n optimised.\n\nSynonyms:\ngleam/string_tree.to_string\ngleam/string_tree to_string","url":"gleam/string_tree.html#to_string"},{"doc":"gleam/string_tree","title":"uppercase","content":"pub fn uppercase(tree: StringTree) -&gt; StringTree\n Converts a `StringTree` to a new one where the contents have been\n uppercased.\n\nSynonyms:\ngleam/string_tree.uppercase\ngleam/string_tree uppercase","url":"gleam/string_tree.html#uppercase"},{"doc":"gleam/string_tree","title":"gleam/string_tree","content":"","url":"gleam/string_tree.html"},{"doc":"gleam/string","title":"append","content":"pub fn append(to first: String, suffix second: String) -&gt; String\n Creates a new `String` by joining two `String`s together.\n\n This function copies both `String`s and runs in linear time. If you find\n yourself joining `String`s frequently consider using the [`string_tree`](../gleam/string_tree.html)\n module as it can append `String`s much faster!\n\n ## Examples\n\n \n append(to: &quot;butter&quot;, suffix: &quot;fly&quot;)\n // -&gt; &quot;butterfly&quot;\n \n\nSynonyms:\ngleam/string.append\ngleam/string append","url":"gleam/string.html#append"},{"doc":"gleam/string","title":"byte_size","content":"pub fn byte_size(string: String) -&gt; Int\n Returns the number of bytes in a `String`.\n\n This function runs in constant time on Erlang and in linear time on\n JavaScript.\n\n ## Examples\n\n \n byte_size(&quot;🏳️‍⚧️🏳️‍🌈👩🏾‍❤️‍👨🏻&quot;)\n // -&gt; 58\n \n\nSynonyms:\ngleam/string.byte_size\ngleam/string byte_size","url":"gleam/string.html#byte_size"},{"doc":"gleam/string","title":"capitalise","content":"pub fn capitalise(string: String) -&gt; String\n Creates a new `String` with the first grapheme in the input `String`\n converted to uppercase and the remaining graphemes to lowercase.\n\n ## Examples\n\n \n capitalise(&quot;mamouna&quot;)\n // -&gt; &quot;Mamouna&quot;\n \n\nSynonyms:\ngleam/string.capitalise\ngleam/string capitalise","url":"gleam/string.html#capitalise"},{"doc":"gleam/string","title":"compare","content":"pub fn compare(a: String, b: String) -&gt; Order\n Compares two `String`s to see which is &quot;larger&quot; by comparing their graphemes.\n\n This does not compare the size or length of the given `String`s.\n\n ## Examples\n\n \n compare(&quot;Anthony&quot;, &quot;Anthony&quot;)\n // -&gt; order.Eq\n \n\n \n compare(&quot;A&quot;, &quot;B&quot;)\n // -&gt; order.Lt\n \n\nSynonyms:\ngleam/string.compare\ngleam/string compare","url":"gleam/string.html#compare"},{"doc":"gleam/string","title":"concat","content":"pub fn concat(strings: List(String)) -&gt; String\n Creates a new `String` by joining many `String`s together.\n\n This function copies both `String`s and runs in linear time. If you find\n yourself joining `String`s frequently consider using the [`string_tree`](../gleam/string_tree.html)\n module as it can append `String`s much faster!\n\n ## Examples\n\n \n concat([&quot;never&quot;, &quot;the&quot;, &quot;less&quot;])\n // -&gt; &quot;nevertheless&quot;\n \n\nSynonyms:\ngleam/string.concat\ngleam/string concat","url":"gleam/string.html#concat"},{"doc":"gleam/string","title":"contains","content":"pub fn contains(\n  does haystack: String,\n  contain needle: String,\n) -&gt; Bool\n Checks if the first `String` contains the second.\n\n ## Examples\n\n \n contains(does: &quot;theory&quot;, contain: &quot;ory&quot;)\n // -&gt; True\n \n\n \n contains(does: &quot;theory&quot;, contain: &quot;the&quot;)\n // -&gt; True\n \n\n \n contains(does: &quot;theory&quot;, contain: &quot;THE&quot;)\n // -&gt; False\n \n\nSynonyms:\ngleam/string.contains\ngleam/string contains","url":"gleam/string.html#contains"},{"doc":"gleam/string","title":"crop","content":"pub fn crop(\n  from string: String,\n  before substring: String,\n) -&gt; String\n Drops contents of the first `String` that occur before the second `String`.\n If the `from` string does not contain the `before` string, `from` is returned unchanged.\n\n ## Examples\n\n \n crop(from: &quot;The Lone Gunmen&quot;, before: &quot;Lone&quot;)\n // -&gt; &quot;Lone Gunmen&quot;\n \n\nSynonyms:\ngleam/string.crop\ngleam/string crop","url":"gleam/string.html#crop"},{"doc":"gleam/string","title":"drop_end","content":"pub fn drop_end(\n  from string: String,\n  up_to num_graphemes: Int,\n) -&gt; String\n Drops *n* graphemes from the end of a `String`.\n\n ## Examples\n\n \n drop_end(from: &quot;Cigarette Smoking Man&quot;, up_to: 2)\n // -&gt; &quot;Cigarette Smoking M&quot;\n \n\nSynonyms:\ngleam/string.drop_end\ngleam/string drop_end","url":"gleam/string.html#drop_end"},{"doc":"gleam/string","title":"drop_start","content":"pub fn drop_start(\n  from string: String,\n  up_to num_graphemes: Int,\n) -&gt; String\n Drops *n* graphemes from the start of a `String`.\n\n ## Examples\n\n \n drop_start(from: &quot;The Lone Gunmen&quot;, up_to: 2)\n // -&gt; &quot;e Lone Gunmen&quot;\n \n\nSynonyms:\ngleam/string.drop_start\ngleam/string drop_start","url":"gleam/string.html#drop_start"},{"doc":"gleam/string","title":"ends_with","content":"pub fn ends_with(string: String, suffix: String) -&gt; Bool\n Checks whether the first `String` ends with the second one.\n\n ## Examples\n\n \n ends_with(&quot;theory&quot;, &quot;ory&quot;)\n // -&gt; True\n \n\nSynonyms:\ngleam/string.ends_with\ngleam/string ends_with","url":"gleam/string.html#ends_with"},{"doc":"gleam/string","title":"first","content":"pub fn first(string: String) -&gt; Result(String, Nil)\n Returns the first grapheme cluster in a given `String` and wraps it in a\n `Result(String, Nil)`. If the `String` is empty, it returns `Error(Nil)`.\n Otherwise, it returns `Ok(String)`.\n\n ## Examples\n\n \n first(&quot;&quot;)\n // -&gt; Error(Nil)\n \n\n \n first(&quot;icecream&quot;)\n // -&gt; Ok(&quot;i&quot;)\n \n\nSynonyms:\ngleam/string.first\ngleam/string first","url":"gleam/string.html#first"},{"doc":"gleam/string","title":"from_utf_codepoints","content":"pub fn from_utf_codepoints(\n  utf_codepoints: List(UtfCodepoint),\n) -&gt; String\n Converts a `List` of `UtfCodepoint`s to a `String`.\n\n See &lt;https://en.wikipedia.org/wiki/Code_point&gt; and\n &lt;https://en.wikipedia.org/wiki/Unicode#Codespace_and_Code_Points&gt; for an\n explanation on code points.\n\n ## Examples\n\n \n let assert Ok(a) = utf_codepoint(97)\n let assert Ok(b) = utf_codepoint(98)\n let assert Ok(c) = utf_codepoint(99)\n from_utf_codepoints([a, b, c])\n // -&gt; &quot;abc&quot;\n \n\nSynonyms:\ngleam/string.from_utf_codepoints\ngleam/string from_utf_codepoints","url":"gleam/string.html#from_utf_codepoints"},{"doc":"gleam/string","title":"inspect","content":"pub fn inspect(term: a) -&gt; String\n Returns a `String` representation of a term in Gleam syntax.\n\nSynonyms:\ngleam/string.inspect\ngleam/string inspect","url":"gleam/string.html#inspect"},{"doc":"gleam/string","title":"is_empty","content":"pub fn is_empty(str: String) -&gt; Bool\n Determines if a `String` is empty.\n\n ## Examples\n\n \n is_empty(&quot;&quot;)\n // -&gt; True\n \n\n \n is_empty(&quot;the world&quot;)\n // -&gt; False\n \n\nSynonyms:\ngleam/string.is_empty\ngleam/string is_empty","url":"gleam/string.html#is_empty"},{"doc":"gleam/string","title":"join","content":"pub fn join(\n  strings: List(String),\n  with separator: String,\n) -&gt; String\n Joins many `String`s together with a given separator.\n\n This function runs in linear time.\n\n ## Examples\n\n \n join([&quot;home&quot;,&quot;evan&quot;,&quot;Desktop&quot;], with: &quot;/&quot;)\n // -&gt; &quot;home/evan/Desktop&quot;\n \n\nSynonyms:\ngleam/string.join\ngleam/string join","url":"gleam/string.html#join"},{"doc":"gleam/string","title":"last","content":"pub fn last(string: String) -&gt; Result(String, Nil)\n Returns the last grapheme cluster in a given `String` and wraps it in a\n `Result(String, Nil)`. If the `String` is empty, it returns `Error(Nil)`.\n Otherwise, it returns `Ok(String)`.\n\n ## Examples\n\n \n last(&quot;&quot;)\n // -&gt; Error(Nil)\n \n\n \n last(&quot;icecream&quot;)\n // -&gt; Ok(&quot;m&quot;)\n \n\nSynonyms:\ngleam/string.last\ngleam/string last","url":"gleam/string.html#last"},{"doc":"gleam/string","title":"length","content":"pub fn length(string: String) -&gt; Int\n Gets the number of grapheme clusters in a given `String`.\n\n This function has to iterate across the whole string to count the number of\n graphemes, so it runs in linear time.\n\n ## Examples\n\n \n length(&quot;Gleam&quot;)\n // -&gt; 5\n \n\n \n length(&quot;ß↑e̊&quot;)\n // -&gt; 3\n \n\n \n length(&quot;&quot;)\n // -&gt; 0\n \n\nSynonyms:\ngleam/string.length\ngleam/string length","url":"gleam/string.html#length"},{"doc":"gleam/string","title":"lowercase","content":"pub fn lowercase(string: String) -&gt; String\n Creates a new `String` with all the graphemes in the input `String` converted to\n lowercase.\n\n Useful for case-insensitive comparisons.\n\n ## Examples\n\n \n lowercase(&quot;X-FILES&quot;)\n // -&gt; &quot;x-files&quot;\n \n\nSynonyms:\ngleam/string.lowercase\ngleam/string lowercase","url":"gleam/string.html#lowercase"},{"doc":"gleam/string","title":"pad_end","content":"pub fn pad_end(\n  string: String,\n  to desired_length: Int,\n  with pad_string: String,\n) -&gt; String\n Pads the end of a `String` until it has a given length.\n\n ## Examples\n\n \n pad_end(&quot;123&quot;, to: 5, with: &quot;.&quot;)\n // -&gt; &quot;123..&quot;\n \n\n \n pad_end(&quot;123&quot;, to: 3, with: &quot;.&quot;)\n // -&gt; &quot;123&quot;\n \n\n \n pad_end(&quot;123&quot;, to: 2, with: &quot;.&quot;)\n // -&gt; &quot;123&quot;\n \n\nSynonyms:\ngleam/string.pad_end\ngleam/string pad_end","url":"gleam/string.html#pad_end"},{"doc":"gleam/string","title":"pad_start","content":"pub fn pad_start(\n  string: String,\n  to desired_length: Int,\n  with pad_string: String,\n) -&gt; String\n Pads the start of a `String` until it has a given length.\n\n ## Examples\n\n \n pad_start(&quot;121&quot;, to: 5, with: &quot;.&quot;)\n // -&gt; &quot;..121&quot;\n \n\n \n pad_start(&quot;121&quot;, to: 3, with: &quot;.&quot;)\n // -&gt; &quot;121&quot;\n \n\n \n pad_start(&quot;121&quot;, to: 2, with: &quot;.&quot;)\n // -&gt; &quot;121&quot;\n \n\nSynonyms:\ngleam/string.pad_start\ngleam/string pad_start","url":"gleam/string.html#pad_start"},{"doc":"gleam/string","title":"pop_grapheme","content":"pub fn pop_grapheme(\n  string: String,\n) -&gt; Result(#(String, String), Nil)\n Splits a non-empty `String` into its first element (head) and rest (tail).\n This lets you pattern match on `String`s exactly as you would with lists.\n\n Note on JavaScript using the function to iterate over a string will likely\n be slower than using `to_graphemes` due to string slicing being more\n expensive on JavaScript than Erlang.\n\n ## Examples\n\n \n pop_grapheme(&quot;gleam&quot;)\n // -&gt; Ok(#(&quot;g&quot;, &quot;leam&quot;))\n \n\n \n pop_grapheme(&quot;&quot;)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/string.pop_grapheme\ngleam/string pop_grapheme","url":"gleam/string.html#pop_grapheme"},{"doc":"gleam/string","title":"repeat","content":"pub fn repeat(string: String, times times: Int) -&gt; String\n Creates a new `String` by repeating a `String` a given number of times.\n\n This function runs in linear time.\n\n ## Examples\n\n \n repeat(&quot;ha&quot;, times: 3)\n // -&gt; &quot;hahaha&quot;\n \n\nSynonyms:\ngleam/string.repeat\ngleam/string repeat","url":"gleam/string.html#repeat"},{"doc":"gleam/string","title":"replace","content":"pub fn replace(\n  in string: String,\n  each pattern: String,\n  with substitute: String,\n) -&gt; String\n Creates a new `String` by replacing all occurrences of a given substring.\n\n ## Examples\n\n \n replace(&quot;www.example.com&quot;, each: &quot;.&quot;, with: &quot;-&quot;)\n // -&gt; &quot;www-example-com&quot;\n \n\n \n replace(&quot;a,b,c,d,e&quot;, each: &quot;,&quot;, with: &quot;/&quot;)\n // -&gt; &quot;a/b/c/d/e&quot;\n \n\nSynonyms:\ngleam/string.replace\ngleam/string replace","url":"gleam/string.html#replace"},{"doc":"gleam/string","title":"reverse","content":"pub fn reverse(string: String) -&gt; String\n Reverses a `String`.\n\n This function has to iterate across the whole `String` so it runs in linear\n time.\n\n ## Examples\n\n \n reverse(&quot;stressed&quot;)\n // -&gt; &quot;desserts&quot;\n \n\nSynonyms:\ngleam/string.reverse\ngleam/string reverse","url":"gleam/string.html#reverse"},{"doc":"gleam/string","title":"slice","content":"pub fn slice(\n  from string: String,\n  at_index idx: Int,\n  length len: Int,\n) -&gt; String\n Takes a substring given a start grapheme index and a length. Negative indexes\n are taken starting from the *end* of the list.\n\n ## Examples\n\n \n slice(from: &quot;gleam&quot;, at_index: 1, length: 2)\n // -&gt; &quot;le&quot;\n \n\n \n slice(from: &quot;gleam&quot;, at_index: 1, length: 10)\n // -&gt; &quot;leam&quot;\n \n\n \n slice(from: &quot;gleam&quot;, at_index: 10, length: 3)\n // -&gt; &quot;&quot;\n \n\n \n slice(from: &quot;gleam&quot;, at_index: -2, length: 2)\n // -&gt; &quot;am&quot;\n \n\n \n slice(from: &quot;gleam&quot;, at_index: -12, length: 2)\n // -&gt; &quot;&quot;\n \n\nSynonyms:\ngleam/string.slice\ngleam/string slice","url":"gleam/string.html#slice"},{"doc":"gleam/string","title":"split","content":"pub fn split(x: String, on substring: String) -&gt; List(String)\n Creates a list of `String`s by splitting a given string on a given substring.\n\n ## Examples\n\n \n split(&quot;home/gleam/desktop/&quot;, on: &quot;/&quot;)\n // -&gt; [&quot;home&quot;, &quot;gleam&quot;, &quot;desktop&quot;, &quot;&quot;]\n \n\nSynonyms:\ngleam/string.split\ngleam/string split","url":"gleam/string.html#split"},{"doc":"gleam/string","title":"split_once","content":"pub fn split_once(\n  string: String,\n  on substring: String,\n) -&gt; Result(#(String, String), Nil)\n Splits a `String` a single time on the given substring.\n\n Returns an `Error` if substring not present.\n\n ## Examples\n\n \n split_once(&quot;home/gleam/desktop/&quot;, on: &quot;/&quot;)\n // -&gt; Ok(#(&quot;home&quot;, &quot;gleam/desktop/&quot;))\n \n\n \n split_once(&quot;home/gleam/desktop/&quot;, on: &quot;?&quot;)\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/string.split_once\ngleam/string split_once","url":"gleam/string.html#split_once"},{"doc":"gleam/string","title":"starts_with","content":"pub fn starts_with(string: String, prefix: String) -&gt; Bool\n Checks whether the first `String` starts with the second one.\n\n ## Examples\n\n \n starts_with(&quot;theory&quot;, &quot;ory&quot;)\n // -&gt; False\n \n\nSynonyms:\ngleam/string.starts_with\ngleam/string starts_with","url":"gleam/string.html#starts_with"},{"doc":"gleam/string","title":"to_graphemes","content":"pub fn to_graphemes(string: String) -&gt; List(String)\n Converts a `String` to a list of\n [graphemes](https://en.wikipedia.org/wiki/Grapheme).\n\n \n to_graphemes(&quot;abc&quot;)\n // -&gt; [&quot;a&quot;, &quot;b&quot;, &quot;c&quot;]\n \n\nSynonyms:\ngleam/string.to_graphemes\ngleam/string to_graphemes","url":"gleam/string.html#to_graphemes"},{"doc":"gleam/string","title":"to_option","content":"pub fn to_option(string: String) -&gt; Option(String)\n Converts a `String` into `Option(String)` where an empty `String` becomes\n `None`.\n\n ## Examples\n\n \n to_option(&quot;&quot;)\n // -&gt; None\n \n\n \n to_option(&quot;hats&quot;)\n // -&gt; Some(&quot;hats&quot;)\n \n\nSynonyms:\ngleam/string.to_option\ngleam/string to_option","url":"gleam/string.html#to_option"},{"doc":"gleam/string","title":"to_utf_codepoints","content":"pub fn to_utf_codepoints(string: String) -&gt; List(UtfCodepoint)\n Converts a `String` to a `List` of `UtfCodepoint`.\n\n See &lt;https://en.wikipedia.org/wiki/Code_point&gt; and\n &lt;https://en.wikipedia.org/wiki/Unicode#Codespace_and_Code_Points&gt; for an\n explanation on code points.\n\n ## Examples\n\n \n &quot;a&quot; |&gt; to_utf_codepoints\n // -&gt; [UtfCodepoint(97)]\n \n\n \n // Semantically the same as:\n // [&quot;🏳&quot;, &quot;️&quot;, &quot;‍&quot;, &quot;🌈&quot;] or:\n // [waving_white_flag, variant_selector_16, zero_width_joiner, rainbow]\n &quot;🏳️‍🌈&quot; |&gt; to_utf_codepoints\n // -&gt; [\n //   UtfCodepoint(127987),\n //   UtfCodepoint(65039),\n //   UtfCodepoint(8205),\n //   UtfCodepoint(127752),\n // ]\n \n\nSynonyms:\ngleam/string.to_utf_codepoints\ngleam/string to_utf_codepoints","url":"gleam/string.html#to_utf_codepoints"},{"doc":"gleam/string","title":"trim","content":"pub fn trim(string: String) -&gt; String\n Removes whitespace on both sides of a `String`.\n\n Whitespace in this function is the set of nonbreakable whitespace\n codepoints, defined as Pattern_White_Space in [Unicode Standard Annex #31][1].\n\n [1]: https://unicode.org/reports/tr31/\n\n ## Examples\n\n \n trim(&quot;  hats  \\n&quot;)\n // -&gt; &quot;hats&quot;\n \n\nSynonyms:\ngleam/string.trim\ngleam/string trim","url":"gleam/string.html#trim"},{"doc":"gleam/string","title":"trim_end","content":"pub fn trim_end(string: String) -&gt; String\n Removes whitespace at the end of a `String`.\n\n ## Examples\n\n \n trim_end(&quot;  hats  \\n&quot;)\n // -&gt; &quot;  hats&quot;\n \n\nSynonyms:\ngleam/string.trim_end\ngleam/string trim_end","url":"gleam/string.html#trim_end"},{"doc":"gleam/string","title":"trim_start","content":"pub fn trim_start(string: String) -&gt; String\n Removes whitespace at the start of a `String`.\n\n ## Examples\n\n \n trim_start(&quot;  hats  \\n&quot;)\n // -&gt; &quot;hats  \\n&quot;\n \n\nSynonyms:\ngleam/string.trim_start\ngleam/string trim_start","url":"gleam/string.html#trim_start"},{"doc":"gleam/string","title":"uppercase","content":"pub fn uppercase(string: String) -&gt; String\n Creates a new `String` with all the graphemes in the input `String` converted to\n uppercase.\n\n Useful for case-insensitive comparisons and VIRTUAL YELLING.\n\n ## Examples\n\n \n uppercase(&quot;skinner&quot;)\n // -&gt; &quot;SKINNER&quot;\n \n\nSynonyms:\ngleam/string.uppercase\ngleam/string uppercase","url":"gleam/string.html#uppercase"},{"doc":"gleam/string","title":"utf_codepoint","content":"pub fn utf_codepoint(value: Int) -&gt; Result(UtfCodepoint, Nil)\n Converts an integer to a `UtfCodepoint`.\n\n Returns an `Error` if the integer does not represent a valid UTF codepoint.\n\nSynonyms:\ngleam/string.utf_codepoint\ngleam/string utf_codepoint","url":"gleam/string.html#utf_codepoint"},{"doc":"gleam/string","title":"utf_codepoint_to_int","content":"pub fn utf_codepoint_to_int(cp: UtfCodepoint) -&gt; Int\n Converts an UtfCodepoint to its ordinal code point value.\n\n ## Examples\n\n \n let assert [utf_codepoint, ..] = to_utf_codepoints(&quot;💜&quot;)\n utf_codepoint_to_int(utf_codepoint)\n // -&gt; 128156\n \n\nSynonyms:\ngleam/string.utf_codepoint_to_int\ngleam/string utf_codepoint_to_int","url":"gleam/string.html#utf_codepoint_to_int"},{"doc":"gleam/string","title":"gleam/string","content":" Strings in Gleam are UTF-8 binaries. They can be written in your code as\n text surrounded by `&quot;double quotes&quot;`.","url":"gleam/string.html"},{"doc":"gleam/bit_array","title":"append","content":"pub fn append(\n  to first: BitArray,\n  suffix second: BitArray,\n) -&gt; BitArray\n Creates a new bit array by joining two bit arrays.\n\n ## Examples\n\n \n append(to: from_string(&quot;butter&quot;), suffix: from_string(&quot;fly&quot;))\n // -&gt; from_string(&quot;butterfly&quot;)\n \n\nSynonyms:\ngleam/bit_array.append\ngleam/bit_array append","url":"gleam/bit_array.html#append"},{"doc":"gleam/bit_array","title":"base16_decode","content":"pub fn base16_decode(input: String) -&gt; Result(BitArray, Nil)\n Decodes a base 16 encoded string into a `BitArray`.\n\nSynonyms:\ngleam/bit_array.base16_decode\ngleam/bit_array base16_decode","url":"gleam/bit_array.html#base16_decode"},{"doc":"gleam/bit_array","title":"base16_encode","content":"pub fn base16_encode(input: BitArray) -&gt; String\n Encodes a `BitArray` into a base 16 encoded string.\n\n If the bit array does not contain a whole number of bytes then it is padded\n with zero bits prior to being encoded.\n\nSynonyms:\ngleam/bit_array.base16_encode\ngleam/bit_array base16_encode","url":"gleam/bit_array.html#base16_encode"},{"doc":"gleam/bit_array","title":"base64_decode","content":"pub fn base64_decode(encoded: String) -&gt; Result(BitArray, Nil)\n Decodes a base 64 encoded string into a `BitArray`.\n\nSynonyms:\ngleam/bit_array.base64_decode\ngleam/bit_array base64_decode","url":"gleam/bit_array.html#base64_decode"},{"doc":"gleam/bit_array","title":"base64_encode","content":"pub fn base64_encode(input: BitArray, padding: Bool) -&gt; String\n Encodes a BitArray into a base 64 encoded string.\n\n If the bit array does not contain a whole number of bytes then it is padded\n with zero bits prior to being encoded.\n\nSynonyms:\ngleam/bit_array.base64_encode\ngleam/bit_array base64_encode","url":"gleam/bit_array.html#base64_encode"},{"doc":"gleam/bit_array","title":"base64_url_decode","content":"pub fn base64_url_decode(\n  encoded: String,\n) -&gt; Result(BitArray, Nil)\n Decodes a base 64 encoded string with URL and filename safe alphabet into a\n `BitArray`.\n\nSynonyms:\ngleam/bit_array.base64_url_decode\ngleam/bit_array base64_url_decode","url":"gleam/bit_array.html#base64_url_decode"},{"doc":"gleam/bit_array","title":"base64_url_encode","content":"pub fn base64_url_encode(\n  input: BitArray,\n  padding: Bool,\n) -&gt; String\n Encodes a `BitArray` into a base 64 encoded string with URL and filename\n safe alphabet.\n\n If the bit array does not contain a whole number of bytes then it is padded\n with zero bits prior to being encoded.\n\nSynonyms:\ngleam/bit_array.base64_url_encode\ngleam/bit_array base64_url_encode","url":"gleam/bit_array.html#base64_url_encode"},{"doc":"gleam/bit_array","title":"bit_size","content":"pub fn bit_size(x: BitArray) -&gt; Int\n Returns an integer which is the number of bits in the bit array.\n\nSynonyms:\ngleam/bit_array.bit_size\ngleam/bit_array bit_size","url":"gleam/bit_array.html#bit_size"},{"doc":"gleam/bit_array","title":"byte_size","content":"pub fn byte_size(x: BitArray) -&gt; Int\n Returns an integer which is the number of bytes in the bit array.\n\nSynonyms:\ngleam/bit_array.byte_size\ngleam/bit_array byte_size","url":"gleam/bit_array.html#byte_size"},{"doc":"gleam/bit_array","title":"compare","content":"pub fn compare(a: BitArray, with b: BitArray) -&gt; Order\n Compare two bit arrays as sequences of bytes.\n\n ## Examples\n\n \n compare(&lt;&lt;1&gt;&gt;, &lt;&lt;2&gt;&gt;)\n // -&gt; Lt\n\n compare(&lt;&lt;&quot;AB&quot;:utf8&gt;&gt;, &lt;&lt;&quot;AA&quot;:utf8&gt;&gt;)\n // -&gt; Gt\n\n compare(&lt;&lt;1, 2:size(2)&gt;&gt;, with: &lt;&lt;1, 2:size(2)&gt;&gt;)\n // -&gt; Eq\n \n\nSynonyms:\ngleam/bit_array.compare\ngleam/bit_array compare","url":"gleam/bit_array.html#compare"},{"doc":"gleam/bit_array","title":"concat","content":"pub fn concat(bit_arrays: List(BitArray)) -&gt; BitArray\n Creates a new bit array by joining multiple binaries.\n\n ## Examples\n\n \n concat([from_string(&quot;butter&quot;), from_string(&quot;fly&quot;)])\n // -&gt; from_string(&quot;butterfly&quot;)\n \n\nSynonyms:\ngleam/bit_array.concat\ngleam/bit_array concat","url":"gleam/bit_array.html#concat"},{"doc":"gleam/bit_array","title":"from_string","content":"pub fn from_string(x: String) -&gt; BitArray\n Converts a UTF-8 `String` type into a `BitArray`.\n\nSynonyms:\ngleam/bit_array.from_string\ngleam/bit_array from_string","url":"gleam/bit_array.html#from_string"},{"doc":"gleam/bit_array","title":"inspect","content":"pub fn inspect(input: BitArray) -&gt; String\n Converts a bit array to a string containing the decimal value of each byte.\n\n ## Examples\n\n \n inspect(&lt;&lt;0, 20, 0x20, 255&gt;&gt;)\n // -&gt; &quot;&lt;&lt;0, 20, 32, 255&gt;&gt;&quot;\n\n inspect(&lt;&lt;100, 5:3&gt;&gt;)\n // -&gt; &quot;&lt;&lt;100, 5:size(3)&gt;&gt;&quot;\n \n\nSynonyms:\ngleam/bit_array.inspect\ngleam/bit_array inspect","url":"gleam/bit_array.html#inspect"},{"doc":"gleam/bit_array","title":"is_utf8","content":"pub fn is_utf8(bits: BitArray) -&gt; Bool\n Tests to see whether a bit array is valid UTF-8.\n\nSynonyms:\ngleam/bit_array.is_utf8\ngleam/bit_array is_utf8","url":"gleam/bit_array.html#is_utf8"},{"doc":"gleam/bit_array","title":"pad_to_bytes","content":"pub fn pad_to_bytes(x: BitArray) -&gt; BitArray\n Pads a bit array with zeros so that it is a whole number of bytes.\n\nSynonyms:\ngleam/bit_array.pad_to_bytes\ngleam/bit_array pad_to_bytes","url":"gleam/bit_array.html#pad_to_bytes"},{"doc":"gleam/bit_array","title":"slice","content":"pub fn slice(\n  from string: BitArray,\n  at position: Int,\n  take length: Int,\n) -&gt; Result(BitArray, Nil)\n Extracts a sub-section of a bit array.\n\n The slice will start at given position and continue up to specified\n length.\n A negative length can be used to extract bytes at the end of a bit array.\n\n This function runs in constant time.\n\nSynonyms:\ngleam/bit_array.slice\ngleam/bit_array slice","url":"gleam/bit_array.html#slice"},{"doc":"gleam/bit_array","title":"starts_with","content":"pub fn starts_with(bits: BitArray, prefix: BitArray) -&gt; Bool\n Checks whether the first `BitArray` starts with the second one.\n\n ## Examples\n\n \n starts_with(&lt;&lt;1, 2, 3, 4&gt;&gt;, &lt;&lt;1, 2&gt;&gt;)\n // -&gt; True\n \n\nSynonyms:\ngleam/bit_array.starts_with\ngleam/bit_array starts_with","url":"gleam/bit_array.html#starts_with"},{"doc":"gleam/bit_array","title":"to_string","content":"pub fn to_string(bits: BitArray) -&gt; Result(String, Nil)\n Converts a bit array to a string.\n\n Returns an error if the bit array is invalid UTF-8 data.\n\nSynonyms:\ngleam/bit_array.to_string\ngleam/bit_array to_string","url":"gleam/bit_array.html#to_string"},{"doc":"gleam/bit_array","title":"gleam/bit_array","content":" BitArrays are a sequence of binary data of any length.","url":"gleam/bit_array.html"},{"doc":"gleam/bool","title":"and","content":"pub fn and(a: Bool, b: Bool) -&gt; Bool\n Returns the and of two bools, but it evaluates both arguments.\n\n It&#39;s the function equivalent of the `&amp;&amp;` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n and(True, True)\n // -&gt; True\n \n\n \n and(False, True)\n // -&gt; False\n \n\n \n False |&gt; and(True)\n // -&gt; False\n \n\nSynonyms:\ngleam/bool.and\ngleam/bool and","url":"gleam/bool.html#and"},{"doc":"gleam/bool","title":"exclusive_nor","content":"pub fn exclusive_nor(a: Bool, b: Bool) -&gt; Bool\n Returns the exclusive nor of two bools.\n\n ## Examples\n\n \n exclusive_nor(False, False)\n // -&gt; True\n \n\n \n exclusive_nor(False, True)\n // -&gt; False\n \n\n \n exclusive_nor(True, False)\n // -&gt; False\n \n\n \n exclusive_nor(True, True)\n // -&gt; True\n \n\nSynonyms:\ngleam/bool.exclusive_nor\ngleam/bool exclusive_nor","url":"gleam/bool.html#exclusive_nor"},{"doc":"gleam/bool","title":"exclusive_or","content":"pub fn exclusive_or(a: Bool, b: Bool) -&gt; Bool\n Returns the exclusive or of two bools.\n\n ## Examples\n\n \n exclusive_or(False, False)\n // -&gt; False\n \n\n \n exclusive_or(False, True)\n // -&gt; True\n \n\n \n exclusive_or(True, False)\n // -&gt; True\n \n\n \n exclusive_or(True, True)\n // -&gt; False\n \n\nSynonyms:\ngleam/bool.exclusive_or\ngleam/bool exclusive_or","url":"gleam/bool.html#exclusive_or"},{"doc":"gleam/bool","title":"guard","content":"pub fn guard(\n  when requirement: Bool,\n  return consequence: a,\n  otherwise alternative: fn() -&gt; a,\n) -&gt; a\n Run a callback function if the given bool is `False`, otherwise return a\n default value.\n\n With a `use` expression this function can simulate the early-return pattern\n found in some other programming languages.\n\n In a procedural language:\n\n js\n if (predicate) return value;\n // ...\n \n\n In Gleam with a `use` expression:\n\n \n use &lt;- guard(when: predicate, return: value)\n // ...\n \n\n Like everything in Gleam `use` is an expression, so it short circuits the\n current block, not the entire function. As a result you can assign the value\n to a variable:\n\n \n let x = {\n   use &lt;- guard(when: predicate, return: value)\n   // ...\n }\n \n\n Note that unlike in procedural languages the `return` value is evaluated\n even when the predicate is `False`, so it is advisable not to perform\n expensive computation nor side-effects there.\n\n\n ## Examples\n\n \n let name = &quot;&quot;\n use &lt;- guard(when: name == &quot;&quot;, return: &quot;Welcome!&quot;)\n &quot;Hello, &quot; &lt;&gt; name\n // -&gt; &quot;Welcome!&quot;\n \n\n \n let name = &quot;Kamaka&quot;\n use &lt;- guard(when: name == &quot;&quot;, return: &quot;Welcome!&quot;)\n &quot;Hello, &quot; &lt;&gt; name\n // -&gt; &quot;Hello, Kamaka&quot;\n \n\nSynonyms:\ngleam/bool.guard\ngleam/bool guard","url":"gleam/bool.html#guard"},{"doc":"gleam/bool","title":"lazy_guard","content":"pub fn lazy_guard(\n  when requirement: Bool,\n  return consequence: fn() -&gt; a,\n  otherwise alternative: fn() -&gt; a,\n) -&gt; a\n Runs a callback function if the given bool is `True`, otherwise runs an\n alternative callback function.\n\n Useful when further computation should be delayed regardless of the given\n bool&#39;s value.\n\n See [`guard`](#guard) for more info.\n\n ## Examples\n\n \n let name = &quot;Kamaka&quot;\n let inquiry = fn() { &quot;How may we address you?&quot; }\n use &lt;- lazy_guard(when: name == &quot;&quot;, return: inquiry)\n &quot;Hello, &quot; &lt;&gt; name\n // -&gt; &quot;Hello, Kamaka&quot;\n \n\n \n import gleam/int\n\n let name = &quot;&quot;\n let greeting = fn() { &quot;Hello, &quot; &lt;&gt; name }\n use &lt;- lazy_guard(when: name == &quot;&quot;, otherwise: greeting)\n let number = int.random(99)\n let name = &quot;User &quot; &lt;&gt; int.to_string(number)\n &quot;Welcome, &quot; &lt;&gt; name\n // -&gt; &quot;Welcome, User 54&quot;\n \n\nSynonyms:\ngleam/bool.lazy_guard\ngleam/bool lazy_guard","url":"gleam/bool.html#lazy_guard"},{"doc":"gleam/bool","title":"nand","content":"pub fn nand(a: Bool, b: Bool) -&gt; Bool\n Returns the nand of two bools.\n\n ## Examples\n\n \n nand(False, False)\n // -&gt; True\n \n\n \n nand(False, True)\n // -&gt; True\n \n\n \n nand(True, False)\n // -&gt; True\n \n\n \n nand(True, True)\n // -&gt; False\n \n\nSynonyms:\ngleam/bool.nand\ngleam/bool nand","url":"gleam/bool.html#nand"},{"doc":"gleam/bool","title":"negate","content":"pub fn negate(bool: Bool) -&gt; Bool\n Returns the opposite bool value.\n\n This is the same as the `!` or `not` operators in some other languages.\n\n ## Examples\n\n \n negate(True)\n // -&gt; False\n \n\n \n negate(False)\n // -&gt; True\n \n\nSynonyms:\ngleam/bool.negate\ngleam/bool negate","url":"gleam/bool.html#negate"},{"doc":"gleam/bool","title":"nor","content":"pub fn nor(a: Bool, b: Bool) -&gt; Bool\n Returns the nor of two bools.\n\n ## Examples\n\n \n nor(False, False)\n // -&gt; True\n \n\n \n nor(False, True)\n // -&gt; False\n \n\n \n nor(True, False)\n // -&gt; False\n \n\n \n nor(True, True)\n // -&gt; False\n \n\nSynonyms:\ngleam/bool.nor\ngleam/bool nor","url":"gleam/bool.html#nor"},{"doc":"gleam/bool","title":"or","content":"pub fn or(a: Bool, b: Bool) -&gt; Bool\n Returns the or of two bools, but it evaluates both arguments.\n\n It&#39;s the function equivalent of the `||` operator.\n This function is useful in higher order functions or pipes.\n\n ## Examples\n\n \n or(True, True)\n // -&gt; True\n \n\n \n or(False, True)\n // -&gt; True\n \n\n \n False |&gt; or(True)\n // -&gt; True\n \n\nSynonyms:\ngleam/bool.or\ngleam/bool or","url":"gleam/bool.html#or"},{"doc":"gleam/bool","title":"to_string","content":"pub fn to_string(bool: Bool) -&gt; String\n Returns a string representation of the given bool.\n\n ## Examples\n\n \n to_string(True)\n // -&gt; &quot;True&quot;\n \n\n \n to_string(False)\n // -&gt; &quot;False&quot;\n \n\nSynonyms:\ngleam/bool.to_string\ngleam/bool to_string","url":"gleam/bool.html#to_string"},{"doc":"gleam/bool","title":"gleam/bool","content":" A type with two possible values, `True` and `False`. Used to indicate whether\n things are... true or false!\n\n Often is it clearer and offers more type safety to define a custom type\n than to use `Bool`. For example, rather than having a `is_teacher: Bool`\n field consider having a `role: SchoolRole` field where `SchoolRole` is a custom\n type that can be either `Student` or `Teacher`.","url":"gleam/bool.html"},{"doc":"gleam/bytes_tree","title":"BytesTree","content":"pub opaque type BytesTree\n\n\nSynonyms:\ngleam/bytes_tree.BytesTree\ngleam/bytes_tree BytesTree","url":"gleam/bytes_tree.html#BytesTree"},{"doc":"gleam/bytes_tree","title":"append","content":"pub fn append(\n  to first: BytesTree,\n  suffix second: BitArray,\n) -&gt; BytesTree\n Appends a bit array to the end of a bytes tree.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_tree.append\ngleam/bytes_tree append","url":"gleam/bytes_tree.html#append"},{"doc":"gleam/bytes_tree","title":"append_string","content":"pub fn append_string(\n  to first: BytesTree,\n  suffix second: String,\n) -&gt; BytesTree\n Appends a string onto the end of a bytes tree.\n\n Runs in constant time when running on Erlang.\n Runs in linear time with the length of the string otherwise.\n\nSynonyms:\ngleam/bytes_tree.append_string\ngleam/bytes_tree append_string","url":"gleam/bytes_tree.html#append_string"},{"doc":"gleam/bytes_tree","title":"append_tree","content":"pub fn append_tree(\n  to first: BytesTree,\n  suffix second: BytesTree,\n) -&gt; BytesTree\n Appends a bytes tree onto the end of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_tree.append_tree\ngleam/bytes_tree append_tree","url":"gleam/bytes_tree.html#append_tree"},{"doc":"gleam/bytes_tree","title":"byte_size","content":"pub fn byte_size(tree: BytesTree) -&gt; Int\n Returns the size of the bytes tree&#39;s content in bytes.\n\n Runs in linear time.\n\nSynonyms:\ngleam/bytes_tree.byte_size\ngleam/bytes_tree byte_size","url":"gleam/bytes_tree.html#byte_size"},{"doc":"gleam/bytes_tree","title":"concat","content":"pub fn concat(trees: List(BytesTree)) -&gt; BytesTree\n Joins a list of bytes trees into a single one.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_tree.concat\ngleam/bytes_tree concat","url":"gleam/bytes_tree.html#concat"},{"doc":"gleam/bytes_tree","title":"concat_bit_arrays","content":"pub fn concat_bit_arrays(bits: List(BitArray)) -&gt; BytesTree\n Joins a list of bit arrays into a single bytes tree.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_tree.concat_bit_arrays\ngleam/bytes_tree concat_bit_arrays","url":"gleam/bytes_tree.html#concat_bit_arrays"},{"doc":"gleam/bytes_tree","title":"from_bit_array","content":"pub fn from_bit_array(bits: BitArray) -&gt; BytesTree\n Creates a new bytes tree from a bit array.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_tree.from_bit_array\ngleam/bytes_tree from_bit_array","url":"gleam/bytes_tree.html#from_bit_array"},{"doc":"gleam/bytes_tree","title":"from_string","content":"pub fn from_string(string: String) -&gt; BytesTree\n Creates a new bytes tree from a string.\n\n Runs in constant time when running on Erlang.\n Runs in linear time otherwise.\n\nSynonyms:\ngleam/bytes_tree.from_string\ngleam/bytes_tree from_string","url":"gleam/bytes_tree.html#from_string"},{"doc":"gleam/bytes_tree","title":"from_string_tree","content":"pub fn from_string_tree(tree: StringTree) -&gt; BytesTree\n Creates a new bytes tree from a string tree.\n\n Runs in constant time when running on Erlang.\n Runs in linear time otherwise.\n\nSynonyms:\ngleam/bytes_tree.from_string_tree\ngleam/bytes_tree from_string_tree","url":"gleam/bytes_tree.html#from_string_tree"},{"doc":"gleam/bytes_tree","title":"new","content":"pub fn new() -&gt; BytesTree\n Create an empty `BytesTree`. Useful as the start of a pipe chaining many\n trees together.\n\nSynonyms:\ngleam/bytes_tree.new\ngleam/bytes_tree new","url":"gleam/bytes_tree.html#new"},{"doc":"gleam/bytes_tree","title":"prepend","content":"pub fn prepend(\n  to second: BytesTree,\n  prefix first: BitArray,\n) -&gt; BytesTree\n Prepends a bit array to the start of a bytes tree.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_tree.prepend\ngleam/bytes_tree prepend","url":"gleam/bytes_tree.html#prepend"},{"doc":"gleam/bytes_tree","title":"prepend_string","content":"pub fn prepend_string(\n  to second: BytesTree,\n  prefix first: String,\n) -&gt; BytesTree\n Prepends a string onto the start of a bytes tree.\n\n Runs in constant time when running on Erlang.\n Runs in linear time with the length of the string otherwise.\n\nSynonyms:\ngleam/bytes_tree.prepend_string\ngleam/bytes_tree prepend_string","url":"gleam/bytes_tree.html#prepend_string"},{"doc":"gleam/bytes_tree","title":"prepend_tree","content":"pub fn prepend_tree(\n  to second: BytesTree,\n  prefix first: BytesTree,\n) -&gt; BytesTree\n Prepends a bytes tree onto the start of another.\n\n Runs in constant time.\n\nSynonyms:\ngleam/bytes_tree.prepend_tree\ngleam/bytes_tree prepend_tree","url":"gleam/bytes_tree.html#prepend_tree"},{"doc":"gleam/bytes_tree","title":"to_bit_array","content":"pub fn to_bit_array(tree: BytesTree) -&gt; BitArray\n Turns a bytes tree into a bit array.\n\n Runs in linear time.\n\n When running on Erlang this function is implemented natively by the\n virtual machine and is highly optimised.\n\nSynonyms:\ngleam/bytes_tree.to_bit_array\ngleam/bytes_tree to_bit_array","url":"gleam/bytes_tree.html#to_bit_array"},{"doc":"gleam/bytes_tree","title":"gleam/bytes_tree","content":" `BytesTree` is a type used for efficiently building binary content to be\n written to a file or a socket. Internally it is represented as tree so to\n append or prepend to a bytes tree is a constant time operation that\n allocates a new node in the tree without copying any of the content. When\n writing to an output stream the tree is traversed and the content is sent\n directly rather than copying it into a single buffer beforehand.\n\n If we append one bit array to another the bit arrays must be copied to a\n new location in memory so that they can sit together. This behaviour\n enables efficient reading of the data but copying can be expensive,\n especially if we want to join many bit arrays together.\n\n BytesTree is different in that it can be joined together in constant\n time using minimal memory, and then can be efficiently converted to a\n bit array using the `to_bit_array` function.\n\n Byte trees are always byte aligned, so that a number of bits that is not\n divisible by 8 will be padded with 0s.\n\n On Erlang this type is compatible with Erlang&#39;s iolists.","url":"gleam/bytes_tree.html"},{"doc":"gleam/result","title":"all","content":"pub fn all(results: List(Result(a, b))) -&gt; Result(List(a), b)\n Combines a list of results into a single result.\n If all elements in the list are `Ok` then returns an `Ok` holding the list of values.\n If any element is `Error` then returns the first error.\n\n ## Examples\n\n \n all([Ok(1), Ok(2)])\n // -&gt; Ok([1, 2])\n \n\n \n all([Ok(1), Error(&quot;e&quot;)])\n // -&gt; Error(&quot;e&quot;)\n \n\nSynonyms:\ngleam/result.all\ngleam/result all","url":"gleam/result.html#all"},{"doc":"gleam/result","title":"flatten","content":"pub fn flatten(result: Result(Result(a, b), b)) -&gt; Result(a, b)\n Merges a nested `Result` into a single layer.\n\n ## Examples\n\n \n flatten(Ok(Ok(1)))\n // -&gt; Ok(1)\n \n\n \n flatten(Ok(Error(&quot;&quot;)))\n // -&gt; Error(&quot;&quot;)\n \n\n \n flatten(Error(Nil))\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/result.flatten\ngleam/result flatten","url":"gleam/result.html#flatten"},{"doc":"gleam/result","title":"is_error","content":"pub fn is_error(result: Result(a, b)) -&gt; Bool\n Checks whether the result is an `Error` value.\n\n ## Examples\n\n \n is_error(Ok(1))\n // -&gt; False\n \n\n \n is_error(Error(Nil))\n // -&gt; True\n \n\nSynonyms:\ngleam/result.is_error\ngleam/result is_error","url":"gleam/result.html#is_error"},{"doc":"gleam/result","title":"is_ok","content":"pub fn is_ok(result: Result(a, b)) -&gt; Bool\n Checks whether the result is an `Ok` value.\n\n ## Examples\n\n \n is_ok(Ok(1))\n // -&gt; True\n \n\n \n is_ok(Error(Nil))\n // -&gt; False\n \n\nSynonyms:\ngleam/result.is_ok\ngleam/result is_ok","url":"gleam/result.html#is_ok"},{"doc":"gleam/result","title":"lazy_or","content":"pub fn lazy_or(\n  first: Result(a, b),\n  second: fn() -&gt; Result(a, b),\n) -&gt; Result(a, b)\n Returns the first value if it is `Ok`, otherwise evaluates the given function for a fallback value.\n\n If you need access to the initial error value, use `result.try_recover`.\n\n ## Examples\n\n \n lazy_or(Ok(1), fn() { Ok(2) })\n // -&gt; Ok(1)\n \n\n \n lazy_or(Ok(1), fn() { Error(&quot;Error 2&quot;) })\n // -&gt; Ok(1)\n \n\n \n lazy_or(Error(&quot;Error 1&quot;), fn() { Ok(2) })\n // -&gt; Ok(2)\n \n\n \n lazy_or(Error(&quot;Error 1&quot;), fn() { Error(&quot;Error 2&quot;) })\n // -&gt; Error(&quot;Error 2&quot;)\n \n\nSynonyms:\ngleam/result.lazy_or\ngleam/result lazy_or","url":"gleam/result.html#lazy_or"},{"doc":"gleam/result","title":"lazy_unwrap","content":"pub fn lazy_unwrap(\n  result: Result(a, b),\n  or default: fn() -&gt; a,\n) -&gt; a\n Extracts the `Ok` value from a result, evaluating the default function if the result\n is an `Error`.\n\n ## Examples\n\n \n lazy_unwrap(Ok(1), fn() { 0 })\n // -&gt; 1\n \n\n \n lazy_unwrap(Error(&quot;&quot;), fn() { 0 })\n // -&gt; 0\n \n\nSynonyms:\ngleam/result.lazy_unwrap\ngleam/result lazy_unwrap","url":"gleam/result.html#lazy_unwrap"},{"doc":"gleam/result","title":"map","content":"pub fn map(\n  over result: Result(a, b),\n  with fun: fn(a) -&gt; c,\n) -&gt; Result(c, b)\n Updates a value held within the `Ok` of a result by calling a given function\n on it.\n\n If the result is an `Error` rather than `Ok` the function is not called and the\n result stays the same.\n\n ## Examples\n\n \n map(over: Ok(1), with: fn(x) { x + 1 })\n // -&gt; Ok(2)\n \n\n \n map(over: Error(1), with: fn(x) { x + 1 })\n // -&gt; Error(1)\n \n\nSynonyms:\ngleam/result.map\ngleam/result map","url":"gleam/result.html#map"},{"doc":"gleam/result","title":"map_error","content":"pub fn map_error(\n  over result: Result(a, b),\n  with fun: fn(b) -&gt; c,\n) -&gt; Result(a, c)\n Updates a value held within the `Error` of a result by calling a given function\n on it.\n\n If the result is `Ok` rather than `Error` the function is not called and the\n result stays the same.\n\n ## Examples\n\n \n map_error(over: Error(1), with: fn(x) { x + 1 })\n // -&gt; Error(2)\n \n\n \n map_error(over: Ok(1), with: fn(x) { x + 1 })\n // -&gt; Ok(1)\n \n\nSynonyms:\ngleam/result.map_error\ngleam/result map_error","url":"gleam/result.html#map_error"},{"doc":"gleam/result","title":"or","content":"pub fn or(\n  first: Result(a, b),\n  second: Result(a, b),\n) -&gt; Result(a, b)\n Returns the first value if it is `Ok`, otherwise returns the second value.\n\n ## Examples\n\n \n or(Ok(1), Ok(2))\n // -&gt; Ok(1)\n \n\n \n or(Ok(1), Error(&quot;Error 2&quot;))\n // -&gt; Ok(1)\n \n\n \n or(Error(&quot;Error 1&quot;), Ok(2))\n // -&gt; Ok(2)\n \n\n \n or(Error(&quot;Error 1&quot;), Error(&quot;Error 2&quot;))\n // -&gt; Error(&quot;Error 2&quot;)\n \n\nSynonyms:\ngleam/result.or\ngleam/result or","url":"gleam/result.html#or"},{"doc":"gleam/result","title":"partition","content":"pub fn partition(\n  results: List(Result(a, b)),\n) -&gt; #(List(a), List(b))\n Given a list of results, returns a pair where the first element is a list\n of all the values inside `Ok` and the second element is a list with all the\n values inside `Error`. The values in both lists appear in reverse order with\n respect to their position in the original list of results.\n\n ## Examples\n\n \n partition([Ok(1), Error(&quot;a&quot;), Error(&quot;b&quot;), Ok(2)])\n // -&gt; #([2, 1], [&quot;b&quot;, &quot;a&quot;])\n \n\nSynonyms:\ngleam/result.partition\ngleam/result partition","url":"gleam/result.html#partition"},{"doc":"gleam/result","title":"replace","content":"pub fn replace(result: Result(a, b), value: c) -&gt; Result(c, b)\n Replace the value within a result\n\n ## Examples\n\n \n replace(Ok(1), Nil)\n // -&gt; Ok(Nil)\n \n\n \n replace(Error(1), Nil)\n // -&gt; Error(1)\n \n\nSynonyms:\ngleam/result.replace\ngleam/result replace","url":"gleam/result.html#replace"},{"doc":"gleam/result","title":"replace_error","content":"pub fn replace_error(\n  result: Result(a, b),\n  error: c,\n) -&gt; Result(a, c)\n Replace the error within a result\n\n ## Examples\n\n \n replace_error(Error(1), Nil)\n // -&gt; Error(Nil)\n \n\n \n replace_error(Ok(1), Nil)\n // -&gt; Ok(1)\n \n\nSynonyms:\ngleam/result.replace_error\ngleam/result replace_error","url":"gleam/result.html#replace_error"},{"doc":"gleam/result","title":"then","content":"pub fn then(\n  result: Result(a, b),\n  apply fun: fn(a) -&gt; Result(c, b),\n) -&gt; Result(c, b)\n An alias for `try`. See the documentation for that function for more information.\n\nSynonyms:\ngleam/result.then\ngleam/result then","url":"gleam/result.html#then"},{"doc":"gleam/result","title":"try","content":"pub fn try(\n  result: Result(a, b),\n  apply fun: fn(a) -&gt; Result(c, b),\n) -&gt; Result(c, b)\n &quot;Updates&quot; an `Ok` result by passing its value to a function that yields a result,\n and returning the yielded result. (This may &quot;replace&quot; the `Ok` with an `Error`.)\n\n If the input is an `Error` rather than an `Ok`, the function is not called and\n the original `Error` is returned.\n\n This function is the equivalent of calling `map` followed by `flatten`, and\n it is useful for chaining together multiple functions that may fail.\n\n ## Examples\n\n \n try(Ok(1), fn(x) { Ok(x + 1) })\n // -&gt; Ok(2)\n \n\n \n try(Ok(1), fn(x) { Ok(#(&quot;a&quot;, x)) })\n // -&gt; Ok(#(&quot;a&quot;, 1))\n \n\n \n try(Ok(1), fn(_) { Error(&quot;Oh no&quot;) })\n // -&gt; Error(&quot;Oh no&quot;)\n \n\n \n try(Error(Nil), fn(x) { Ok(x + 1) })\n // -&gt; Error(Nil)\n \n\nSynonyms:\ngleam/result.try\ngleam/result try","url":"gleam/result.html#try"},{"doc":"gleam/result","title":"try_recover","content":"pub fn try_recover(\n  result: Result(a, b),\n  with fun: fn(b) -&gt; Result(a, c),\n) -&gt; Result(a, c)\n Updates a value held within the `Error` of a result by calling a given function\n on it, where the given function also returns a result. The two results are\n then merged together into one result.\n\n If the result is an `Ok` rather than `Error` the function is not called and the\n result stays the same.\n\n This function is useful for chaining together computations that may fail\n and trying to recover from possible errors.\n\n If you do not need access to the initial error value, use `result.lazy_or`.\n\n ## Examples\n\n \n Ok(1) |&gt; try_recover(with: fn(_) { Error(&quot;failed to recover&quot;) })\n // -&gt; Ok(1)\n \n\n \n Error(1) |&gt; try_recover(with: fn(error) { Ok(error + 1) })\n // -&gt; Ok(2)\n \n\n \n Error(1) |&gt; try_recover(with: fn(error) { Error(&quot;failed to recover&quot;) })\n // -&gt; Error(&quot;failed to recover&quot;)\n \n\nSynonyms:\ngleam/result.try_recover\ngleam/result try_recover","url":"gleam/result.html#try_recover"},{"doc":"gleam/result","title":"unwrap","content":"pub fn unwrap(result: Result(a, b), or default: a) -&gt; a\n Extracts the `Ok` value from a result, returning a default value if the result\n is an `Error`.\n\n ## Examples\n\n \n unwrap(Ok(1), 0)\n // -&gt; 1\n \n\n \n unwrap(Error(&quot;&quot;), 0)\n // -&gt; 0\n \n\nSynonyms:\ngleam/result.unwrap\ngleam/result unwrap","url":"gleam/result.html#unwrap"},{"doc":"gleam/result","title":"unwrap_both","content":"pub fn unwrap_both(result: Result(a, a)) -&gt; a\n Extracts the inner value from a result. Both the value and error must be of\n the same type.\n\n ## Examples\n\n \n unwrap_both(Error(1))\n // -&gt; 1\n \n\n \n unwrap_both(Ok(2))\n // -&gt; 2\n \n\nSynonyms:\ngleam/result.unwrap_both\ngleam/result unwrap_both","url":"gleam/result.html#unwrap_both"},{"doc":"gleam/result","title":"unwrap_error","content":"pub fn unwrap_error(result: Result(a, b), or default: b) -&gt; b\n Extracts the `Error` value from a result, returning a default value if the result\n is an `Ok`.\n\n ## Examples\n\n \n unwrap_error(Error(1), 0)\n // -&gt; 1\n \n\n \n unwrap_error(Ok(&quot;&quot;), 0)\n // -&gt; 0\n \n\nSynonyms:\ngleam/result.unwrap_error\ngleam/result unwrap_error","url":"gleam/result.html#unwrap_error"},{"doc":"gleam/result","title":"values","content":"pub fn values(results: List(Result(a, b))) -&gt; List(a)\n Given a list of results, returns only the values inside `Ok`.\n\n ## Examples\n\n \n values([Ok(1), Error(&quot;a&quot;), Ok(3)])\n // -&gt; [1, 3]\n \n\nSynonyms:\ngleam/result.values\ngleam/result values","url":"gleam/result.html#values"},{"doc":"gleam/result","title":"gleam/result","content":" Result represents the result of something that may succeed or not.\n `Ok` means it was successful, `Error` means it was not successful.","url":"gleam/result.html"},{"doc":"gleam/dynamic","title":"DecodeError","content":"pub type DecodeError {\n  DecodeError(\n    expected: String,\n    found: String,\n    path: List(String),\n  )\n}\n\nDecodeError(expected: String, found: String, path: List(String))\n\n\nSynonyms:\ngleam/dynamic.DecodeError\ngleam/dynamic DecodeError","url":"gleam/dynamic.html#DecodeError"},{"doc":"gleam/dynamic","title":"DecodeErrors","content":"pub type DecodeErrors =\n  List(DecodeError)\n\n\nSynonyms:\ngleam/dynamic.DecodeErrors\ngleam/dynamic DecodeErrors","url":"gleam/dynamic.html#DecodeErrors"},{"doc":"gleam/dynamic","title":"Decoder","content":"pub type Decoder(t) =\n  fn(Dynamic) -&gt; Result(t, DecodeErrors)\n\n\nSynonyms:\ngleam/dynamic.Decoder\ngleam/dynamic Decoder","url":"gleam/dynamic.html#Decoder"},{"doc":"gleam/dynamic","title":"Dynamic","content":"pub type Dynamic\n `Dynamic` data is data that we don&#39;t know the type of yet.\n We likely get data like this from interop with Erlang, or from\n IO with the outside world.\n\n\nSynonyms:\ngleam/dynamic.Dynamic\ngleam/dynamic Dynamic","url":"gleam/dynamic.html#Dynamic"},{"doc":"gleam/dynamic","title":"any","content":"pub fn any(\n  of decoders: List(fn(Dynamic) -&gt; Result(a, List(DecodeError))),\n) -&gt; fn(Dynamic) -&gt; Result(a, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.any\ngleam/dynamic any","url":"gleam/dynamic.html#any"},{"doc":"gleam/dynamic","title":"bit_array","content":"pub fn bit_array(\n  from data: Dynamic,\n) -&gt; Result(BitArray, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.bit_array\ngleam/dynamic bit_array","url":"gleam/dynamic.html#bit_array"},{"doc":"gleam/dynamic","title":"bool","content":"pub fn bool(\n  from data: Dynamic,\n) -&gt; Result(Bool, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.bool\ngleam/dynamic bool","url":"gleam/dynamic.html#bool"},{"doc":"gleam/dynamic","title":"classify","content":"pub fn classify(data: Dynamic) -&gt; String\n Return a string indicating the type of the dynamic value.\n\n This function may be useful for constructing error messages or logs. If you\n want to turn dynamic data into well typed data then you want the\n `gleam/dynamic/decode` module.\n\n \n classify(from(&quot;Hello&quot;))\n // -&gt; &quot;String&quot;\n \n\nSynonyms:\ngleam/dynamic.classify\ngleam/dynamic classify","url":"gleam/dynamic.html#classify"},{"doc":"gleam/dynamic","title":"decode1","content":"pub fn decode1(\n  constructor: fn(a) -&gt; b,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(b, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode1\ngleam/dynamic decode1","url":"gleam/dynamic.html#decode1"},{"doc":"gleam/dynamic","title":"decode2","content":"pub fn decode2(\n  constructor: fn(a, b) -&gt; c,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(c, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode2\ngleam/dynamic decode2","url":"gleam/dynamic.html#decode2"},{"doc":"gleam/dynamic","title":"decode3","content":"pub fn decode3(\n  constructor: fn(a, b, c) -&gt; d,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(d, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode3\ngleam/dynamic decode3","url":"gleam/dynamic.html#decode3"},{"doc":"gleam/dynamic","title":"decode4","content":"pub fn decode4(\n  constructor: fn(a, b, c, d) -&gt; e,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(e, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode4\ngleam/dynamic decode4","url":"gleam/dynamic.html#decode4"},{"doc":"gleam/dynamic","title":"decode5","content":"pub fn decode5(\n  constructor: fn(a, b, c, d, e) -&gt; f,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(f, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode5\ngleam/dynamic decode5","url":"gleam/dynamic.html#decode5"},{"doc":"gleam/dynamic","title":"decode6","content":"pub fn decode6(\n  constructor: fn(a, b, c, d, e, f) -&gt; g,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(g, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode6\ngleam/dynamic decode6","url":"gleam/dynamic.html#decode6"},{"doc":"gleam/dynamic","title":"decode7","content":"pub fn decode7(\n  constructor: fn(a, b, c, d, e, f, g) -&gt; h,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n  t7: fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(h, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode7\ngleam/dynamic decode7","url":"gleam/dynamic.html#decode7"},{"doc":"gleam/dynamic","title":"decode8","content":"pub fn decode8(\n  constructor: fn(a, b, c, d, e, f, g, h) -&gt; i,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n  t7: fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n  t8: fn(Dynamic) -&gt; Result(h, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(i, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode8\ngleam/dynamic decode8","url":"gleam/dynamic.html#decode8"},{"doc":"gleam/dynamic","title":"decode9","content":"pub fn decode9(\n  constructor: fn(a, b, c, d, e, f, g, h, i) -&gt; j,\n  t1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  t2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  t3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  t4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  t5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  t6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n  t7: fn(Dynamic) -&gt; Result(g, List(DecodeError)),\n  t8: fn(Dynamic) -&gt; Result(h, List(DecodeError)),\n  t9: fn(Dynamic) -&gt; Result(i, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(j, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.decode9\ngleam/dynamic decode9","url":"gleam/dynamic.html#decode9"},{"doc":"gleam/dynamic","title":"dict","content":"pub fn dict(\n  of key_type: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  to value_type: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Dict(a, b), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.dict\ngleam/dynamic dict","url":"gleam/dynamic.html#dict"},{"doc":"gleam/dynamic","title":"dynamic","content":"pub fn dynamic(\n  value: Dynamic,\n) -&gt; Result(Dynamic, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.dynamic\ngleam/dynamic dynamic","url":"gleam/dynamic.html#dynamic"},{"doc":"gleam/dynamic","title":"element","content":"pub fn element(\n  at index: Int,\n  of inner_type: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(a, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.element\ngleam/dynamic element","url":"gleam/dynamic.html#element"},{"doc":"gleam/dynamic","title":"field","content":"pub fn field(\n  named name: a,\n  of inner_type: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(b, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.field\ngleam/dynamic field","url":"gleam/dynamic.html#field"},{"doc":"gleam/dynamic","title":"float","content":"pub fn float(\n  from data: Dynamic,\n) -&gt; Result(Float, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.float\ngleam/dynamic float","url":"gleam/dynamic.html#float"},{"doc":"gleam/dynamic","title":"from","content":"pub fn from(a: a) -&gt; Dynamic\n Converts any Gleam data into `Dynamic` data.\n\nSynonyms:\ngleam/dynamic.from\ngleam/dynamic from","url":"gleam/dynamic.html#from"},{"doc":"gleam/dynamic","title":"int","content":"pub fn int(from data: Dynamic) -&gt; Result(Int, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.int\ngleam/dynamic int","url":"gleam/dynamic.html#int"},{"doc":"gleam/dynamic","title":"list","content":"pub fn list(\n  of decoder_type: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(List(a), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.list\ngleam/dynamic list","url":"gleam/dynamic.html#list"},{"doc":"gleam/dynamic","title":"optional","content":"pub fn optional(\n  of decode: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Option(a), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.optional\ngleam/dynamic optional","url":"gleam/dynamic.html#optional"},{"doc":"gleam/dynamic","title":"optional_field","content":"pub fn optional_field(\n  named name: a,\n  of inner_type: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Option(b), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.optional_field\ngleam/dynamic optional_field","url":"gleam/dynamic.html#optional_field"},{"doc":"gleam/dynamic","title":"result","content":"pub fn result(\n  ok decode_ok: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  error decode_error: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(Result(a, b), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.result\ngleam/dynamic result","url":"gleam/dynamic.html#result"},{"doc":"gleam/dynamic","title":"shallow_list","content":"pub fn shallow_list(\n  from value: Dynamic,\n) -&gt; Result(List(Dynamic), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.shallow_list\ngleam/dynamic shallow_list","url":"gleam/dynamic.html#shallow_list"},{"doc":"gleam/dynamic","title":"string","content":"pub fn string(\n  from data: Dynamic,\n) -&gt; Result(String, List(DecodeError))\n\nSynonyms:\ngleam/dynamic.string\ngleam/dynamic string","url":"gleam/dynamic.html#string"},{"doc":"gleam/dynamic","title":"tuple2","content":"pub fn tuple2(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.tuple2\ngleam/dynamic tuple2","url":"gleam/dynamic.html#tuple2"},{"doc":"gleam/dynamic","title":"tuple3","content":"pub fn tuple3(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b, c), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.tuple3\ngleam/dynamic tuple3","url":"gleam/dynamic.html#tuple3"},{"doc":"gleam/dynamic","title":"tuple4","content":"pub fn tuple4(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  fourth decode4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b, c, d), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.tuple4\ngleam/dynamic tuple4","url":"gleam/dynamic.html#tuple4"},{"doc":"gleam/dynamic","title":"tuple5","content":"pub fn tuple5(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  fourth decode4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  fifth decode5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt; Result(#(a, b, c, d, e), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.tuple5\ngleam/dynamic tuple5","url":"gleam/dynamic.html#tuple5"},{"doc":"gleam/dynamic","title":"tuple6","content":"pub fn tuple6(\n  first decode1: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n  second decode2: fn(Dynamic) -&gt; Result(b, List(DecodeError)),\n  third decode3: fn(Dynamic) -&gt; Result(c, List(DecodeError)),\n  fourth decode4: fn(Dynamic) -&gt; Result(d, List(DecodeError)),\n  fifth decode5: fn(Dynamic) -&gt; Result(e, List(DecodeError)),\n  sixth decode6: fn(Dynamic) -&gt; Result(f, List(DecodeError)),\n) -&gt; fn(Dynamic) -&gt;\n  Result(#(a, b, c, d, e, f), List(DecodeError))\n\nSynonyms:\ngleam/dynamic.tuple6\ngleam/dynamic tuple6","url":"gleam/dynamic.html#tuple6"},{"doc":"gleam/dynamic","title":"gleam/dynamic","content":"","url":"gleam/dynamic.html"},{"doc":"gleam/dynamic/decode","title":"DecodeError","content":"pub type DecodeError {\n  DecodeError(\n    expected: String,\n    found: String,\n    path: List(String),\n  )\n}\n Error returned when unexpected data is encountered\n\nDecodeError(expected: String, found: String, path: List(String))\n\n\nSynonyms:\ngleam/dynamic/decode.DecodeError\ngleam/dynamic/decode DecodeError","url":"gleam/dynamic/decode.html#DecodeError"},{"doc":"gleam/dynamic/decode","title":"Decoder","content":"pub opaque type Decoder(t)\n A decoder is a value that can be used to turn dynamically typed `Dynamic`\n data into typed data using the `run` function.\n\n Several smaller decoders can be combined to make larger decoders using\n functions such as `list` and `field`.\n\n\nSynonyms:\ngleam/dynamic/decode.Decoder\ngleam/dynamic/decode Decoder","url":"gleam/dynamic/decode.html#Decoder"},{"doc":"gleam/dynamic/decode","title":"Dynamic","content":"pub type Dynamic =\n  dynamic.Dynamic\n `Dynamic` data is data that we don&#39;t know the type of yet, originating from\n external untyped systems.\n\n You should never be converting your well typed data to dynamic data.\n\n\nSynonyms:\ngleam/dynamic/decode.Dynamic\ngleam/dynamic/decode Dynamic","url":"gleam/dynamic/decode.html#Dynamic"},{"doc":"gleam/dynamic/decode","title":"bit_array","content":"pub const bit_array: Decoder(BitArray)\n A decoder that decodes `BitArray` values. This decoder never returns an error.\n\n # Examples\n\n \n let result = decode.run(dynamic.from(&lt;&lt;5, 7&gt;&gt;), decode.bit_array)\n assert result == Ok(&lt;&lt;5, 7&gt;&gt;)\n \n\nSynonyms:\ngleam/dynamic/decode.bit_array\ngleam/dynamic/decode bit_array","url":"gleam/dynamic/decode.html#bit_array"},{"doc":"gleam/dynamic/decode","title":"bool","content":"pub const bool: Decoder(Bool)\n A decoder that decodes `Bool` values.\n\n # Examples\n\n \n let result = decode.run(dynamic.from(True), decode.bool)\n assert result == Ok(True)\n \n\nSynonyms:\ngleam/dynamic/decode.bool\ngleam/dynamic/decode bool","url":"gleam/dynamic/decode.html#bool"},{"doc":"gleam/dynamic/decode","title":"dynamic","content":"pub const dynamic: Decoder(Dynamic)\n A decoder that decodes `Dynamic` values. This decoder never returns an error.\n\n # Examples\n\n \n let result = decode.run(dynamic.from(3.14), decode.dynamic)\n assert result == Ok(dynamic.from(3.14))\n \n\nSynonyms:\ngleam/dynamic/decode.dynamic\ngleam/dynamic/decode dynamic","url":"gleam/dynamic/decode.html#dynamic"},{"doc":"gleam/dynamic/decode","title":"float","content":"pub const float: Decoder(Float)\n A decoder that decodes `Float` values.\n\n # Examples\n\n \n let result = decode.run(dynamic.from(3.14), decode.float)\n assert result == Ok(3.14)\n \n\nSynonyms:\ngleam/dynamic/decode.float\ngleam/dynamic/decode float","url":"gleam/dynamic/decode.html#float"},{"doc":"gleam/dynamic/decode","title":"int","content":"pub const int: Decoder(Int)\n A decoder that decodes `Int` values.\n\n # Examples\n\n \n let result = decode.run(dynamic.from(147), decode.int)\n assert result == Ok(147)\n \n\nSynonyms:\ngleam/dynamic/decode.int\ngleam/dynamic/decode int","url":"gleam/dynamic/decode.html#int"},{"doc":"gleam/dynamic/decode","title":"string","content":"pub const string: Decoder(String)\n A decoder that decodes `String` values.\n\n # Examples\n\n \n let result = decode.run(dynamic.from(&quot;Hello!&quot;), decode.string)\n assert result == Ok(&quot;Hello!&quot;)\n \n\nSynonyms:\ngleam/dynamic/decode.string\ngleam/dynamic/decode string","url":"gleam/dynamic/decode.html#string"},{"doc":"gleam/dynamic/decode","title":"at","content":"pub fn at(path: List(a), inner: Decoder(b)) -&gt; Decoder(b)\n A decoder that decodes a value that is nested within other values. For\n example, decoding a value that is within some deeply nested JSON objects.\n\n This function will index into dictionaries with any key type, and if the key is\n an int then it&#39;ll also index into Erlang tuples and JavaScript arrays, and\n the first two elements of Gleam lists.\n\n # Examples\n\n \n let decoder = decode.at([&quot;one&quot;, &quot;two&quot;], decode.int)\n\n let data = dynamic.from(dict.from_list([\n   #(&quot;one&quot;, dict.from_list([\n     #(&quot;two&quot;, 1000),\n   ])),\n ]))\n\n\n decode.run(data, decoder)\n // -&gt; Ok(1000)\n \n\n \n dynamic.from(Nil)\n |&gt; decode.run(decode.optional(decode.int))\n // -&gt; Ok(option.None)\n \n\nSynonyms:\ngleam/dynamic/decode.at\ngleam/dynamic/decode at","url":"gleam/dynamic/decode.html#at"},{"doc":"gleam/dynamic/decode","title":"collapse_errors","content":"pub fn collapse_errors(\n  decoder: Decoder(a),\n  name: String,\n) -&gt; Decoder(a)\n Replace all errors produced by a decoder with one single error for a named\n expected type.\n\n This function may be useful if you wish to simplify errors before\n presenting them to a user, particularly when using the `one_of` function.\n\n # Examples\n\n \n let decoder = decode.string |&gt; decode.collapse_errors(&quot;MyThing&quot;)\n let result = decode.run(dynamic.from(1000), decoder)\n assert result == Error([DecodeError(&quot;MyThing&quot;, &quot;Int&quot;, [])])\n \n\nSynonyms:\ngleam/dynamic/decode.collapse_errors\ngleam/dynamic/decode collapse_errors","url":"gleam/dynamic/decode.html#collapse_errors"},{"doc":"gleam/dynamic/decode","title":"decode_error","content":"pub fn decode_error(\n  expected expected: String,\n  found found: Dynamic,\n) -&gt; List(DecodeError)\n Construct a decode error for some unexpected dynamic data.\n\nSynonyms:\ngleam/dynamic/decode.decode_error\ngleam/dynamic/decode decode_error","url":"gleam/dynamic/decode.html#decode_error"},{"doc":"gleam/dynamic/decode","title":"dict","content":"pub fn dict(\n  key: Decoder(a),\n  value: Decoder(b),\n) -&gt; Decoder(Dict(a, b))\n A decoder that decodes dicts where all keys and vales are decoded with\n given decoders.\n\n # Examples\n\n \n let values = dict.from_list([\n   #(&quot;one&quot;, 1),\n   #(&quot;two&quot;, 2),\n ])\n\n let result =\n   decode.run(dynamic.from(values), decode.dict(decode.string, decode.int))\n assert result == Ok(values)\n \n\nSynonyms:\ngleam/dynamic/decode.dict\ngleam/dynamic/decode dict","url":"gleam/dynamic/decode.html#dict"},{"doc":"gleam/dynamic/decode","title":"failure","content":"pub fn failure(zero: a, expected: String) -&gt; Decoder(a)\n Define a decoder that always fails. The parameter for this function is the\n name of the type that has failed to decode.\n\nSynonyms:\ngleam/dynamic/decode.failure\ngleam/dynamic/decode failure","url":"gleam/dynamic/decode.html#failure"},{"doc":"gleam/dynamic/decode","title":"field","content":"pub fn field(\n  field_name: a,\n  field_decoder: Decoder(b),\n  next: fn(b) -&gt; Decoder(c),\n) -&gt; Decoder(c)\n Run a decoder on a field of a `Dynamic` value, decoding the value if it is\n of the desired type, or returning errors. An error is returned if there is\n no field for the specified key.\n\n This function will index into dictionaries with any key type, and if the key is\n an int then it&#39;ll also index into Erlang tuples and JavaScript arrays, and\n the first two elements of Gleam lists.\n\n # Examples\n\n \n let data = dynamic.from(dict.from_list([\n   #(&quot;email&quot;, &quot;lucy@example.com&quot;),\n   #(&quot;name&quot;, &quot;Lucy&quot;),\n ]))\n\n let decoder = {\n   use name &lt;- decode.field(&quot;name&quot;, string)\n   use email &lt;- decode.field(&quot;email&quot;, string)\n   decode.success(SignUp(name: name, email: email))\n }\n\n let result = decode.run(data, decoder)\n assert result == Ok(SignUp(name: &quot;Lucy&quot;, email: &quot;lucy@example.com&quot;))\n \n\n If you wish to decode a value that is more deeply nested within the dynamic\n data, see [`subfield`](#subfield) and [`at`](#at).\n\n If you wish to return a default in the event that a field is not present,\n see [`optional_field`](#optional_field) and / [`optionally_at`](#optionally_at).\n\nSynonyms:\ngleam/dynamic/decode.field\ngleam/dynamic/decode field","url":"gleam/dynamic/decode.html#field"},{"doc":"gleam/dynamic/decode","title":"list","content":"pub fn list(of inner: Decoder(a)) -&gt; Decoder(List(a))\n A decoder that decodes lists where all elements are decoded with a given\n decoder.\n\n # Examples\n\n \n let result =\n   decode.run(dynamic.from([1, 2, 3]), decode.list(of: decode.int))\n assert result == Ok([1, 2, 3])\n \n\nSynonyms:\ngleam/dynamic/decode.list\ngleam/dynamic/decode list","url":"gleam/dynamic/decode.html#list"},{"doc":"gleam/dynamic/decode","title":"map","content":"pub fn map(\n  decoder: Decoder(a),\n  transformer: fn(a) -&gt; b,\n) -&gt; Decoder(b)\n Apply a transformation function to any value decoded by the decoder.\n\n # Examples\n\n \n let decoder = decode.int |&gt; decode.map(int.to_string)\n let result = decode.run(dynamic.from(1000), decoder)\n assert result == Ok(&quot;1000&quot;)\n \n\nSynonyms:\ngleam/dynamic/decode.map\ngleam/dynamic/decode map","url":"gleam/dynamic/decode.html#map"},{"doc":"gleam/dynamic/decode","title":"map_errors","content":"pub fn map_errors(\n  decoder: Decoder(a),\n  transformer: fn(List(DecodeError)) -&gt; List(DecodeError),\n) -&gt; Decoder(a)\n Apply a transformation function to any errors returned by the decoder.\n\nSynonyms:\ngleam/dynamic/decode.map_errors\ngleam/dynamic/decode map_errors","url":"gleam/dynamic/decode.html#map_errors"},{"doc":"gleam/dynamic/decode","title":"new_primitive_decoder","content":"pub fn new_primitive_decoder(\n  name: String,\n  decoding_function: fn(Dynamic) -&gt; Result(a, a),\n) -&gt; Decoder(a)\n Create a decoder for a new data type from a decoding function.\n\n This function is used for new primitive types. For example, you might\n define a decoder for Erlang&#39;s pid type.\n\n A default &quot;zero&quot; value is also required to make a decoder. When this\n decoder is used as part of a larger decoder this zero value used as\n a placeholder so that the rest of the decoder can continue to run and\n collect all decoding errors.\n\n If you were to make a decoder for the `String` type (rather than using the\n build-in `string` decoder) you would define it like so:\n\n \n pub fn string_decoder() -&gt; decode.Decoder(String) {\n   let default = &quot;&quot;\n   decode.new_primitive_decoder(&quot;String&quot;, fn(data) {\n     case dynamic.string(data) {\n       Ok(x) -&gt; Ok(x)\n       Error(_) -&gt; Error(default)\n     }\n   })\n }\n \n\nSynonyms:\ngleam/dynamic/decode.new_primitive_decoder\ngleam/dynamic/decode new_primitive_decoder","url":"gleam/dynamic/decode.html#new_primitive_decoder"},{"doc":"gleam/dynamic/decode","title":"one_of","content":"pub fn one_of(\n  first: Decoder(a),\n  or alternatives: List(Decoder(a)),\n) -&gt; Decoder(a)\n Create a new decoder from several other decoders. Each of the inner\n decoders is run in turn, and the value from the first to succeed is used.\n\n If no decoder succeeds then the errors from the first decoder is used.\n If you wish for different errors then you may wish to use the\n `collapse_errors` or `map_errors` functions.\n\n # Examples\n\n \n let decoder = decode.one_of(decode.string, or: [\n   decode.int |&gt; decode.map(int.to_string),\n   decode.float |&gt; decode.map(float.to_string),\n ])\n decode.run(dynamic.from(1000), decoder)\n // -&gt; Ok(&quot;1000&quot;)\n \n\nSynonyms:\ngleam/dynamic/decode.one_of\ngleam/dynamic/decode one_of","url":"gleam/dynamic/decode.html#one_of"},{"doc":"gleam/dynamic/decode","title":"optional","content":"pub fn optional(inner: Decoder(a)) -&gt; Decoder(Option(a))\n A decoder that decodes nullable values of a type decoded by with a given\n decoder.\n\n This function can handle common representations of null on all runtimes, such as\n `nil`, `null`, and `undefined` on Erlang, and `undefined` and `null` on\n JavaScript.\n\n # Examples\n\n \n let result = decode.run(dynamic.from(100), decode.optional(decode.int))\n assert result == Ok(option.Some(100))\n \n\n \n let result = decode.run(dynamic.from(Nil), decode.optional(decode.int))\n assert result == Ok(option.None)\n \n\nSynonyms:\ngleam/dynamic/decode.optional\ngleam/dynamic/decode optional","url":"gleam/dynamic/decode.html#optional"},{"doc":"gleam/dynamic/decode","title":"optional_field","content":"pub fn optional_field(\n  key: a,\n  default: b,\n  field_decoder: Decoder(b),\n  next: fn(b) -&gt; Decoder(c),\n) -&gt; Decoder(c)\n Run a decoder on a field of a `Dynamic` value, decoding the value if it is\n of the desired type, or returning errors. The given default value is\n returned if there is no field for the specified key.\n\n This function will index into dictionaries with any key type, and if the key is\n an int then it&#39;ll also index into Erlang tuples and JavaScript arrays, and\n the first two elements of Gleam lists.\n\n # Examples\n\n \n let data = dynamic.from(dict.from_list([\n   #(&quot;name&quot;, &quot;Lucy&quot;),\n ]))\n\n let decoder = {\n   use name &lt;- decode.field(&quot;name&quot;, string)\n   use email &lt;- decode.optional_field(&quot;email&quot;, &quot;n/a&quot;, string)\n   decode.success(SignUp(name: name, email: email))\n }\n\n let result = decode.run(data, decoder)\n assert result == Ok(SignUp(name: &quot;Lucy&quot;, email: &quot;n/a&quot;))\n \n\nSynonyms:\ngleam/dynamic/decode.optional_field\ngleam/dynamic/decode optional_field","url":"gleam/dynamic/decode.html#optional_field"},{"doc":"gleam/dynamic/decode","title":"optionally_at","content":"pub fn optionally_at(\n  path: List(a),\n  default: b,\n  inner: Decoder(b),\n) -&gt; Decoder(b)\n A decoder that decodes a value that is nested within other values. For\n example, decoding a value that is within some deeply nested JSON objects.\n\n This function will index into dictionaries with any key type, and if the key is\n an int then it&#39;ll also index into Erlang tuples and JavaScript arrays, and\n the first two elements of Gleam lists.\n\n # Examples\n\n \n let decoder = decode.optionally_at([&quot;one&quot;, &quot;two&quot;], 100, decode.int)\n\n let data = dynamic.from(dict.from_list([\n   #(&quot;one&quot;, dict.from_list([])),\n ]))\n\n\n decode.run(data, decoder)\n // -&gt; Ok(100)\n \n\nSynonyms:\ngleam/dynamic/decode.optionally_at\ngleam/dynamic/decode optionally_at","url":"gleam/dynamic/decode.html#optionally_at"},{"doc":"gleam/dynamic/decode","title":"recursive","content":"pub fn recursive(inner: fn() -&gt; Decoder(a)) -&gt; Decoder(a)\n Create a decoder that can refer to itself, useful for decoding deeply\n nested data.\n\n Attempting to create a recursive decoder without this function could result\n in an infinite loop. If you are using `field` or other `use`able functions\n then you may not need to use this function.\n\n \n type Nested {\n   Nested(List(Nested))\n   Value(String)\n }\n\n fn nested_decoder() -&gt; decode.Decoder(Nested) {\n   use &lt;- decode.recursive\n   decode.one_of(decode.string |&gt; decode.map(Value), [\n     decode.list(nested_decoder()) |&gt; decode.map(Nested),\n   ])\n }\n \n\nSynonyms:\ngleam/dynamic/decode.recursive\ngleam/dynamic/decode recursive","url":"gleam/dynamic/decode.html#recursive"},{"doc":"gleam/dynamic/decode","title":"run","content":"pub fn run(\n  data: Dynamic,\n  decoder: Decoder(a),\n) -&gt; Result(a, List(DecodeError))\n Run a decoder on a `Dynamic` value, decoding the value if it is of the\n desired type, or returning errors.\n\n # Examples\n\n \n let decoder = {\n   use name &lt;- decode.field(&quot;email&quot;, decode.string)\n   use email &lt;- decode.field(&quot;password&quot;, decode.string)\n   decode.success(SignUp(name: name, email: email))\n }\n\n decode.run(data, decoder)\n \n\nSynonyms:\ngleam/dynamic/decode.run\ngleam/dynamic/decode run","url":"gleam/dynamic/decode.html#run"},{"doc":"gleam/dynamic/decode","title":"subfield","content":"pub fn subfield(\n  field_path: List(a),\n  field_decoder: Decoder(b),\n  next: fn(b) -&gt; Decoder(c),\n) -&gt; Decoder(c)\n The same as [`field`](#field), except taking a path to the value rather\n than a field name.\n\n This function will index into dictionaries with any key type, and if the key is\n an int then it&#39;ll also index into Erlang tuples and JavaScript arrays, and\n the first two elements of Gleam lists.\n\n # Examples\n\n \n let data = dynamic.from(dict.from_list([\n   #(&quot;data&quot;, dict.from_list([\n     #(&quot;email&quot;, &quot;lucy@example.com&quot;),\n     #(&quot;name&quot;, &quot;Lucy&quot;),\n   ]))\n ]))\n\n let decoder = {\n   use name &lt;- decode.subfield([&quot;data&quot;, &quot;name&quot;], decode.string)\n   use email &lt;- decode.subfield([&quot;data&quot;, &quot;email&quot;], decode.string)\n   decode.success(SignUp(name: name, email: email))\n }\n let result = decode.run(data, decoder)\n assert result == Ok(SignUp(name: &quot;Lucy&quot;, email: &quot;lucy@example.com&quot;))\n \n\nSynonyms:\ngleam/dynamic/decode.subfield\ngleam/dynamic/decode subfield","url":"gleam/dynamic/decode.html#subfield"},{"doc":"gleam/dynamic/decode","title":"success","content":"pub fn success(data: a) -&gt; Decoder(a)\n Finalise a decoder having successfully extracted a value.\n\n # Examples\n\n \n let data = dynamic.from(dict.from_list([\n   #(&quot;email&quot;, &quot;lucy@example.com&quot;),\n   #(&quot;name&quot;, &quot;Lucy&quot;),\n ]))\n\n let decoder = {\n   use name &lt;- decode.field(&quot;name&quot;, string)\n   use email &lt;- decode.field(&quot;email&quot;, string)\n   decode.success(SignUp(name: name, email: email))\n }\n\n let result = decode.run(data, decoder)\n assert result == Ok(SignUp(name: &quot;Lucy&quot;, email: &quot;lucy@example.com&quot;))\n \n\nSynonyms:\ngleam/dynamic/decode.success\ngleam/dynamic/decode success","url":"gleam/dynamic/decode.html#success"},{"doc":"gleam/dynamic/decode","title":"then","content":"pub fn then(\n  decoder: Decoder(a),\n  next: fn(a) -&gt; Decoder(b),\n) -&gt; Decoder(b)\n Create a new decoder based upon the value of a previous decoder.\n\n This may be useful to run one previous decoder to use in further decoding.\n\nSynonyms:\ngleam/dynamic/decode.then\ngleam/dynamic/decode then","url":"gleam/dynamic/decode.html#then"},{"doc":"gleam/dynamic/decode","title":"gleam/dynamic/decode","content":" The `Dynamic` type is used to represent dynamically typed data. That is, data\n that we don&#39;t know the precise type of yet, so we need to introspect the data to\n see if it is of the desired type before we can use it. Typically data like this\n would come from user input or from untyped languages such as Erlang or JavaScript.\n\n This module provides the `Decoder` type and associated functions, which provides\n a type-safe and composable way to convert dynamic data into some desired type,\n or into errors if the data doesn&#39;t have the desired structure.\n\n The `Decoder` type is generic and has 1 type parameter, which is the type that\n it attempts to decode. A `Decoder(String)` can be used to decode strings, and a\n `Decoder(Option(Int))` can be used to decode `Option(Int)`s\n\n Decoders work using _runtime reflection_ and the data structures of the target\n platform. Differences between Erlang and JavaScript data structures may impact\n your decoders, so it is important to test your decoders on all supported\n platforms.\n\n The decoding technique used by this module was inspired by Juraj Petráš&#39;\n [Toy](https://github.com/Hackder/toy), Go&#39;s `encoding/json`, and Elm&#39;s\n `Json.Decode`. Thank you to them!\n\n # Examples\n\n Dynamic data may come from various sources and so many different syntaxes could\n be used to describe or construct them. In these examples a pseudocode\n syntax is used to describe the data.\n\n ## Simple types\n\n This module defines decoders for simple data types such as [`string`](#string),\n [`int`](#int), [`float`](#float), [`bit_array`](#bit_array), and [`bool`](#bool).\n\n ```gleam\n // Data:\n // &quot;Hello, Joe!&quot;\n\n let result = decode.run(data, decode.string)\n assert result == Ok(&quot;Hello, Joe!&quot;)\n ```\n\n ## Lists\n\n The [`list`](#list) decoder decodes `List`s. To use it you must construct it by\n passing in another decoder into the `list` function, which is the decoder that\n is to be used for the elements of the list, type checking both the list and its\n elements.\n\n ```gleam\n // Data:\n // [1, 2, 3, 4]\n\n let result = decode.run(data, decode.list(decode.int))\n assert result == Ok([1, 2, 3, 4])\n ```\n\n On Erlang this decoder can decode from lists, and on JavaScript it can\n decode from lists as well as JavaScript arrays.\n\n ## Options\n\n The [`optional`](#optional) decoder is used to decode values that may or may not\n be present. In other environment these might be called &quot;nullable&quot; values.\n\n Like the `list` decoder, the `optional` decoder takes another decoder,\n which is used to decode the value if it is present.\n\n ```gleam\n // Data:\n // 12.45\n\n let result = decode.run(data, decode.optional(decode.float))\n assert result == Ok(option.Some(12.45))\n ```\n ```gleam\n // Data:\n // null\n\n let result = decode.run(data, decode.optional(decode.int))\n assert result == Ok(option.None)\n ```\n\n This decoder knows how to handle multiple different runtime representations of\n absent values, including `Nil`, `None`, `null`, and `undefined`.\n\n ## Dicts\n\n The [`dict`](#dict) decoder decodes `Dicts` and contains two other decoders, one\n for the keys, one for the values.\n\n ```gleam\n // Data:\n // { &quot;Lucy&quot; -&gt; 10, &quot;Nubi&quot; -&gt; 20 }\n\n let result = decode.run(data, decode.dict(decode.string, decode.int))\n assert result == Ok(dict.from_list([\n   #(&quot;Lucy&quot;, 10),\n   #(&quot;Nubi&quot;, 20),\n ]))\n ```\n\n ## Indexing objects\n\n The [`at`](#at) decoder can be used to decode a value that is nested within\n key-value containers such as Gleam dicts, Erlang maps, or JavaScript objects.\n\n ```gleam\n // Data:\n // { &quot;one&quot; -&gt; { &quot;two&quot; -&gt; 123 } }\n\n let result = decode.run(data, decode.at([&quot;one&quot;, &quot;two&quot;], decode.int))\n assert result == Ok(123)\n ```\n\n ## Indexing arrays\n\n If you use ints as keys then the [`at`](#at) decoder can be used to index into\n array-like containers such as Gleam or Erlang tuples, or JavaScript arrays.\n\n ```gleam\n // Data:\n // [&quot;one&quot;, &quot;two&quot;, &quot;three&quot;]\n\n let result = decode.run(data, decode.at([1], decode.string))\n assert result == Ok(&quot;two&quot;)\n ```\n\n ## Records\n\n Decoding records from dynamic data is more complex and requires combining a\n decoder for each field and a special constructor that builds your records with\n the decoded field values.\n\n ```gleam\n // Data:\n // {\n //   &quot;score&quot; -&gt; 180,\n //   &quot;name&quot; -&gt; &quot;Mel Smith&quot;,\n //   &quot;is-admin&quot; -&gt; false,\n //   &quot;enrolled&quot; -&gt; true,\n //   &quot;colour&quot; -&gt; &quot;Red&quot;,\n // }\n\n let decoder = {\n   use name &lt;- decode.field(&quot;name&quot;, decode.string)\n   use score &lt;- decode.field(&quot;score&quot;, decode.int)\n   use colour &lt;- decode.field(&quot;colour&quot;, decode.string)\n   use enrolled &lt;- decode.field(&quot;enrolled&quot;, decode.bool)\n   decode.success(Player(name:, score:, colour:, enrolled:))\n }\n\n let result = decode.run(data, decoder)\n assert result == Ok(Player(&quot;Mel Smith&quot;, 180, &quot;Red&quot;, True))\n ```\n\n ## Enum variants\n\n Imagine you have a custom type where all the variants do not contain any values.\n\n ```gleam\n pub type PocketMonsterType {\n   Fire\n   Water\n   Grass\n   Electric\n }\n ```\n\n You might choose to encode these variants as strings, `&quot;fire&quot;` for `Fire`,\n `&quot;water&quot;` for `Water`, and so on. To decode them you&#39;ll need to decode the dynamic\n data as a string, but then you&#39;ll need to decode it further still as not all\n strings are valid values for the enum. This can be done with the `then`\n function, which enables running a second decoder after the first one\n succeeds.\n\n ```gleam\n let decoder = {\n   use decoded_string &lt;- decode.then(decode.string)\n   case decoded_string {\n     // Return succeeding decoders for valid strings\n     &quot;fire&quot; -&gt; decode.success(Fire)\n     &quot;water&quot; -&gt; decode.success(Water)\n     &quot;grass&quot; -&gt; decode.success(Grass)\n     &quot;electric&quot; -&gt; decode.success(Electric)\n     // Return a failing decoder for any other strings\n     _ -&gt; decode.failure(Fire, &quot;PocketMonsterType&quot;)\n   }\n }\n\n let result = decode.run(dynamic.from(&quot;water&quot;), decoder)\n assert result == Ok(Water)\n\n let result = decode.run(dynamic.from(&quot;wobble&quot;), decoder)\n assert result == Error([DecodeError(&quot;PocketMonsterType&quot;, &quot;String&quot;, [])])\n ```\n\n ## Record variants\n\n Decoding type variants that contain other values is done by combining the\n techniques from the &quot;enum variants&quot; and &quot;records&quot; examples. Imagine you have\n this custom type that you want to decode:\n\n ```gleam\n pub type PocketMonsterPerson {\n   Trainer(name: String, badge_count: Int)\n   GymLeader(name: String, speciality: PocketMonsterType)\n }\n ```\n And you would like to be able to decode these from dynamic data like this:\n ```erlang\n {\n   &quot;type&quot; -&gt; &quot;trainer&quot;,\n   &quot;name&quot; -&gt; &quot;Ash&quot;,\n   &quot;badge-count&quot; -&gt; 1,\n }\n ```\n ```erlang\n {\n   &quot;type&quot; -&gt; &quot;gym-leader&quot;,\n   &quot;name&quot; -&gt; &quot;Misty&quot;,\n   &quot;speciality&quot; -&gt; &quot;water&quot;,\n }\n ```\n\n Notice how both documents have a `&quot;type&quot;` field, which is used to indicate which\n variant the data is for.\n\n First, define decoders for each of the variants:\n\n ```gleam\n let trainer_decoder = {\n   use name &lt;- decode.field(&quot;name&quot;, decode.string)\n   use badge_count &lt;- decode.field(&quot;badge-count&quot;, decode.int)\n   decode.success(Trainer(name, badge_count))\n })\n\n let gym_leader_decoder = {\n   use name &lt;- decode.field(&quot;name&quot;, decode.string)\n   use speciality &lt;- decode.field(&quot;speciality&quot;, pocket_monster_type_decoder)\n   decode.success(GymLeader(name, speciality))\n }\n ```\n\n A third decoder can be used to extract and decode the `&quot;type&quot;` field, and the\n `then` function then returns whichever decoder is suitable for the document.\n\n ```gleam\n let decoder = {\n   use tag &lt;- decode.field(&quot;type&quot;, decode.string)\n   case tag {\n     &quot;gym-leader&quot; -&gt; gym_leader_decoder\n     _ -&gt; trainer_decoder\n   }\n }\n\n decode.run(data, decoder)\n ```","url":"gleam/dynamic/decode.html"},{"doc":"gleam/function","title":"flip","content":"pub fn flip(fun: fn(a, b) -&gt; c) -&gt; fn(b, a) -&gt; c\n Takes a function that takes two arguments and returns a new function that\n takes the same two arguments, but in reverse order.\n\nSynonyms:\ngleam/function.flip\ngleam/function flip","url":"gleam/function.html#flip"},{"doc":"gleam/function","title":"identity","content":"pub fn identity(x: a) -&gt; a\n Takes a single argument and always returns its input value.\n\nSynonyms:\ngleam/function.identity\ngleam/function identity","url":"gleam/function.html#identity"},{"doc":"gleam/function","title":"tap","content":"pub fn tap(arg: a, effect: fn(a) -&gt; b) -&gt; a\n Takes an argument and a single function,\n calls that function with that argument\n and returns that argument instead of the function return value.\n Useful for running synchronous side effects in a pipeline.\n\nSynonyms:\ngleam/function.tap\ngleam/function tap","url":"gleam/function.html#tap"},{"doc":"gleam/function","title":"gleam/function","content":"","url":"gleam/function.html"},{"doc":"gleam/io","title":"debug","content":"pub fn debug(term: a) -&gt; a\n Writes a value to standard error (stderr) yielding Gleam syntax.\n\n The value is returned after being printed so it can be used in pipelines.\n\n ## Example\n\n \n debug(&quot;Hi mum&quot;)\n // -&gt; &quot;Hi mum&quot;\n // &lt;&lt;&quot;Hi mum&quot;&gt;&gt;\n \n\n \n debug(Ok(1))\n // -&gt; Ok(1)\n // {ok, 1}\n \n\n \n import gleam/list\n\n [1, 2]\n |&gt; list.map(fn(x) { x + 1 })\n |&gt; debug\n |&gt; list.map(fn(x) { x * 2 })\n // -&gt; [4, 6]\n // [2, 3]\n \n\n Note: At runtime Gleam doesn&#39;t have type information anymore. This combined\n with some types having the same runtime representation results in it not\n always being possible to correctly choose which Gleam syntax to show.\n\nSynonyms:\ngleam/io.debug\ngleam/io debug","url":"gleam/io.html#debug"},{"doc":"gleam/io","title":"print","content":"pub fn print(string: String) -&gt; Nil\n Writes a string to standard output (stdout).\n\n If you want your output to be printed on its own line see `println`.\n\n ## Example\n\n \n io.print(&quot;Hi mum&quot;)\n // -&gt; Nil\n // Hi mum\n \n\nSynonyms:\ngleam/io.print\ngleam/io print","url":"gleam/io.html#print"},{"doc":"gleam/io","title":"print_error","content":"pub fn print_error(string: String) -&gt; Nil\n Writes a string to standard error (stderr).\n\n If you want your output to be printed on its own line see `println_error`.\n\n ## Example\n\n \n io.print_error(&quot;Hi pop&quot;)\n // -&gt; Nil\n // Hi pop\n \n\nSynonyms:\ngleam/io.print_error\ngleam/io print_error","url":"gleam/io.html#print_error"},{"doc":"gleam/io","title":"println","content":"pub fn println(string: String) -&gt; Nil\n Writes a string to standard output (stdout), appending a newline to the end.\n\n ## Example\n\n \n io.println(&quot;Hi mum&quot;)\n // -&gt; Nil\n // Hi mum\n \n\nSynonyms:\ngleam/io.println\ngleam/io println","url":"gleam/io.html#println"},{"doc":"gleam/io","title":"println_error","content":"pub fn println_error(string: String) -&gt; Nil\n Writes a string to standard error (stderr), appending a newline to the end.\n\n ## Example\n\n \n io.println_error(&quot;Hi pop&quot;)\n // -&gt; Nil\n // Hi pop\n \n\nSynonyms:\ngleam/io.println_error\ngleam/io println_error","url":"gleam/io.html#println_error"},{"doc":"gleam/io","title":"gleam/io","content":"","url":"gleam/io.html"},{"doc":"gleam/set","title":"Set","content":"pub opaque type Set(member)\n A set is a collection of unique members of the same type.\n\n It is implemented using the `gleam/dict` module, so inserts and lookups have\n logarithmic time complexity.\n\n\nSynonyms:\ngleam/set.Set\ngleam/set Set","url":"gleam/set.html#Set"},{"doc":"gleam/set","title":"contains","content":"pub fn contains(in set: Set(a), this member: a) -&gt; Bool\n Checks whether a set contains a given member.\n\n This function runs in logarithmic time.\n\n ## Examples\n\n \n new()\n |&gt; insert(2)\n |&gt; contains(2)\n // -&gt; True\n \n\n \n new()\n |&gt; insert(2)\n |&gt; contains(1)\n // -&gt; False\n \n\nSynonyms:\ngleam/set.contains\ngleam/set contains","url":"gleam/set.html#contains"},{"doc":"gleam/set","title":"delete","content":"pub fn delete(from set: Set(a), this member: a) -&gt; Set(a)\n Removes a member from a set. If the set does not contain the member then\n the set is returned unchanged.\n\n This function runs in logarithmic time.\n\n ## Examples\n\n \n new()\n |&gt; insert(2)\n |&gt; delete(2)\n |&gt; contains(1)\n // -&gt; False\n \n\nSynonyms:\ngleam/set.delete\ngleam/set delete","url":"gleam/set.html#delete"},{"doc":"gleam/set","title":"difference","content":"pub fn difference(\n  from first: Set(a),\n  minus second: Set(a),\n) -&gt; Set(a)\n Creates a new set that contains members that are present in the first set\n but not the second.\n\n ## Examples\n\n \n difference(from_list([1, 2]), from_list([2, 3, 4])) |&gt; to_list\n // -&gt; [1]\n \n\nSynonyms:\ngleam/set.difference\ngleam/set difference","url":"gleam/set.html#difference"},{"doc":"gleam/set","title":"drop","content":"pub fn drop(from set: Set(a), drop disallowed: List(a)) -&gt; Set(a)\n Creates a new set from a given set with all the same entries except any\n entry found on the given list.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4])\n |&gt; drop([1, 3])\n |&gt; to_list\n // -&gt; [2, 4]\n \nSynonyms:\ngleam/set.drop\ngleam/set drop","url":"gleam/set.html#drop"},{"doc":"gleam/set","title":"each","content":"pub fn each(set: Set(a), fun: fn(a) -&gt; b) -&gt; Nil\n Calls a function for each member in a set, discarding the return\n value.\n\n Useful for producing a side effect for every item of a set.\n\n \n let set = from_list([&quot;apple&quot;, &quot;banana&quot;, &quot;cherry&quot;])\n\n each(set, io.println)\n // -&gt; Nil\n // apple\n // banana\n // cherry\n \n\n The order of elements in the iteration is an implementation detail that\n should not be relied upon.\n\nSynonyms:\ngleam/set.each\ngleam/set each","url":"gleam/set.html#each"},{"doc":"gleam/set","title":"filter","content":"pub fn filter(\n  in set: Set(a),\n  keeping predicate: fn(a) -&gt; Bool,\n) -&gt; Set(a)\n Creates a new set from an existing set, minus any members that a given\n function returns `False` for.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n import gleam/int\n\n from_list([1, 4, 6, 3, 675, 44, 67])\n |&gt; filter(keeping: int.is_even)\n |&gt; to_list\n // -&gt; [4, 6, 44]\n \n\nSynonyms:\ngleam/set.filter\ngleam/set filter","url":"gleam/set.html#filter"},{"doc":"gleam/set","title":"fold","content":"pub fn fold(\n  over set: Set(a),\n  from initial: b,\n  with reducer: fn(b, a) -&gt; b,\n) -&gt; b\n Combines all entries into a single value by calling a given function on each\n one.\n\n Sets are not ordered so the values are not returned in any specific order.\n Do not write code that relies on the order entries are used by this\n function as it may change in later versions of Gleam or Erlang.\n\n # Examples\n\n \n from_list([1, 3, 9])\n |&gt; fold(0, fn(accumulator, member) { accumulator + member })\n // -&gt; 13\n \n\nSynonyms:\ngleam/set.fold\ngleam/set fold","url":"gleam/set.html#fold"},{"doc":"gleam/set","title":"from_list","content":"pub fn from_list(members: List(a)) -&gt; Set(a)\n Creates a new set of the members in a given list.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n import gleam/int\n import gleam/list\n\n [1, 1, 2, 4, 3, 2] |&gt; from_list |&gt; to_list |&gt; list.sort(by: int.compare)\n // -&gt; [1, 2, 3, 4]\n \n\nSynonyms:\ngleam/set.from_list\ngleam/set from_list","url":"gleam/set.html#from_list"},{"doc":"gleam/set","title":"insert","content":"pub fn insert(into set: Set(a), this member: a) -&gt; Set(a)\n Inserts an member into the set.\n\n This function runs in logarithmic time.\n\n ## Examples\n\n \n new()\n |&gt; insert(1)\n |&gt; insert(2)\n |&gt; size\n // -&gt; 2\n \n\nSynonyms:\ngleam/set.insert\ngleam/set insert","url":"gleam/set.html#insert"},{"doc":"gleam/set","title":"intersection","content":"pub fn intersection(\n  of first: Set(a),\n  and second: Set(a),\n) -&gt; Set(a)\n Creates a new set that contains members that are present in both given sets.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n intersection(from_list([1, 2]), from_list([2, 3])) |&gt; to_list\n // -&gt; [2]\n \n\nSynonyms:\ngleam/set.intersection\ngleam/set intersection","url":"gleam/set.html#intersection"},{"doc":"gleam/set","title":"is_disjoint","content":"pub fn is_disjoint(first: Set(a), from second: Set(a)) -&gt; Bool\n Determines if two sets contain no common members\n\n ## Examples\n\n \n is_disjoint(from_list([1, 2, 3]), from_list([4, 5, 6]))\n // -&gt; True\n \n\n \n is_disjoint(from_list([1, 2, 3]), from_list([3, 4, 5]))\n // -&gt; False\n \n\nSynonyms:\ngleam/set.is_disjoint\ngleam/set is_disjoint","url":"gleam/set.html#is_disjoint"},{"doc":"gleam/set","title":"is_empty","content":"pub fn is_empty(set: Set(a)) -&gt; Bool\n Determines whether or not the set is empty.\n\n ## Examples\n\n \n new() |&gt; is_empty\n // -&gt; True\n \n\n \n new() |&gt; insert(1) |&gt; is_empty\n // -&gt; False\n \n\nSynonyms:\ngleam/set.is_empty\ngleam/set is_empty","url":"gleam/set.html#is_empty"},{"doc":"gleam/set","title":"is_subset","content":"pub fn is_subset(first: Set(a), of second: Set(a)) -&gt; Bool\n Determines if a set is fully contained by another.\n\n ## Examples\n\n \n is_subset(from_list([1]), from_list([1, 2]))\n // -&gt; True\n \n\n \n is_subset(from_list([1, 2, 3]), from_list([3, 4, 5]))\n // -&gt; False\n \n\nSynonyms:\ngleam/set.is_subset\ngleam/set is_subset","url":"gleam/set.html#is_subset"},{"doc":"gleam/set","title":"map","content":"pub fn map(set: Set(a), with fun: fn(a) -&gt; b) -&gt; Set(b)\n Creates a new set from a given set with the result of applying the given\n function to each member.\n\n ## Examples\n\n \n from_list([1, 2, 3, 4])\n |&gt; map(with: fn(x) { x * 2 })\n |&gt; to_list\n // -&gt; [2, 4, 6, 8]\n \nSynonyms:\ngleam/set.map\ngleam/set map","url":"gleam/set.html#map"},{"doc":"gleam/set","title":"new","content":"pub fn new() -&gt; Set(a)\n Creates a new empty set.\n\nSynonyms:\ngleam/set.new\ngleam/set new","url":"gleam/set.html#new"},{"doc":"gleam/set","title":"size","content":"pub fn size(set: Set(a)) -&gt; Int\n Gets the number of members in a set.\n\n This function runs in constant time.\n\n ## Examples\n\n \n new()\n |&gt; insert(1)\n |&gt; insert(2)\n |&gt; size\n // -&gt; 2\n \n\nSynonyms:\ngleam/set.size\ngleam/set size","url":"gleam/set.html#size"},{"doc":"gleam/set","title":"symmetric_difference","content":"pub fn symmetric_difference(\n  of first: Set(a),\n  and second: Set(a),\n) -&gt; Set(a)\n Creates a new set that contains members that are present in either set, but\n not both.\n\n \n symmetric_difference(from_list([1, 2, 3]), from_list([3, 4])) |&gt; to_list\n // -&gt; [1, 2, 4]\n \n\nSynonyms:\ngleam/set.symmetric_difference\ngleam/set symmetric_difference","url":"gleam/set.html#symmetric_difference"},{"doc":"gleam/set","title":"take","content":"pub fn take(from set: Set(a), keeping desired: List(a)) -&gt; Set(a)\n Creates a new set from a given set, only including any members which are in\n a given list.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n from_list([1, 2, 3])\n |&gt; take([1, 3, 5])\n |&gt; to_list\n // -&gt; [1, 3]\n \n\nSynonyms:\ngleam/set.take\ngleam/set take","url":"gleam/set.html#take"},{"doc":"gleam/set","title":"to_list","content":"pub fn to_list(set: Set(a)) -&gt; List(a)\n Converts the set into a list of the contained members.\n\n The list has no specific ordering, any unintentional ordering may change in\n future versions of Gleam or Erlang.\n\n This function runs in linear time.\n\n ## Examples\n\n \n new() |&gt; insert(2) |&gt; to_list\n // -&gt; [2]\n \n\nSynonyms:\ngleam/set.to_list\ngleam/set to_list","url":"gleam/set.html#to_list"},{"doc":"gleam/set","title":"union","content":"pub fn union(of first: Set(a), and second: Set(a)) -&gt; Set(a)\n Creates a new set that contains all members of both given sets.\n\n This function runs in loglinear time.\n\n ## Examples\n\n \n union(from_list([1, 2]), from_list([2, 3])) |&gt; to_list\n // -&gt; [1, 2, 3]\n \n\nSynonyms:\ngleam/set.union\ngleam/set union","url":"gleam/set.html#union"},{"doc":"gleam/set","title":"gleam/set","content":"","url":"gleam/set.html"},{"doc":"gleam/uri","title":"Uri","content":"pub type Uri {\n  Uri(\n    scheme: Option(String),\n    userinfo: Option(String),\n    host: Option(String),\n    port: Option(Int),\n    path: String,\n    query: Option(String),\n    fragment: Option(String),\n  )\n}\n Type representing holding the parsed components of an URI.\n All components of a URI are optional, except the path.\n\nUri(\n  scheme: Option(String),\n  userinfo: Option(String),\n  host: Option(String),\n  port: Option(Int),\n  path: String,\n  query: Option(String),\n  fragment: Option(String),\n)\n\n\nSynonyms:\ngleam/uri.Uri\ngleam/uri Uri","url":"gleam/uri.html#Uri"},{"doc":"gleam/uri","title":"merge","content":"pub fn merge(base: Uri, relative: Uri) -&gt; Result(Uri, Nil)\n Resolves a URI with respect to the given base URI.\n\n The base URI must be an absolute URI or this function will return an error.\n The algorithm for merging uris is described in\n [RFC 3986](https://tools.ietf.org/html/rfc3986#section-5.2).\n\nSynonyms:\ngleam/uri.merge\ngleam/uri merge","url":"gleam/uri.html#merge"},{"doc":"gleam/uri","title":"origin","content":"pub fn origin(uri: Uri) -&gt; Result(String, Nil)\n Fetches the origin of a URI.\n\n Returns the origin of a uri as defined in\n [RFC 6454](https://tools.ietf.org/html/rfc6454)\n\n The supported URI schemes are `http` and `https`.\n URLs without a scheme will return `Error`.\n\n ## Examples\n\n \n let assert Ok(uri) = parse(&quot;http://example.com/path?foo#bar&quot;)\n origin(uri)\n // -&gt; Ok(&quot;http://example.com&quot;)\n \n\nSynonyms:\ngleam/uri.origin\ngleam/uri origin","url":"gleam/uri.html#origin"},{"doc":"gleam/uri","title":"parse","content":"pub fn parse(uri_string: String) -&gt; Result(Uri, Nil)\n Parses a compliant URI string into the `Uri` Type.\n If the string is not a valid URI string then an error is returned.\n\n The opposite operation is `uri.to_string`.\n\n ## Examples\n\n \n parse(&quot;https://example.com:1234/a/b?query=true#fragment&quot;)\n // -&gt; Ok(\n //   Uri(\n //     scheme: Some(&quot;https&quot;),\n //     userinfo: None,\n //     host: Some(&quot;example.com&quot;),\n //     port: Some(1234),\n //     path: &quot;/a/b&quot;,\n //     query: Some(&quot;query=true&quot;),\n //     fragment: Some(&quot;fragment&quot;)\n //   )\n // )\n \n\nSynonyms:\ngleam/uri.parse\ngleam/uri parse","url":"gleam/uri.html#parse"},{"doc":"gleam/uri","title":"parse_query","content":"pub fn parse_query(\n  query: String,\n) -&gt; Result(List(#(String, String)), Nil)\n Parses an urlencoded query string into a list of key value pairs.\n Returns an error for invalid encoding.\n\n The opposite operation is `uri.query_to_string`.\n\n ## Examples\n\n \n parse_query(&quot;a=1&amp;b=2&quot;)\n // -&gt; Ok([#(&quot;a&quot;, &quot;1&quot;), #(&quot;b&quot;, &quot;2&quot;)])\n \n\nSynonyms:\ngleam/uri.parse_query\ngleam/uri parse_query","url":"gleam/uri.html#parse_query"},{"doc":"gleam/uri","title":"path_segments","content":"pub fn path_segments(path: String) -&gt; List(String)\n Splits the path section of a URI into it&#39;s constituent segments.\n\n Removes empty segments and resolves dot-segments as specified in\n [section 5.2](https://www.ietf.org/rfc/rfc3986.html#section-5.2) of the RFC.\n\n ## Examples\n\n \n path_segments(&quot;/users/1&quot;)\n // -&gt; [&quot;users&quot; ,&quot;1&quot;]\n \n\nSynonyms:\ngleam/uri.path_segments\ngleam/uri path_segments","url":"gleam/uri.html#path_segments"},{"doc":"gleam/uri","title":"percent_decode","content":"pub fn percent_decode(value: String) -&gt; Result(String, Nil)\n Decodes a percent encoded string.\n\n ## Examples\n\n \n percent_decode(&quot;100%25%20great+fun&quot;)\n // -&gt; Ok(&quot;100% great+fun&quot;)\n \n\nSynonyms:\ngleam/uri.percent_decode\ngleam/uri percent_decode","url":"gleam/uri.html#percent_decode"},{"doc":"gleam/uri","title":"percent_encode","content":"pub fn percent_encode(value: String) -&gt; String\n Encodes a string into a percent encoded representation.\n\n ## Examples\n\n \n percent_encode(&quot;100% great&quot;)\n // -&gt; &quot;100%25%20great&quot;\n \n\nSynonyms:\ngleam/uri.percent_encode\ngleam/uri percent_encode","url":"gleam/uri.html#percent_encode"},{"doc":"gleam/uri","title":"query_to_string","content":"pub fn query_to_string(query: List(#(String, String))) -&gt; String\n Encodes a list of key value pairs as a URI query string.\n\n The opposite operation is `uri.parse_query`.\n\n ## Examples\n\n \n query_to_string([#(&quot;a&quot;, &quot;1&quot;), #(&quot;b&quot;, &quot;2&quot;)])\n // -&gt; &quot;a=1&amp;b=2&quot;\n \n\nSynonyms:\ngleam/uri.query_to_string\ngleam/uri query_to_string","url":"gleam/uri.html#query_to_string"},{"doc":"gleam/uri","title":"to_string","content":"pub fn to_string(uri: Uri) -&gt; String\n Encodes a `Uri` value as a URI string.\n\n The opposite operation is `uri.parse`.\n\n ## Examples\n\n \n let uri = Uri(Some(&quot;http&quot;), None, Some(&quot;example.com&quot;), ...)\n to_string(uri)\n // -&gt; &quot;http://example.com&quot;\n \n\nSynonyms:\ngleam/uri.to_string\ngleam/uri to_string","url":"gleam/uri.html#to_string"},{"doc":"gleam/uri","title":"gleam/uri","content":" Utilities for working with URIs\n\n This module provides functions for working with URIs (for example, parsing\n URIs or encoding query strings). The functions in this module are implemented\n according to [RFC 3986](https://tools.ietf.org/html/rfc3986).\n\n Query encoding (Form encoding) is defined in the\n [W3C specification](https://www.w3.org/TR/html52/sec-forms.html#urlencoded-form-data).","url":"gleam/uri.html"}]);